@@ -23,16 +23,10 @@
 #include <vector>
 
 #include "exec/text_converter.hpp"
-#include "exprs/hll_hash_function.h"
 #include "gen_cpp/PlanNodes_types.h"
-#include "olap/olap_common.h"
-#include "olap/utils.h"
 #include "runtime/row_batch.h"
 #include "runtime/runtime_state.h"
-#include "runtime/string_value.h"
 #include "runtime/tuple_row.h"
-#include "util/debug_util.h"
-#include "util/file_utils.h"
 #include "util/hash_util.hpp"
 #include "util/runtime_profile.h"
 
@@ -128,6 +122,7 @@ Status CsvScanNode::prepare(RuntimeState* state) {
     }
 
     RETURN_IF_ERROR(ScanNode::prepare(state));
+    SCOPED_CONSUME_MEM_TRACKER(mem_tracker());
 
     // add timer
     _split_check_timer = ADD_TIMER(_runtime_profile, "split check timer");
@@ -195,7 +190,7 @@ Status CsvScanNode::prepare(RuntimeState* state) {
         return Status::InternalError("new a csv scanner failed.");
     }
 
-    _tuple_pool.reset(new (std::nothrow) MemPool(state->instance_mem_tracker().get()));
+    _tuple_pool.reset(new (std::nothrow) MemPool());
     if (_tuple_pool.get() == nullptr) {
         return Status::InternalError("new a mem pool failed.");
     }
@@ -210,7 +205,9 @@ Status CsvScanNode::prepare(RuntimeState* state) {
 }
 
 Status CsvScanNode::open(RuntimeState* state) {
+    SCOPED_TIMER(_runtime_profile->total_time_counter());
     RETURN_IF_ERROR(ExecNode::open(state));
+    SCOPED_CONSUME_MEM_TRACKER(mem_tracker());
     VLOG_CRITICAL << "CsvScanNode::Open";
 
     if (nullptr == state) {
@@ -223,9 +220,7 @@ Status CsvScanNode::open(RuntimeState* state) {
 
     _runtime_state = state;
 
-    RETURN_IF_ERROR(exec_debug_action(TExecNodePhase::OPEN));
     RETURN_IF_CANCELLED(state);
-    SCOPED_TIMER(_runtime_profile->total_time_counter());
     RETURN_IF_ERROR(_csv_scanner->open());
 
     return Status::OK();
@@ -241,9 +236,9 @@ Status CsvScanNode::get_next(RuntimeState* state, RowBatch* row_batch, bool* eos
         return Status::InternalError("used before initialize.");
     }
 
-    RETURN_IF_ERROR(exec_debug_action(TExecNodePhase::GETNEXT));
     RETURN_IF_CANCELLED(state);
     SCOPED_TIMER(_runtime_profile->total_time_counter());
+    SCOPED_CONSUME_MEM_TRACKER(mem_tracker());
 
     if (reached_limit()) {
         *eos = true;
@@ -321,7 +316,6 @@ Status CsvScanNode::close(RuntimeState* state) {
         return Status::OK();
     }
     VLOG_CRITICAL << "CsvScanNode::Close";
-    RETURN_IF_ERROR(exec_debug_action(TExecNodePhase::CLOSE));
 
     SCOPED_TIMER(_runtime_profile->total_time_counter());
 
@@ -490,7 +484,7 @@ bool CsvScanNode::check_and_write_text_slot(const std::string& column_name,
                                    char_len);
             value_to_convert_length = char_len;
         }
-    } else if (slot->type().is_decimal_type()) {
+    } else if (slot->type().is_decimal_v2_type()) {
         int precision = column_type.precision;
         int scale = column_type.scale;
         bool is_success = check_decimal_input(value, value_length, precision, scale, error_msg);
