@@ -17,36 +17,30 @@
 
 #include "exec/json_scanner.h"
 
-#include <algorithm>
 #include <fmt/format.h>
 
-#include "env/env.h"
-#include "exec/broker_reader.h"
-#include "exec/buffered_reader.h"
-#include "exec/local_file_reader.h"
+#include <algorithm>
+
 #include "exec/plain_text_line_reader.h"
-#include "exec/s3_reader.h"
-#include "exprs/expr.h"
 #include "exprs/json_functions.h"
-#include "gutil/strings/split.h"
+#include "io/file_factory.h"
 #include "runtime/exec_env.h"
-#include "runtime/mem_tracker.h"
 #include "runtime/runtime_state.h"
 
 namespace doris {
+using namespace ErrorCode;
 
 JsonScanner::JsonScanner(RuntimeState* state, RuntimeProfile* profile,
                          const TBrokerScanRangeParams& params,
                          const std::vector<TBrokerRangeDesc>& ranges,
                          const std::vector<TNetworkAddress>& broker_addresses,
                          const std::vector<TExpr>& pre_filter_texprs, ScannerCounter* counter)
-        : BaseScanner(state, profile, params, pre_filter_texprs, counter),
-          _ranges(ranges),
-          _broker_addresses(broker_addresses),
+        : BaseScanner(state, profile, params, ranges, broker_addresses, pre_filter_texprs, counter),
           _cur_file_reader(nullptr),
+          _cur_file_reader_s(nullptr),
+          _real_reader(nullptr),
           _cur_line_reader(nullptr),
           _cur_json_reader(nullptr),
-          _next_range(0),
           _cur_reader_eof(false),
           _read_json_by_line(false) {
     if (params.__isset.line_delimiter_length && params.line_delimiter_length > 1) {
@@ -66,11 +60,11 @@ Status JsonScanner::open() {
     return BaseScanner::open();
 }
 
-Status JsonScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool *fill_tuple) {
+Status JsonScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool* fill_tuple) {
     SCOPED_TIMER(_read_timer);
     // Get one line
     while (!_scanner_eof) {
-        if (_cur_file_reader == nullptr || _cur_reader_eof) {
+        if (!_real_reader || _cur_reader_eof) {
             RETURN_IF_ERROR(open_next_reader());
             // If there isn't any more reader, break this
             if (_scanner_eof) {
@@ -88,7 +82,7 @@ Status JsonScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool
 
         bool is_empty_row = false;
         RETURN_IF_ERROR(_cur_json_reader->read_json_row(_src_tuple, _src_slot_descs, tuple_pool,
-                                                    &is_empty_row, &_cur_reader_eof));
+                                                        &is_empty_row, &_cur_reader_eof));
 
         if (is_empty_row) {
             // Read empty row, just continue
@@ -112,28 +106,21 @@ Status JsonScanner::open_next_reader() {
         _scanner_eof = true;
         return Status::OK();
     }
+    RETURN_IF_ERROR(open_based_reader());
+    RETURN_IF_ERROR(open_json_reader());
+    _next_range++;
+    return Status::OK();
+}
 
+Status JsonScanner::open_based_reader() {
     RETURN_IF_ERROR(open_file_reader());
     if (_read_json_by_line) {
         RETURN_IF_ERROR(open_line_reader());
     }
-    RETURN_IF_ERROR(open_json_reader());
-    _next_range++;
-
     return Status::OK();
 }
 
 Status JsonScanner::open_file_reader() {
-    if (_cur_file_reader != nullptr) {
-        if (_stream_load_pipe != nullptr) {
-            _stream_load_pipe.reset();
-            _cur_file_reader = nullptr;
-        } else {
-            delete _cur_file_reader;
-            _cur_file_reader = nullptr;
-        }
-    }
-
     const TBrokerRangeDesc& range = _ranges[_next_range];
     int64_t start_offset = range.start_offset;
     if (start_offset != 0) {
@@ -142,45 +129,18 @@ Status JsonScanner::open_file_reader() {
     if (range.__isset.read_json_by_line) {
         _read_json_by_line = range.read_json_by_line;
     }
-    switch (range.file_type) {
-    case TFileType::FILE_LOCAL: {
-        LocalFileReader* file_reader = new LocalFileReader(range.path, start_offset);
-        RETURN_IF_ERROR(file_reader->open());
-        _cur_file_reader = file_reader;
-        break;
-    }
-    case TFileType::FILE_BROKER: {
-        BrokerReader* broker_reader =
-                new BrokerReader(_state->exec_env(), _broker_addresses, _params.properties,
-                                 range.path, start_offset);
-        RETURN_IF_ERROR(broker_reader->open());
-        _cur_file_reader = broker_reader;
-        break;
-    }
-    case TFileType::FILE_S3: {
-        BufferedReader* s3_reader =
-                new BufferedReader(_profile, new S3Reader(_params.properties, range.path, start_offset));
-        RETURN_IF_ERROR(s3_reader->open());
-        _cur_file_reader = s3_reader;
-        break;
-    }
-    case TFileType::FILE_STREAM: {
-        _stream_load_pipe = _state->exec_env()->load_stream_mgr()->get(range.load_id);
-        if (_stream_load_pipe == nullptr) {
-            VLOG_NOTICE << "unknown stream load id: " << UniqueId(range.load_id);
-            return Status::InternalError("unknown stream load id");
-        }
-        _cur_file_reader = _stream_load_pipe.get();
-        break;
-    }
-    default: {
-        std::stringstream ss;
-        ss << "Unknown file type, type=" << range.file_type;
-        return Status::InternalError(ss.str());
-    }
+
+    if (range.file_type == TFileType::FILE_STREAM) {
+        RETURN_IF_ERROR(FileFactory::create_pipe_reader(range.load_id, _cur_file_reader_s));
+        _real_reader = _cur_file_reader_s.get();
+    } else {
+        RETURN_IF_ERROR(FileFactory::create_file_reader(
+                range.file_type, _state->exec_env(), _profile, _broker_addresses,
+                _params.properties, range, start_offset, _cur_file_reader));
+        _real_reader = _cur_file_reader.get();
     }
     _cur_reader_eof = false;
-    return Status::OK();
+    return _real_reader->open();
 }
 
 Status JsonScanner::open_line_reader() {
@@ -197,8 +157,8 @@ Status JsonScanner::open_line_reader() {
     } else {
         _skip_next_line = false;
     }
-    _cur_line_reader = new PlainTextLineReader(_profile, _cur_file_reader, nullptr,
-                                               size, _line_delimiter, _line_delimiter_length);
+    _cur_line_reader = new PlainTextLineReader(_profile, _real_reader, nullptr, size,
+                                               _line_delimiter, _line_delimiter_length);
     _cur_reader_eof = false;
     return Status::OK();
 }
@@ -215,6 +175,24 @@ Status JsonScanner::open_json_reader() {
     bool num_as_string = false;
     bool fuzzy_parse = false;
 
+    RETURN_IF_ERROR(
+            get_range_params(jsonpath, json_root, strip_outer_array, num_as_string, fuzzy_parse));
+    if (_read_json_by_line) {
+        _cur_json_reader =
+                new JsonReader(_state, _counter, _profile, strip_outer_array, num_as_string,
+                               fuzzy_parse, &_scanner_eof, nullptr, _cur_line_reader);
+    } else {
+        _cur_json_reader = new JsonReader(_state, _counter, _profile, strip_outer_array,
+                                          num_as_string, fuzzy_parse, &_scanner_eof, _real_reader);
+    }
+
+    RETURN_IF_ERROR(_cur_json_reader->init(jsonpath, json_root));
+    return Status::OK();
+}
+
+Status JsonScanner::get_range_params(std::string& jsonpath, std::string& json_root,
+                                     bool& strip_outer_array, bool& num_as_string,
+                                     bool& fuzzy_parse) {
     const TBrokerRangeDesc& range = _ranges[_next_range];
 
     if (range.__isset.jsonpaths) {
@@ -232,16 +210,6 @@ Status JsonScanner::open_json_reader() {
     if (range.__isset.fuzzy_parse) {
         fuzzy_parse = range.fuzzy_parse;
     }
-    if (_read_json_by_line) {
-        _cur_json_reader =
-                new JsonReader(_state, _counter, _profile, strip_outer_array, num_as_string,
-                               fuzzy_parse, &_scanner_eof, nullptr, _cur_line_reader);
-    } else {
-        _cur_json_reader =  new JsonReader(_state, _counter, _profile, strip_outer_array, num_as_string,
-                                           fuzzy_parse, &_scanner_eof, _cur_file_reader);
-    }
-
-    RETURN_IF_ERROR(_cur_json_reader->init(jsonpath, json_root));
     return Status::OK();
 }
 
@@ -255,14 +223,6 @@ void JsonScanner::close() {
         delete _cur_line_reader;
         _cur_line_reader = nullptr;
     }
-    if (_cur_file_reader != nullptr) {
-        if (_stream_load_pipe != nullptr) {
-            _stream_load_pipe.reset();
-        } else {
-            delete _cur_file_reader;
-        }
-        _cur_file_reader = nullptr;
-    }
 }
 
 ////// class JsonDataInternal
@@ -281,9 +241,8 @@ rapidjson::Value::ConstValueIterator JsonDataInternal::get_next() {
 
 ////// class JsonReader
 JsonReader::JsonReader(RuntimeState* state, ScannerCounter* counter, RuntimeProfile* profile,
-                       bool strip_outer_array, bool num_as_string,bool fuzzy_parse,
-                       bool* scanner_eof,
-                       FileReader* file_reader, LineReader* line_reader)
+                       bool strip_outer_array, bool num_as_string, bool fuzzy_parse,
+                       bool* scanner_eof, FileReader* file_reader, LineReader* line_reader)
         : _handle_json_callback(nullptr),
           _next_line(0),
           _total_lines(0),
@@ -311,14 +270,8 @@ JsonReader::~JsonReader() {
 }
 
 Status JsonReader::init(const std::string& jsonpath, const std::string& json_root) {
-    // parse jsonpath
-    if (!jsonpath.empty()) {
-        Status st = _generate_json_paths(jsonpath, &_parsed_jsonpaths);
-        RETURN_IF_ERROR(st);
-    }
-    if (!json_root.empty()) {
-        JsonFunctions::parse_json_paths(json_root, &_parsed_json_root);
-    }
+    // generate _parsed_jsonpaths and _parsed_json_root
+    RETURN_IF_ERROR(_parse_jsonpath_and_json_root(jsonpath, json_root));
 
     //improve performance
     if (_parsed_jsonpaths.empty()) { // input is a simple json-string
@@ -333,17 +286,29 @@ Status JsonReader::init(const std::string& jsonpath, const std::string& json_roo
     return Status::OK();
 }
 
+Status JsonReader::_parse_jsonpath_and_json_root(const std::string& jsonpath,
+                                                 const std::string& json_root) {
+    // parse jsonpath
+    if (!jsonpath.empty()) {
+        RETURN_IF_ERROR(_generate_json_paths(jsonpath, &_parsed_jsonpaths));
+    }
+    if (!json_root.empty()) {
+        JsonFunctions::parse_json_paths(json_root, &_parsed_json_root);
+    }
+    return Status::OK();
+}
+
 Status JsonReader::_generate_json_paths(const std::string& jsonpath,
                                         std::vector<std::vector<JsonPath>>* vect) {
     rapidjson::Document jsonpaths_doc;
     if (!jsonpaths_doc.Parse(jsonpath.c_str(), jsonpath.length()).HasParseError()) {
         if (!jsonpaths_doc.IsArray()) {
-            return Status::InvalidArgument("Invalid json path: " + jsonpath);
+            return Status::InvalidArgument("Invalid json path: {}", jsonpath);
         } else {
             for (int i = 0; i < jsonpaths_doc.Size(); i++) {
                 const rapidjson::Value& path = jsonpaths_doc[i];
                 if (!path.IsString()) {
-                    return Status::InvalidArgument("Invalid json path: " + jsonpath);
+                    return Status::InvalidArgument("Invalid json path: {}", jsonpath);
                 }
                 std::vector<JsonPath> parsed_paths;
                 JsonFunctions::parse_json_paths(path.GetString(), &parsed_paths);
@@ -352,7 +317,7 @@ Status JsonReader::_generate_json_paths(const std::string& jsonpath,
             return Status::OK();
         }
     } else {
-        return Status::InvalidArgument("Invalid json path: " + jsonpath);
+        return Status::InvalidArgument("Invalid json path: {}", jsonpath);
     }
 }
 
@@ -365,7 +330,7 @@ void JsonReader::_close() {
 
 // read one json string from line reader or file reader and parse it to json doc.
 // return Status::DataQualityError() if data has quality error.
-// return other error if encounter other problemes.
+// return other error if encounter other problems.
 // return Status::OK() if parse succeed or reach EOF.
 Status JsonReader::_parse_json_doc(size_t* size, bool* eof) {
     // read a whole message
@@ -409,8 +374,10 @@ Status JsonReader::_parse_json_doc(size_t* size, bool* eof) {
     if (has_parse_error) {
         fmt::memory_buffer error_msg;
         fmt::format_to(error_msg, "Parse json data for JsonDoc failed. code: {}, error info: {}",
-                _origin_json_doc.GetParseError(), rapidjson::GetParseError_En(_origin_json_doc.GetParseError()));
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return std::string((char*)json_str, *size); },
+                       _origin_json_doc.GetParseError(),
+                       rapidjson::GetParseError_En(_origin_json_doc.GetParseError()));
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return std::string((char*)json_str, *size); },
                 [&]() -> std::string { return fmt::to_string(error_msg); }, _scanner_eof));
         _counter->num_rows_filtered++;
         if (*_scanner_eof) {
@@ -430,7 +397,8 @@ Status JsonReader::_parse_json_doc(size_t* size, bool* eof) {
         if (_json_doc == nullptr) {
             fmt::memory_buffer error_msg;
             fmt::format_to(error_msg, "{}", "JSON Root not found.");
-            RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(_origin_json_doc); },
+            RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                    [&]() -> std::string { return _print_json_value(_origin_json_doc); },
                     [&]() -> std::string { return fmt::to_string(error_msg); }, _scanner_eof));
             _counter->num_rows_filtered++;
             if (*_scanner_eof) {
@@ -446,8 +414,10 @@ Status JsonReader::_parse_json_doc(size_t* size, bool* eof) {
 
     if (_json_doc->IsArray() && !_strip_outer_array) {
         fmt::memory_buffer error_msg;
-        fmt::format_to(error_msg, "{}", "JSON data is array-object, `strip_outer_array` must be TRUE.");
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(_origin_json_doc); },
+        fmt::format_to(error_msg, "{}",
+                       "JSON data is array-object, `strip_outer_array` must be TRUE.");
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return _print_json_value(_origin_json_doc); },
                 [&]() -> std::string { return fmt::to_string(error_msg); }, _scanner_eof));
         _counter->num_rows_filtered++;
         if (*_scanner_eof) {
@@ -460,8 +430,10 @@ Status JsonReader::_parse_json_doc(size_t* size, bool* eof) {
 
     if (!_json_doc->IsArray() && _strip_outer_array) {
         fmt::memory_buffer error_msg;
-        fmt::format_to(error_msg, "{}", "JSON data is not an array-object, `strip_outer_array` must be FALSE.");
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(_origin_json_doc); },
+        fmt::format_to(error_msg, "{}",
+                       "JSON data is not an array-object, `strip_outer_array` must be FALSE.");
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return _print_json_value(_origin_json_doc); },
                 [&]() -> std::string { return fmt::to_string(error_msg); }, _scanner_eof));
         _counter->num_rows_filtered++;
         if (*_scanner_eof) {
@@ -502,8 +474,8 @@ void JsonReader::_fill_slot(Tuple* tuple, SlotDescriptor* slot_desc, MemPool* me
 }
 
 Status JsonReader::_write_data_to_tuple(rapidjson::Value::ConstValueIterator value,
-                                      SlotDescriptor* desc, Tuple* tuple, MemPool* tuple_pool,
-                                      bool* valid) {
+                                        SlotDescriptor* desc, Tuple* tuple, MemPool* tuple_pool,
+                                        bool* valid) {
     const char* str_value = nullptr;
     uint8_t tmp_buf[128] = {0};
     int32_t wbytes = 0;
@@ -514,19 +486,19 @@ Status JsonReader::_write_data_to_tuple(rapidjson::Value::ConstValueIterator val
         break;
     case rapidjson::Type::kNumberType:
         if (value->IsUint()) {
-            wbytes = sprintf((char*)tmp_buf, "%u", value->GetUint());
+            wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%u", value->GetUint());
             _fill_slot(tuple, desc, tuple_pool, tmp_buf, wbytes);
         } else if (value->IsInt()) {
-            wbytes = sprintf((char*)tmp_buf, "%d", value->GetInt());
+            wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%d", value->GetInt());
             _fill_slot(tuple, desc, tuple_pool, tmp_buf, wbytes);
         } else if (value->IsUint64()) {
-            wbytes = sprintf((char*)tmp_buf, "%lu", value->GetUint64());
+            wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%" PRIu64, value->GetUint64());
             _fill_slot(tuple, desc, tuple_pool, tmp_buf, wbytes);
         } else if (value->IsInt64()) {
-            wbytes = sprintf((char*)tmp_buf, "%ld", value->GetInt64());
+            wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%" PRId64, value->GetInt64());
             _fill_slot(tuple, desc, tuple_pool, tmp_buf, wbytes);
         } else {
-            wbytes = sprintf((char*)tmp_buf, "%f", value->GetDouble());
+            wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%f", value->GetDouble());
             _fill_slot(tuple, desc, tuple_pool, tmp_buf, wbytes);
         }
         break;
@@ -540,12 +512,16 @@ Status JsonReader::_write_data_to_tuple(rapidjson::Value::ConstValueIterator val
         if (desc->is_nullable()) {
             tuple->set_null(desc->null_indicator_offset());
         } else {
-            RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(*value); },
+            RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                    [&]() -> std::string { return _print_json_value(*value); },
                     [&]() -> std::string {
-                    fmt::memory_buffer error_msg;
-                    fmt::format_to(error_msg, "Json value is null, but the column `{}` is not nullable.", desc->col_name());
-                    return fmt::to_string(error_msg);
-                    }, _scanner_eof));
+                        fmt::memory_buffer error_msg;
+                        fmt::format_to(error_msg,
+                                       "Json value is null, but the column `{}` is not nullable.",
+                                       desc->col_name());
+                        return fmt::to_string(error_msg);
+                    },
+                    _scanner_eof));
             _counter->num_rows_filtered++;
             *valid = false;
             return Status::OK();
@@ -566,12 +542,13 @@ Status JsonReader::_write_data_to_tuple(rapidjson::Value::ConstValueIterator val
 // set valid to false and return OK if we met an invalid row.
 // return other status if encounter other problmes.
 Status JsonReader::_set_tuple_value(rapidjson::Value& objectValue, Tuple* tuple,
-                                  const std::vector<SlotDescriptor*>& slot_descs,
-                                  MemPool* tuple_pool, bool* valid) {
+                                    const std::vector<SlotDescriptor*>& slot_descs,
+                                    MemPool* tuple_pool, bool* valid) {
     if (!objectValue.IsObject()) {
         // Here we expect the incoming `objectValue` to be a Json Object, such as {"key" : "value"},
         // not other type of Json format.
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(objectValue); },
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return _print_json_value(objectValue); },
                 [&]() -> std::string { return "Expect json object value"; }, _scanner_eof));
         _counter->num_rows_filtered++;
         *valid = false; // current row is invalid
@@ -601,12 +578,17 @@ Status JsonReader::_set_tuple_value(rapidjson::Value& objectValue, Tuple* tuple,
                 tuple->set_null(v->null_indicator_offset());
                 nullcount++;
             } else {
-               RETURN_IF_ERROR( _state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(objectValue); },
+                RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                        [&]() -> std::string { return _print_json_value(objectValue); },
                         [&]() -> std::string {
-                        fmt::memory_buffer error_msg;
-                        fmt::format_to(error_msg, "The column `{}` is not nullable, but it's not found in jsondata.", v->col_name());
-                        return fmt::to_string(error_msg);
-                        }, _scanner_eof));
+                            fmt::memory_buffer error_msg;
+                            fmt::format_to(error_msg,
+                                           "The column `{}` is not nullable, but it's not found in "
+                                           "jsondata.",
+                                           v->col_name());
+                            return fmt::to_string(error_msg);
+                        },
+                        _scanner_eof));
                 _counter->num_rows_filtered++;
                 *valid = false; // current row is invalid
                 break;
@@ -615,8 +597,10 @@ Status JsonReader::_set_tuple_value(rapidjson::Value& objectValue, Tuple* tuple,
     }
 
     if (nullcount == slot_descs.size()) {
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(objectValue); },
-                [&]() -> std::string { return "All fields is null, this is a invalid row."; }, _scanner_eof));
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return _print_json_value(objectValue); },
+                [&]() -> std::string { return "All fields is null, this is a invalid row."; },
+                _scanner_eof));
         _counter->num_rows_filtered++;
         *valid = false;
         return Status::OK();
@@ -640,11 +624,11 @@ Status JsonReader::_handle_simple_json(Tuple* tuple, const std::vector<SlotDescr
         if (_next_line >= _total_lines) { // parse json and generic document
             size_t size = 0;
             Status st = _parse_json_doc(&size, eof);
-            if (st.is_data_quality_error()) {
+            if (st.is<DATA_QUALITY_ERROR>()) {
                 continue; // continue to read next
             }
-            RETURN_IF_ERROR(st); // terminate if encounter other errors
-            if (size == 0 || *eof) {          // read all data, then return
+            RETURN_IF_ERROR(st);     // terminate if encounter other errors
+            if (size == 0 || *eof) { // read all data, then return
                 *is_empty_row = true;
                 return Status::OK();
             }
@@ -654,7 +638,8 @@ Status JsonReader::_handle_simple_json(Tuple* tuple, const std::vector<SlotDescr
                 _total_lines = _json_doc->Size();
                 if (_total_lines == 0) {
                     // may be passing an empty json, such as "[]"
-                    RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(*_json_doc); },
+                    RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                            [&]() -> std::string { return _print_json_value(*_json_doc); },
                             [&]() -> std::string { return "Empty json line"; }, _scanner_eof));
                     _counter->num_rows_filtered++;
                     if (*_scanner_eof) {
@@ -715,7 +700,8 @@ Status JsonReader::_write_values_by_jsonpath(rapidjson::Value& objectValue, MemP
         bool wrap_explicitly = false;
         if (LIKELY(i < _parsed_jsonpaths.size())) {
             json_values = JsonFunctions::get_json_array_from_parsed_json(
-                    _parsed_jsonpaths[i], &objectValue, _origin_json_doc.GetAllocator(), &wrap_explicitly);
+                    _parsed_jsonpaths[i], &objectValue, _origin_json_doc.GetAllocator(),
+                    &wrap_explicitly);
         }
 
         if (json_values == nullptr) {
@@ -724,12 +710,17 @@ Status JsonReader::_write_values_by_jsonpath(rapidjson::Value& objectValue, MemP
                 tuple->set_null(slot_descs[i]->null_indicator_offset());
                 nullcount++;
             } else {
-                RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(objectValue); },
+                RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                        [&]() -> std::string { return _print_json_value(objectValue); },
                         [&]() -> std::string {
-                        fmt::memory_buffer error_msg;
-                        fmt::format_to(error_msg, "The column `{}` is not nullable, but it's not found in jsondata.", slot_descs[i]->col_name());
-                        return fmt::to_string(error_msg);
-                        }, _scanner_eof));
+                            fmt::memory_buffer error_msg;
+                            fmt::format_to(error_msg,
+                                           "The column `{}` is not nullable, but it's not found in "
+                                           "jsondata.",
+                                           slot_descs[i]->col_name());
+                            return fmt::to_string(error_msg);
+                        },
+                        _scanner_eof));
                 _counter->num_rows_filtered++;
                 *valid = false; // current row is invalid
                 break;
@@ -742,15 +733,20 @@ Status JsonReader::_write_values_by_jsonpath(rapidjson::Value& objectValue, MemP
                 // if json_values' size > 1, it means we just match an array, not a wrapped one, so no need to unwrap.
                 json_values = &((*json_values)[0]);
             }
-            RETURN_IF_ERROR(_write_data_to_tuple(json_values, slot_descs[i], tuple, tuple_pool, valid));
+            RETURN_IF_ERROR(
+                    _write_data_to_tuple(json_values, slot_descs[i], tuple, tuple_pool, valid));
             if (!(*valid)) {
                 break;
             }
         }
     }
     if (nullcount == column_num) {
-        RETURN_IF_ERROR(_state->append_error_msg_to_file([&]() -> std::string { return _print_json_value(objectValue); },
-                [&]() -> std::string { return "All fields is null or not matched, this is a invalid row."; }, _scanner_eof));
+        RETURN_IF_ERROR(_state->append_error_msg_to_file(
+                [&]() -> std::string { return _print_json_value(objectValue); },
+                [&]() -> std::string {
+                    return "All fields is null or not matched, this is a invalid row.";
+                },
+                _scanner_eof));
         _counter->num_rows_filtered++;
         *valid = false;
     }
@@ -770,7 +766,7 @@ Status JsonReader::_handle_nested_complex_json(Tuple* tuple,
     while (true) {
         size_t size = 0;
         Status st = _parse_json_doc(&size, eof);
-        if (st.is_data_quality_error()) {
+        if (st.is<DATA_QUALITY_ERROR>()) {
             continue; // continue to read next
         }
         RETURN_IF_ERROR(st);
@@ -803,16 +799,17 @@ Status JsonReader::_handle_nested_complex_json(Tuple* tuple,
  */
 Status JsonReader::_handle_flat_array_complex_json(Tuple* tuple,
                                                    const std::vector<SlotDescriptor*>& slot_descs,
-                                                   MemPool* tuple_pool, bool* is_empty_row, bool* eof) {
+                                                   MemPool* tuple_pool, bool* is_empty_row,
+                                                   bool* eof) {
     do {
         if (_next_line >= _total_lines) {
             size_t size = 0;
             Status st = _parse_json_doc(&size, eof);
-            if (st.is_data_quality_error()) {
+            if (st.is<DATA_QUALITY_ERROR>()) {
                 continue; // continue to read next
             }
-            RETURN_IF_ERROR(st); // terminate if encounter other errors
-            if (size == 0 || *eof) {          // read all data, then return
+            RETURN_IF_ERROR(st);     // terminate if encounter other errors
+            if (size == 0 || *eof) { // read all data, then return
                 *is_empty_row = true;
                 return Status::OK();
             }
@@ -827,7 +824,8 @@ Status JsonReader::_handle_flat_array_complex_json(Tuple* tuple,
         }
         rapidjson::Value& objectValue = (*_json_doc)[_next_line++];
         bool valid = true;
-        RETURN_IF_ERROR(_write_values_by_jsonpath(objectValue, tuple_pool, tuple, slot_descs, &valid));
+        RETURN_IF_ERROR(
+                _write_values_by_jsonpath(objectValue, tuple_pool, tuple, slot_descs, &valid));
         if (!valid) {
             continue; // process next line
         }
@@ -838,7 +836,7 @@ Status JsonReader::_handle_flat_array_complex_json(Tuple* tuple,
 }
 
 Status JsonReader::read_json_row(Tuple* tuple, const std::vector<SlotDescriptor*>& slot_descs,
-                        MemPool* tuple_pool, bool* is_empty_row, bool* eof) {
+                                 MemPool* tuple_pool, bool* is_empty_row, bool* eof) {
     return (this->*_handle_json_callback)(tuple, slot_descs, tuple_pool, is_empty_row, eof);
 }
 
