@@ -17,22 +17,11 @@
 
 #include "exec/orc_scanner.h"
 
-#include "exec/broker_reader.h"
-#include "exec/buffered_reader.h"
-#include "exec/local_file_reader.h"
-#include "exec/s3_reader.h"
-#include "exprs/expr.h"
-#include "runtime/descriptors.h"
+#include "io/file_factory.h"
 #include "runtime/exec_env.h"
-#include "runtime/mem_tracker.h"
-#include "runtime/raw_value.h"
 #include "runtime/runtime_state.h"
 #include "runtime/tuple.h"
 
-#if defined(__x86_64__)
-    #include "exec/hdfs_file_reader.h"
-#endif
-
 // orc include file didn't expose orc::TimezoneError
 // we have to declare it by hand, following is the source code in orc link
 // https://github.com/apache/orc/blob/84353fbfc447b06e0924024a8e03c1aaebd3e7a5/c%2B%2B/src/Timezone.hh#L104-L109
@@ -120,13 +109,9 @@ ORCScanner::ORCScanner(RuntimeState* state, RuntimeProfile* profile,
                        const TBrokerScanRangeParams& params,
                        const std::vector<TBrokerRangeDesc>& ranges,
                        const std::vector<TNetworkAddress>& broker_addresses,
-                       const std::vector<TExpr>& pre_filter_texprs,
-                       ScannerCounter* counter)
-        : BaseScanner(state, profile, params, pre_filter_texprs, counter),
-          _ranges(ranges),
-          _broker_addresses(broker_addresses),
+                       const std::vector<TExpr>& pre_filter_texprs, ScannerCounter* counter)
+        : BaseScanner(state, profile, params, ranges, broker_addresses, pre_filter_texprs, counter),
           // _splittable(params.splittable),
-          _next_range(0),
           _cur_file_eof(true),
           _total_groups(0),
           _current_group(0),
@@ -139,11 +124,23 @@ ORCScanner::~ORCScanner() {
 
 Status ORCScanner::open() {
     RETURN_IF_ERROR(BaseScanner::open());
+    if (!_ranges.empty()) {
+        std::list<std::string> include_cols;
+        TBrokerRangeDesc range = _ranges[0];
+        _num_of_columns_from_file = range.__isset.num_of_columns_from_file
+                                            ? range.num_of_columns_from_file
+                                            : _src_slot_descs.size();
+        for (int i = 0; i < _num_of_columns_from_file; i++) {
+            auto slot_desc = _src_slot_descs.at(i);
+            include_cols.push_back(slot_desc->col_name());
+        }
+        _row_reader_options.include(include_cols);
+    }
 
     return Status::OK();
 }
 
-Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool* fill_tuple ) {
+Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool* fill_tuple) {
     try {
         SCOPED_TIMER(_read_timer);
         // Get one line
@@ -174,13 +171,8 @@ Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool*
                     ((orc::StructVectorBatch*)_batch.get())->fields;
             for (int column_ipos = 0; column_ipos < _num_of_columns_from_file; ++column_ipos) {
                 auto slot_desc = _src_slot_descs[column_ipos];
-                if (_map_column_to_id.find(slot_desc->col_name()) == _map_column_to_id.end()) {
-                    // if slot not exist in file, set to null
-                    _src_tuple->set_null(slot_desc->null_indicator_offset());
-                    continue;
-                }
-
                 orc::ColumnVectorBatch* cvb = batch_vec[_position_in_orc_original[column_ipos]];
+
                 if (cvb->hasNulls && !cvb->notNull[_current_line_of_group]) {
                     if (!slot_desc->is_nullable()) {
                         std::stringstream str_error;
@@ -220,7 +212,7 @@ Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool*
                     case orc::SHORT:
                     case orc::LONG: {
                         int64_t value = ((orc::LongVectorBatch*)cvb)->data[_current_line_of_group];
-                        wbytes = sprintf((char*)tmp_buf, "%ld", value);
+                        wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%" PRId64, value);
                         str_slot->ptr = reinterpret_cast<char*>(tuple_pool->allocate(wbytes));
                         memcpy(str_slot->ptr, tmp_buf, wbytes);
                         str_slot->len = wbytes;
@@ -229,7 +221,7 @@ Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool*
                     case orc::FLOAT:
                     case orc::DOUBLE: {
                         double value = ((orc::DoubleVectorBatch*)cvb)->data[_current_line_of_group];
-                        wbytes = sprintf((char*)tmp_buf, "%.9f", value);
+                        wbytes = snprintf((char*)tmp_buf, sizeof(tmp_buf), "%.9f", value);
                         str_slot->ptr = reinterpret_cast<char*>(tuple_pool->allocate(wbytes));
                         memcpy(str_slot->ptr, tmp_buf, wbytes);
                         str_slot->len = wbytes;
@@ -267,7 +259,7 @@ Status ORCScanner::get_next(Tuple* tuple, MemPool* tuple_pool, bool* eof, bool*
 
                         std::string v;
                         if (decimal_scale_length <= scale) {
-                            // decimal(5,2) : the integer of 0.01 is 1, so we should fill 0 befor integer
+                            // decimal(5,2) : the integer of 0.01 is 1, so we should fill 0 before integer
                             v = std::string(negative ? "-0." : "0.");
                             int fill_zero = scale - decimal_scale_length;
                             while (fill_zero--) {
@@ -385,43 +377,11 @@ Status ORCScanner::open_next_reader() {
         }
         const TBrokerRangeDesc& range = _ranges[_next_range++];
         std::unique_ptr<FileReader> file_reader;
-        switch (range.file_type) {
-        case TFileType::FILE_LOCAL: {
-            file_reader.reset(new LocalFileReader(range.path, range.start_offset));
-            break;
-        }
-        case TFileType::FILE_BROKER: {
-            int64_t file_size = 0;
-            // for compatibility
-            if (range.__isset.file_size) {
-                file_size = range.file_size;
-            }
-            file_reader.reset(new BufferedReader(_profile, new BrokerReader(_state->exec_env(), _broker_addresses,
-                                               _params.properties, range.path, range.start_offset,
-                                               file_size)));
-            break;
-        }
-        case TFileType::FILE_S3: {
-            file_reader.reset(new BufferedReader(_profile,
-                    new S3Reader(_params.properties, range.path, range.start_offset)));
-            break;
-        }
-        case TFileType::FILE_HDFS: {
-#if defined(__x86_64__)
-            file_reader.reset(new HdfsFileReader(
-                    range.hdfs_params, range.path, range.start_offset));
-            break;
-#else
-            return Status::InternalError("HdfsFileReader do not support on non x86 platform");
-#endif
-        }
-        default: {
-            std::stringstream ss;
-            ss << "Unknown file type, type=" << range.file_type;
-            return Status::InternalError(ss.str());
-        }
-        }
+        RETURN_IF_ERROR(FileFactory::create_file_reader(
+                range.file_type, _state->exec_env(), _profile, _broker_addresses,
+                _params.properties, range, range.start_offset, file_reader));
         RETURN_IF_ERROR(file_reader->open());
+
         if (file_reader->size() == 0) {
             file_reader->close();
             continue;
@@ -439,24 +399,6 @@ Status ORCScanner::open_next_reader() {
         if (_reader->getNumberOfRows() == 0) {
             continue;
         }
-        // build map from column name to type id
-        build_name_id_map();
-        // set include names into read options
-        std::map<int, int> _include_cols_in_src_slots;
-        std::list<std::string> cols;
-        _num_of_columns_from_file = range.__isset.num_of_columns_from_file
-                                            ? range.num_of_columns_from_file
-                                            : _src_slot_descs.size();
-        for (int i = 0; i < _num_of_columns_from_file; i++) {
-            auto slot_desc = _src_slot_descs.at(i);
-
-            // get only columns exist orc file
-            if (_map_column_to_id.find(slot_desc->col_name()) != _map_column_to_id.end()) {
-                _include_cols_in_src_slots[cols.size()] = i;
-                cols.push_back(slot_desc->col_name());
-            }
-        }
-        _row_reader_options.include(cols);
 
         _total_groups = _reader->getNumberOfStripes();
         _current_group = 0;
@@ -473,9 +415,7 @@ Status ORCScanner::open_next_reader() {
             //include columns must in reader field, otherwise createRowReader will throw exception
             auto pos = std::find(include_cols.begin(), include_cols.end(),
                                  _row_reader->getSelectedType().getFieldName(i));
-            _position_in_orc_original.at(
-                    _include_cols_in_src_slots[std::distance(include_cols.begin(), pos)]) =
-                    orc_index++;
+            _position_in_orc_original.at(std::distance(include_cols.begin(), pos)) = orc_index++;
         }
         return Status::OK();
     }
@@ -488,39 +428,4 @@ void ORCScanner::close() {
     _row_reader.reset(nullptr);
 }
 
-void ORCScanner::build_name_id_map() {
-    _map_column_to_id.clear();
-    std::vector<std::string> columns;
-    const orc::Type& type = _reader->getType();
-    build_name_id_map_impl(columns, &type);
-}
-
-void ORCScanner::build_name_id_map_impl(std::vector<std::string>& columns, const orc::Type* type) {
-    if (orc::STRUCT == type->getKind()) {
-        for (size_t i = 0; i < type->getSubtypeCount(); ++i) {
-            const std::string& fieldName = type->getFieldName(i);
-            columns.push_back(fieldName);
-            _map_column_to_id[dot_column_path(columns)] = type->getSubtype(i)->getColumnId();
-            build_name_id_map_impl(columns, type->getSubtype(i));
-            columns.pop_back();
-        }
-    } else {
-        // other non-primitive type
-        for (size_t j = 0; j < type->getSubtypeCount(); ++j) {
-            build_name_id_map_impl(columns, type->getSubtype(j));
-        }
-    }
-}
-
-std::string ORCScanner::dot_column_path(const std::vector<std::string>& columns) {
-    if (columns.empty()) {
-        return std::string();
-    }
-    std::ostringstream columnStream;
-    std::copy(columns.begin(), columns.end(),
-              std::ostream_iterator<std::string>(columnStream, "."));
-    std::string columnPath = columnStream.str();
-    return columnPath.substr(0, columnPath.length() - 1);
-}
-
 } // namespace doris
