@@ -19,18 +19,11 @@
 
 #include <arrow/array.h>
 #include <arrow/status.h>
+#include <gen_cpp/DataSinks_types.h>
 #include <time.h>
 
-#include "common/logging.h"
-#include "exec/file_writer.h"
-#include "gen_cpp/PaloBrokerService_types.h"
-#include "gen_cpp/TPaloBrokerService.h"
-#include "runtime/broker_mgr.h"
-#include "runtime/client_cache.h"
-#include "runtime/descriptors.h"
-#include "runtime/exec_env.h"
-#include "runtime/mem_pool.h"
-#include "util/thrift_util.h"
+#include "io/file_writer.h"
+#include "util/mysql_global.h"
 #include "util/types.h"
 
 namespace doris {
@@ -48,6 +41,124 @@ ParquetOutputStream::~ParquetOutputStream() {
     }
 }
 
+void ParquetBuildHelper::build_schema_repetition_type(
+        parquet::Repetition::type& parquet_repetition_type,
+        const TParquetRepetitionType::type& column_repetition_type) {
+    switch (column_repetition_type) {
+    case TParquetRepetitionType::REQUIRED: {
+        parquet_repetition_type = parquet::Repetition::REQUIRED;
+        break;
+    }
+    case TParquetRepetitionType::REPEATED: {
+        parquet_repetition_type = parquet::Repetition::REPEATED;
+        break;
+    }
+    case TParquetRepetitionType::OPTIONAL: {
+        parquet_repetition_type = parquet::Repetition::OPTIONAL;
+        break;
+    }
+    default:
+        parquet_repetition_type = parquet::Repetition::UNDEFINED;
+    }
+}
+
+void ParquetBuildHelper::build_schema_data_type(parquet::Type::type& parquet_data_type,
+                                                const TParquetDataType::type& column_data_type) {
+    switch (column_data_type) {
+    case TParquetDataType::BOOLEAN: {
+        parquet_data_type = parquet::Type::BOOLEAN;
+        break;
+    }
+    case TParquetDataType::INT32: {
+        parquet_data_type = parquet::Type::INT32;
+        break;
+    }
+    case TParquetDataType::INT64: {
+        parquet_data_type = parquet::Type::INT64;
+        break;
+    }
+    case TParquetDataType::INT96: {
+        parquet_data_type = parquet::Type::INT96;
+        break;
+    }
+    case TParquetDataType::BYTE_ARRAY: {
+        parquet_data_type = parquet::Type::BYTE_ARRAY;
+        break;
+    }
+    case TParquetDataType::FLOAT: {
+        parquet_data_type = parquet::Type::FLOAT;
+        break;
+    }
+    case TParquetDataType::DOUBLE: {
+        parquet_data_type = parquet::Type::DOUBLE;
+        break;
+    }
+    case TParquetDataType::FIXED_LEN_BYTE_ARRAY: {
+        parquet_data_type = parquet::Type::FIXED_LEN_BYTE_ARRAY;
+        break;
+    }
+    default:
+        parquet_data_type = parquet::Type::UNDEFINED;
+    }
+}
+
+void ParquetBuildHelper::build_compression_type(
+        parquet::WriterProperties::Builder& builder,
+        const TParquetCompressionType::type& compression_type) {
+    switch (compression_type) {
+    case TParquetCompressionType::SNAPPY: {
+        builder.compression(parquet::Compression::SNAPPY);
+        break;
+    }
+    case TParquetCompressionType::GZIP: {
+        builder.compression(parquet::Compression::GZIP);
+        break;
+    }
+    case TParquetCompressionType::BROTLI: {
+        builder.compression(parquet::Compression::BROTLI);
+        break;
+    }
+    case TParquetCompressionType::ZSTD: {
+        builder.compression(parquet::Compression::ZSTD);
+        break;
+    }
+    case TParquetCompressionType::LZ4: {
+        builder.compression(parquet::Compression::LZ4);
+        break;
+    }
+    case TParquetCompressionType::LZO: {
+        builder.compression(parquet::Compression::LZO);
+        break;
+    }
+    case TParquetCompressionType::BZ2: {
+        builder.compression(parquet::Compression::BZ2);
+        break;
+    }
+    case TParquetCompressionType::UNCOMPRESSED: {
+        builder.compression(parquet::Compression::UNCOMPRESSED);
+        break;
+    }
+    default:
+        builder.compression(parquet::Compression::UNCOMPRESSED);
+    }
+}
+
+void ParquetBuildHelper::build_version(parquet::WriterProperties::Builder& builder,
+                                       const TParquetVersion::type& parquet_version) {
+    switch (parquet_version) {
+    case TParquetVersion::PARQUET_1_0: {
+        builder.version(parquet::ParquetVersion::PARQUET_1_0);
+        break;
+    }
+    case TParquetVersion::PARQUET_2_LATEST: {
+        builder.version(parquet::ParquetVersion::PARQUET_2_LATEST);
+        break;
+    }
+    default:
+        builder.version(parquet::ParquetVersion::PARQUET_1_0);
+    }
+}
+
 arrow::Status ParquetOutputStream::Write(const void* data, int64_t nbytes) {
     if (_is_closed) {
         return arrow::Status::OK();
@@ -55,7 +166,7 @@ arrow::Status ParquetOutputStream::Write(const void* data, int64_t nbytes) {
     size_t written_len = 0;
     Status st = _file_writer->write(static_cast<const uint8_t*>(data), nbytes, &written_len);
     if (!st.ok()) {
-        return arrow::Status::IOError(st.get_error_msg());
+        return arrow::Status::IOError(st.to_string());
     }
     _cur_pos += written_len;
     _written_len += written_len;
@@ -72,8 +183,8 @@ arrow::Status ParquetOutputStream::Close() {
     }
     Status st = _file_writer->close();
     if (!st.ok()) {
-        LOG(WARNING) << "close parquet output stream failed: " << st.get_error_msg();
-        return arrow::Status::IOError(st.get_error_msg());
+        LOG(WARNING) << "close parquet output stream failed: " << st;
+        return arrow::Status::IOError(st.to_string());
     }
     _is_closed = true;
     return arrow::Status::OK();
@@ -87,7 +198,6 @@ void ParquetOutputStream::set_written_len(int64_t written_len) {
     _written_len = written_len;
 }
 
-/// ParquetWriterWrapper
 ParquetWriterWrapper::ParquetWriterWrapper(FileWriter* file_writer,
                                            const std::vector<ExprContext*>& output_expr_ctxs,
                                            const std::map<std::string, std::string>& properties,
@@ -193,6 +303,55 @@ Status ParquetWriterWrapper::parse_schema(const std::vector<std::vector<std::str
     return Status::OK();
 }
 
+/// ParquetWriterWrapper
+ParquetWriterWrapper::ParquetWriterWrapper(FileWriter* file_writer,
+                                           const std::vector<ExprContext*>& output_expr_ctxs,
+                                           const std::vector<TParquetSchema>& parquet_schemas,
+                                           const TParquetCompressionType::type& compression_type,
+                                           const bool& parquet_disable_dictionary,
+                                           const TParquetVersion::type& parquet_version,
+                                           bool output_object_data)
+        : _output_expr_ctxs(output_expr_ctxs),
+          _cur_writed_rows(0),
+          _rg_writer(nullptr),
+          _output_object_data(output_object_data) {
+    _outstream = std::shared_ptr<ParquetOutputStream>(new ParquetOutputStream(file_writer));
+    parse_properties(compression_type, parquet_disable_dictionary, parquet_version);
+    parse_schema(parquet_schemas);
+    init_parquet_writer();
+}
+
+void ParquetWriterWrapper::parse_properties(const TParquetCompressionType::type& compression_type,
+                                            const bool& parquet_disable_dictionary,
+                                            const TParquetVersion::type& parquet_version) {
+    parquet::WriterProperties::Builder builder;
+    ParquetBuildHelper::build_compression_type(builder, compression_type);
+    ParquetBuildHelper::build_version(builder, parquet_version);
+    if (parquet_disable_dictionary) {
+        builder.disable_dictionary();
+    } else {
+        builder.enable_dictionary();
+    }
+    _properties = builder.build();
+}
+
+void ParquetWriterWrapper::parse_schema(const std::vector<TParquetSchema>& parquet_schemas) {
+    parquet::schema::NodeVector fields;
+    parquet::Repetition::type parquet_repetition_type;
+    parquet::Type::type parquet_data_type;
+    for (int idx = 0; idx < parquet_schemas.size(); ++idx) {
+        ParquetBuildHelper::build_schema_repetition_type(
+                parquet_repetition_type, parquet_schemas[idx].schema_repetition_type);
+        ParquetBuildHelper::build_schema_data_type(parquet_data_type,
+                                                   parquet_schemas[idx].schema_data_type);
+        fields.push_back(parquet::schema::PrimitiveNode::Make(
+                parquet_schemas[idx].schema_column_name, parquet_repetition_type,
+                parquet::LogicalType::None(), parquet_data_type));
+        _schema = std::static_pointer_cast<parquet::schema::GroupNode>(
+                parquet::schema::GroupNode::Make("schema", parquet::Repetition::REQUIRED, fields));
+    }
+}
+
 Status ParquetWriterWrapper::write(const RowBatch& row_batch) {
     int num_rows = row_batch.num_rows();
     for (int i = 0; i < num_rows; ++i) {
@@ -236,20 +395,11 @@ void ParquetWriterWrapper::write_int32_column(int index, T* item) {
 
 Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
     int num_columns = _output_expr_ctxs.size();
-    if (num_columns != _str_schema.size()) {
-        return Status::InternalError("project field size is not equal to schema column size");
-    }
     try {
         for (int index = 0; index < num_columns; ++index) {
             void* item = _output_expr_ctxs[index]->get_value(row);
             switch (_output_expr_ctxs[index]->root()->type().type) {
             case TYPE_BOOLEAN: {
-                if (_str_schema[index][1] != "boolean") {
-                    std::stringstream ss;
-                    ss << "project field type is boolean, but the definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::BoolWriter* col_writer =
                         static_cast<parquet::BoolWriter*>(rgWriter->column(index));
@@ -262,46 +412,18 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
                 break;
             }
             case TYPE_TINYINT: {
-                if (_str_schema[index][1] != "int32") {
-                    std::stringstream ss;
-                    ss << "project field type is tiny int, should use int32, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 write_int32_column(index, static_cast<int8_t*>(item));
                 break;
             }
             case TYPE_SMALLINT: {
-                if (_str_schema[index][1] != "int32") {
-                    std::stringstream ss;
-                    ss << "project field type is small int, should use int32, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 write_int32_column(index, static_cast<int16_t*>(item));
                 break;
             }
             case TYPE_INT: {
-                if (_str_schema[index][1] != "int32") {
-                    std::stringstream ss;
-                    ss << "project field type is tiny int/small int/int, should use int32, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 write_int32_column(index, static_cast<int32_t*>(item));
                 break;
             }
             case TYPE_BIGINT: {
-                if (_str_schema[index][1] != "int64") {
-                    std::stringstream ss;
-                    ss << "project field type is big int, should use int64, but the definition "
-                          "type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::Int64Writer* col_writer =
                         static_cast<parquet::Int64Writer*>(rgWriter->column(index));
@@ -324,12 +446,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
                 return Status::InvalidArgument("do not support large int type.");
             }
             case TYPE_FLOAT: {
-                if (_str_schema[index][1] != "float") {
-                    std::stringstream ss;
-                    ss << "project field type is float, but the definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::FloatWriter* col_writer =
                         static_cast<parquet::FloatWriter*>(rgWriter->column(index));
@@ -342,12 +458,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
                 break;
             }
             case TYPE_DOUBLE: {
-                if (_str_schema[index][1] != "double") {
-                    std::stringstream ss;
-                    ss << "project field type is double, but the definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::DoubleWriter* col_writer =
                         static_cast<parquet::DoubleWriter*>(rgWriter->column(index));
@@ -361,13 +471,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
             }
             case TYPE_DATETIME:
             case TYPE_DATE: {
-                if (_str_schema[index][1] != "int64") {
-                    std::stringstream ss;
-                    ss << "project field type is date/datetime, should use int64, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::Int64Writer* col_writer =
                         static_cast<parquet::Int64Writer*>(rgWriter->column(index));
@@ -385,13 +488,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
             case TYPE_HLL:
             case TYPE_OBJECT: {
                 if (_output_object_data) {
-                    if (_str_schema[index][1] != "byte_array") {
-                        std::stringstream ss;
-                        ss << "project field type is hll/bitmap, should use byte_array, but the "
-                              "definition type of column "
-                           << _str_schema[index][2] << " is " << _str_schema[index][1];
-                        return Status::InvalidArgument(ss.str());
-                    }
                     parquet::RowGroupWriter* rgWriter = get_rg_writer();
                     parquet::ByteArrayWriter* col_writer =
                             static_cast<parquet::ByteArrayWriter*>(rgWriter->column(index));
@@ -416,13 +512,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
             case TYPE_CHAR:
             case TYPE_VARCHAR:
             case TYPE_STRING: {
-                if (_str_schema[index][1] != "byte_array") {
-                    std::stringstream ss;
-                    ss << "project field type is char/varchar, should use byte_array, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::ByteArrayWriter* col_writer =
                         static_cast<parquet::ByteArrayWriter*>(rgWriter->column(index));
@@ -439,13 +528,6 @@ Status ParquetWriterWrapper::_write_one_row(TupleRow* row) {
                 break;
             }
             case TYPE_DECIMALV2: {
-                if (_str_schema[index][1] != "byte_array") {
-                    std::stringstream ss;
-                    ss << "project field type is decimal v2, should use byte_array, but the "
-                          "definition type of column "
-                       << _str_schema[index][2] << " is " << _str_schema[index][1];
-                    return Status::InvalidArgument(ss.str());
-                }
                 parquet::RowGroupWriter* rgWriter = get_rg_writer();
                 parquet::ByteArrayWriter* col_writer =
                         static_cast<parquet::ByteArrayWriter*>(rgWriter->column(index));
@@ -498,6 +580,4 @@ void ParquetWriterWrapper::close() {
     }
 }
 
-ParquetWriterWrapper::~ParquetWriterWrapper() {}
-
 } // namespace doris
