@@ -14,9 +14,11 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exec/partitioned-aggregation-node.h
+// and modified by Doris
 
-#ifndef DORIS_BE_SRC_EXEC_NEW_PARTITIONED_AGGREGATION_NODE_H
-#define DORIS_BE_SRC_EXEC_NEW_PARTITIONED_AGGREGATION_NODE_H
+#pragma once
 
 #include <deque>
 
@@ -26,7 +28,6 @@
 #include "runtime/bufferpool/suballocator.h"
 #include "runtime/descriptors.h" // for TupleId
 #include "runtime/mem_pool.h"
-#include "runtime/string_value.h"
 
 namespace doris {
 
@@ -403,7 +404,7 @@ private:
         void Close(bool finalize_rows);
 
         /// Spill this partition. 'more_aggregate_rows' = true means that more aggregate rows
-        /// may be appended to the the partition before appending unaggregated rows. On
+        /// may be appended to the partition before appending unaggregated rows. On
         /// success, one of the streams is left with a write iterator: the aggregated stream
         /// if 'more_aggregate_rows' is true or the unaggregated stream otherwise.
         Status Spill(bool more_aggregate_rows);
@@ -526,7 +527,7 @@ private:
     /// GetNext() using the agg fn evaluators' Serialize() or Finalize().
     /// For the Finalize() case if the output tuple is different from the intermediate
     /// tuple, then a new tuple is allocated from 'pool' to hold the final result.
-    /// Grouping values are copied into the output tuple and the the output tuple holding
+    /// Grouping values are copied into the output tuple and the output tuple holding
     /// the finalized/serialized aggregate values is returned.
     /// TODO: Coordinate the allocation of new tuples with the release of memory
     /// so as not to make memory consumption blow up.
@@ -693,5 +694,3 @@ private:
 };
 
 } // namespace doris
-
-#endif
