@@ -15,8 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#ifndef DORIS_BE_SRC_QUERY_EXEC_SCHEMA_SCANNER_SCHEMA_USER_PRIVILEGES_SCANNER_H
-#define DORIS_BE_SRC_QUERY_EXEC_SCHEMA_SCANNER_SCHEMA_USER_PRIVILEGES_SCANNER_H
+#pragma once
 
 #include "exec/schema_scanner.h"
 #include "gen_cpp/FrontendService_types.h"
@@ -42,5 +41,3 @@ private:
 };
 
 } // namespace doris
-
-#endif
