@@ -15,18 +15,14 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#include "butil/fast_rand.h"
 #include "exec/tablet_info.h"
 
+#include "runtime/large_int_value.h"
 #include "runtime/mem_pool.h"
-#include "runtime/mem_tracker.h"
-#include "runtime/row_batch.h"
-#include "runtime/tuple_row.h"
 #include "util/random.h"
 #include "util/string_parser.hpp"
 #include "util/time.h"
 
-
 namespace doris {
 
 void OlapTableIndexSchema::to_protobuf(POlapTableIndexSchema* pindex) const {
@@ -35,6 +31,9 @@ void OlapTableIndexSchema::to_protobuf(POlapTableIndexSchema* pindex) const {
     for (auto slot : slots) {
         pindex->add_columns(slot->col_name());
     }
+    for (auto column : columns) {
+        column->to_schema_pb(pindex->add_columns_desc());
+    }
 }
 
 Status OlapTableSchemaParam::init(const POlapTableSchemaParam& pschema) {
@@ -57,12 +56,15 @@ Status OlapTableSchemaParam::init(const POlapTableSchemaParam& pschema) {
         for (auto& col : p_index.columns()) {
             auto it = slots_map.find(col);
             if (it == std::end(slots_map)) {
-                std::stringstream ss;
-                ss << "unknown index column, column=" << col;
-                return Status::InternalError(ss.str());
+                return Status::InternalError("unknown index column, column={}", col);
             }
             index->slots.emplace_back(it->second);
         }
+        for (auto& pcolumn_desc : p_index.columns_desc()) {
+            TabletColumn* tc = _obj_pool.add(new TabletColumn());
+            tc->init_from_pb(pcolumn_desc);
+            index->columns.emplace_back(tc);
+        }
         _indexes.emplace_back(index);
     }
 
@@ -92,12 +94,17 @@ Status OlapTableSchemaParam::init(const TOlapTableSchemaParam& tschema) {
         for (auto& col : t_index.columns) {
             auto it = slots_map.find(col);
             if (it == std::end(slots_map)) {
-                std::stringstream ss;
-                ss << "unknown index column, column=" << col;
-                return Status::InternalError(ss.str());
+                return Status::InternalError("unknown index column, column={}", col);
             }
             index->slots.emplace_back(it->second);
         }
+        if (t_index.__isset.columns_desc) {
+            for (auto& tcolumn_desc : t_index.columns_desc) {
+                TabletColumn* tc = _obj_pool.add(new TabletColumn());
+                tc->init_from_thrift(tcolumn_desc);
+                index->columns.emplace_back(tc);
+            }
+        }
         _indexes.emplace_back(index);
     }
 
@@ -163,10 +170,7 @@ std::string OlapTablePartition::debug_string(TupleDescriptor* tuple_desc) const
 
 OlapTablePartitionParam::OlapTablePartitionParam(std::shared_ptr<OlapTableSchemaParam> schema,
                                                  const TOlapTablePartitionParam& t_param)
-        : _schema(schema),
-          _t_param(t_param),
-          _mem_tracker(MemTracker::CreateTracker(-1, "OlapTablePartitionParam")),
-          _mem_pool(new MemPool(_mem_tracker.get())) {}
+        : _schema(schema), _t_param(t_param), _mem_pool(new MemPool()) {}
 
 OlapTablePartitionParam::~OlapTablePartitionParam() {}
 
@@ -178,18 +182,15 @@ Status OlapTablePartitionParam::init() {
     if (_t_param.__isset.partition_column) {
         auto it = slots_map.find(_t_param.partition_column);
         if (it == std::end(slots_map)) {
-            std::stringstream ss;
-            ss << "partition column not found, column=" << _t_param.partition_column;
-            return Status::InternalError(ss.str());
+            return Status::InternalError("partition column not found, column={}",
+                                         _t_param.partition_column);
         }
         _partition_slot_descs.push_back(it->second);
     } else if (_t_param.__isset.partition_columns) {
         for (auto& part_col : _t_param.partition_columns) {
             auto it = slots_map.find(part_col);
             if (it == std::end(slots_map)) {
-                std::stringstream ss;
-                ss << "partition column not found, column=" << part_col;
-                return Status::InternalError(ss.str());
+                return Status::InternalError("partition column not found, column={}", part_col);
             }
             _partition_slot_descs.push_back(it->second);
         }
@@ -201,9 +202,7 @@ Status OlapTablePartitionParam::init() {
         for (auto& col : _t_param.distributed_columns) {
             auto it = slots_map.find(col);
             if (it == std::end(slots_map)) {
-                std::stringstream ss;
-                ss << "distributed column not found, columns=" << col;
-                return Status::InternalError(ss.str());
+                return Status::InternalError("distributed column not found, columns={}", col);
             }
             _distributed_slot_descs.emplace_back(it->second);
         }
@@ -223,10 +222,7 @@ Status OlapTablePartitionParam::init() {
                 if (slot != nullptr) {
                     hash_val = RawValue::zlib_crc32(slot, slot_desc->type(), hash_val);
                 } else {
-                    //nullptr is treat as 0 when hash
-                    static const int INT_VALUE = 0;
-                    static const TypeDescriptor INT_TYPE(TYPE_INT);
-                    hash_val = RawValue::zlib_crc32(&INT_VALUE, INT_TYPE, hash_val);
+                    hash_val = HashUtil::zlib_crc_hash_null(hash_val);
                 }
             }
             return hash_val % num_buckets;
@@ -262,11 +258,10 @@ Status OlapTablePartitionParam::init() {
         part->num_buckets = t_part.num_buckets;
         auto num_indexes = _schema->indexes().size();
         if (t_part.indexes.size() != num_indexes) {
-            std::stringstream ss;
-            ss << "number of partition's index is not equal with schema's"
-               << ", num_part_indexes=" << t_part.indexes.size()
-               << ", num_schema_indexes=" << num_indexes;
-            return Status::InternalError(ss.str());
+            return Status::InternalError(
+                    "number of partition's index is not equal with schema's,"
+                    "num_part_indexes={}, num_schema_indexes={}",
+                    t_part.indexes.size(), num_indexes);
         }
         part->indexes = t_part.indexes;
         std::sort(part->indexes.begin(), part->indexes.end(),
@@ -280,7 +275,10 @@ Status OlapTablePartitionParam::init() {
                 ss << "partition's index is not equal with schema's"
                    << ", part_index=" << part->indexes[j].index_id
                    << ", schema_index=" << _schema->indexes()[j]->index_id;
-                return Status::InternalError(ss.str());
+                return Status::InternalError(
+                        "partition's index is not equal with schema's"
+                        ", part_index={}, schema_index={}",
+                        part->indexes[j].index_id, _schema->indexes()[j]->index_id);
             }
         }
         _partitions.emplace_back(part);
@@ -295,9 +293,11 @@ Status OlapTablePartitionParam::init() {
     return Status::OK();
 }
 
-bool OlapTablePartitionParam::find_partition(Tuple* tuple, const OlapTablePartition** partition) const {
+bool OlapTablePartitionParam::find_partition(Tuple* tuple,
+                                             const OlapTablePartition** partition) const {
     const TOlapTablePartition& t_part = _t_param.partitions[0];
-    auto it = t_part.__isset.in_keys ? _partitions_map->find(tuple) : _partitions_map->upper_bound(tuple);
+    auto it = t_part.__isset.in_keys ? _partitions_map->find(tuple)
+                                     : _partitions_map->upper_bound(tuple);
     if (it == _partitions_map->end()) {
         return false;
     }
@@ -308,7 +308,8 @@ bool OlapTablePartitionParam::find_partition(Tuple* tuple, const OlapTablePartit
     return false;
 }
 
-uint32_t OlapTablePartitionParam::find_tablet(Tuple* tuple, const OlapTablePartition& partition) const {
+uint32_t OlapTablePartitionParam::find_tablet(Tuple* tuple,
+                                              const OlapTablePartition& partition) const {
     return _compute_tablet_index(tuple, partition.num_buckets);
 }
 
@@ -329,11 +330,33 @@ Status OlapTablePartitionParam::_create_partition_key(const TExprNode& t_expr, T
     tuple->set_not_null(slot_desc->null_indicator_offset());
     switch (t_expr.node_type) {
     case TExprNodeType::DATE_LITERAL: {
-        if (!reinterpret_cast<DateTimeValue*>(slot)->from_date_str(
-                    t_expr.date_literal.value.c_str(), t_expr.date_literal.value.size())) {
-            std::stringstream ss;
-            ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
-            return Status::InternalError(ss.str());
+        if ((t_expr.type.types[0].scalar_type.type == TPrimitiveType::DATE) ||
+            (t_expr.type.types[0].scalar_type.type == TPrimitiveType::DATETIME)) {
+            if (!reinterpret_cast<DateTimeValue*>(slot)->from_date_str(
+                        t_expr.date_literal.value.c_str(), t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
+        } else if (t_expr.type.types[0].scalar_type.type == TPrimitiveType::DATEV2) {
+            if (!reinterpret_cast<
+                         doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType>*>(slot)
+                         ->from_date_str(t_expr.date_literal.value.c_str(),
+                                         t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
+        } else {
+            if (!reinterpret_cast<
+                         doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType>*>(
+                         slot)
+                         ->from_date_str(t_expr.date_literal.value.c_str(),
+                                         t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
         }
         break;
     }
@@ -391,9 +414,8 @@ Status OlapTablePartitionParam::_create_partition_key(const TExprNode& t_expr, T
         break;
     }
     default: {
-        std::stringstream ss;
-        ss << "unsupported partition column node type, type=" << t_expr.node_type;
-        return Status::InternalError(ss.str());
+        return Status::InternalError("unsupported partition column node type, type={}",
+                                     t_expr.node_type);
     }
     }
     return Status::OK();
@@ -414,18 +436,19 @@ std::string OlapTablePartitionParam::debug_string() const {
 }
 
 VOlapTablePartitionParam::VOlapTablePartitionParam(std::shared_ptr<OlapTableSchemaParam>& schema,
-                                                 const TOlapTablePartitionParam& t_param)
+                                                   const TOlapTablePartitionParam& t_param)
         : _schema(schema),
           _t_param(t_param),
           _slots(_schema->tuple_desc()->slots()),
-          _mem_tracker(MemTracker::CreateTracker(-1, "OlapTablePartitionParam")) {
+          _mem_tracker(std::make_unique<MemTracker>("OlapTablePartitionParam")) {
     for (auto slot : _slots) {
-        _partition_block.insert({slot->get_empty_mutable_column(), slot->get_data_type_ptr(), slot->col_name()});
+        _partition_block.insert(
+                {slot->get_empty_mutable_column(), slot->get_data_type_ptr(), slot->col_name()});
     }
 }
 
 VOlapTablePartitionParam::~VOlapTablePartitionParam() {
-    _mem_tracker->Release(_mem_usage);
+    _mem_tracker->release(_mem_usage);
 }
 
 Status VOlapTablePartitionParam::init() {
@@ -434,10 +457,12 @@ Status VOlapTablePartitionParam::init() {
         slot_column_names.emplace_back(slot_desc->col_name());
     }
 
-    auto find_slot_locs = [&slot_column_names](const std::string& slot_name, std::vector<uint16_t>& locs, const std::string& column_type) {
+    auto find_slot_locs = [&slot_column_names](const std::string& slot_name,
+                                               std::vector<uint16_t>& locs,
+                                               const std::string& column_type) {
         auto it = std::find(slot_column_names.begin(), slot_column_names.end(), slot_name);
         if (it == slot_column_names.end()) {
-            return Status::InternalError(column_type + " column not found, column =" + slot_name);
+            return Status::InternalError("{} column not found, column ={}", column_type, slot_name);
         }
         locs.emplace_back(it - slot_column_names.begin());
         return Status::OK();
@@ -449,8 +474,9 @@ Status VOlapTablePartitionParam::init() {
         }
     }
 
-    _partitions_map.reset(new std::map<BlockRow*, VOlapTablePartition*, VOlapTablePartKeyComparator>(
-            VOlapTablePartKeyComparator(_partition_slot_locs)));
+    _partitions_map.reset(
+            new std::map<BlockRow*, VOlapTablePartition*, VOlapTablePartKeyComparator>(
+                    VOlapTablePartKeyComparator(_partition_slot_locs)));
     if (_t_param.__isset.distributed_columns) {
         for (auto& col : _t_param.distributed_columns) {
             RETURN_IF_ERROR(find_slot_locs(col, _distributed_slot_locs, "distributed"));
@@ -465,15 +491,13 @@ Status VOlapTablePartitionParam::init() {
             uint32_t hash_val = 0;
             for (int i = 0; i < _distributed_slot_locs.size(); ++i) {
                 auto slot_desc = _slots[_distributed_slot_locs[i]];
-                auto column = key->first->get_by_position(_distributed_slot_locs[i]).column;
+                auto& column = key->first->get_by_position(_distributed_slot_locs[i]).column;
                 auto val = column->get_data_at(key->second);
                 if (val.data != nullptr) {
-                    hash_val = RawValue::zlib_crc32(val.data, val.size, slot_desc->type().type, hash_val);
+                    hash_val = RawValue::zlib_crc32(val.data, val.size, slot_desc->type().type,
+                                                    hash_val);
                 } else {
-                    // NULL is treat as 0 when hash
-                    static const int INT_VALUE = 0;
-                    static const TypeDescriptor INT_TYPE(TYPE_INT);
-                    hash_val = RawValue::zlib_crc32(&INT_VALUE, INT_TYPE, hash_val);
+                    hash_val = HashUtil::zlib_crc_hash_null(hash_val);
                 }
             }
             return hash_val % num_buckets;
@@ -499,18 +523,18 @@ Status VOlapTablePartitionParam::init() {
             }
         } else {
             for (const auto& keys : t_part.in_keys) {
-                RETURN_IF_ERROR(_create_partition_keys(keys, &part->in_keys.emplace_back(&_partition_block, -1)));
+                RETURN_IF_ERROR(_create_partition_keys(
+                        keys, &part->in_keys.emplace_back(&_partition_block, -1)));
             }
         }
 
         part->num_buckets = t_part.num_buckets;
         auto num_indexes = _schema->indexes().size();
         if (t_part.indexes.size() != num_indexes) {
-            std::stringstream ss;
-            ss << "number of partition's index is not equal with schema's"
-               << ", num_part_indexes=" << t_part.indexes.size()
-               << ", num_schema_indexes=" << num_indexes;
-            return Status::InternalError(ss.str());
+            return Status::InternalError(
+                    "number of partition's index is not equal with schema's"
+                    ", num_part_indexes={}, num_schema_indexes={}",
+                    t_part.indexes.size(), num_indexes);
         }
         part->indexes = t_part.indexes;
         std::sort(part->indexes.begin(), part->indexes.end(),
@@ -524,7 +548,10 @@ Status VOlapTablePartitionParam::init() {
                 ss << "partition's index is not equal with schema's"
                    << ", part_index=" << part->indexes[j].index_id
                    << ", schema_index=" << _schema->indexes()[j]->index_id;
-                return Status::InternalError(ss.str());
+                return Status::InternalError(
+                        "partition's index is not equal with schema's"
+                        ", part_index={}, schema_index={}",
+                        part->indexes[j].index_id, _schema->indexes()[j]->index_id);
             }
         }
         _partitions.emplace_back(part);
@@ -538,12 +565,14 @@ Status VOlapTablePartitionParam::init() {
     }
 
     _mem_usage = _partition_block.allocated_bytes();
-    _mem_tracker->Consume(_mem_usage);
+    _mem_tracker->consume(_mem_usage);
     return Status::OK();
 }
 
-bool VOlapTablePartitionParam::find_partition(BlockRow* block_row, const VOlapTablePartition** partition) const {
-    auto it = _is_in_partition ? _partitions_map->find(block_row) : _partitions_map->upper_bound(block_row);
+bool VOlapTablePartitionParam::find_partition(BlockRow* block_row,
+                                              const VOlapTablePartition** partition) const {
+    auto it = _is_in_partition ? _partitions_map->find(block_row)
+                               : _partitions_map->upper_bound(block_row);
     if (it == _partitions_map->end()) {
         return false;
     }
@@ -554,78 +583,101 @@ bool VOlapTablePartitionParam::find_partition(BlockRow* block_row, const VOlapTa
     return false;
 }
 
-uint32_t VOlapTablePartitionParam::find_tablet(BlockRow* block_row, const VOlapTablePartition& partition) const {
+uint32_t VOlapTablePartitionParam::find_tablet(BlockRow* block_row,
+                                               const VOlapTablePartition& partition) const {
     return _compute_tablet_index(block_row, partition.num_buckets);
 }
 
 Status VOlapTablePartitionParam::_create_partition_keys(const std::vector<TExprNode>& t_exprs,
-                                                       BlockRow* part_key) {
+                                                        BlockRow* part_key) {
     for (int i = 0; i < t_exprs.size(); i++) {
-        RETURN_IF_ERROR(_create_partition_key(t_exprs[i], part_key,
-                _partition_slot_locs[i]));
+        RETURN_IF_ERROR(_create_partition_key(t_exprs[i], part_key, _partition_slot_locs[i]));
     }
     return Status::OK();
 }
 
 Status VOlapTablePartitionParam::_create_partition_key(const TExprNode& t_expr, BlockRow* part_key,
-                                                      uint16_t pos) {
+                                                       uint16_t pos) {
     auto column = std::move(*part_key->first->get_by_position(pos).column).mutate();
     switch (t_expr.node_type) {
     case TExprNodeType::DATE_LITERAL: {
-        vectorized::VecDateTimeValue dt;
-        if (!dt.from_date_str(
-                    t_expr.date_literal.value.c_str(), t_expr.date_literal.value.size())) {
-            std::stringstream ss;
-            ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
-            return Status::InternalError(ss.str());
+        if (TypeDescriptor::from_thrift(t_expr.type).is_date_v2_type()) {
+            vectorized::DateV2Value<doris::vectorized::DateV2ValueType> dt;
+            if (!dt.from_date_str(t_expr.date_literal.value.c_str(),
+                                  t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
+            column->insert_data(reinterpret_cast<const char*>(&dt), 0);
+        } else if (TypeDescriptor::from_thrift(t_expr.type).is_datetime_v2_type()) {
+            vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> dt;
+            if (!dt.from_date_str(t_expr.date_literal.value.c_str(),
+                                  t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
+            column->insert_data(reinterpret_cast<const char*>(&dt), 0);
+        } else {
+            vectorized::VecDateTimeValue dt;
+            if (!dt.from_date_str(t_expr.date_literal.value.c_str(),
+                                  t_expr.date_literal.value.size())) {
+                std::stringstream ss;
+                ss << "invalid date literal in partition column, date=" << t_expr.date_literal;
+                return Status::InternalError(ss.str());
+            }
+            column->insert_data(reinterpret_cast<const char*>(&dt), 0);
         }
-        column->insert_data(reinterpret_cast<const char *>(&dt), 0);
         break;
     }
     case TExprNodeType::INT_LITERAL: {
         switch (t_expr.type.types[0].scalar_type.type) {
-            case TPrimitiveType::TINYINT: {
-                int8_t value = t_expr.int_literal.value;
-                column->insert_data(reinterpret_cast<const char *>(&value), 0);
-                break;
-            }
-            case TPrimitiveType::SMALLINT: {
-                int16_t value = t_expr.int_literal.value;
-                column->insert_data(reinterpret_cast<const char *>(&value), 0);
-                break;
-            }
-            case TPrimitiveType::INT: {
-                int32_t value = t_expr.int_literal.value;
-                column->insert_data(reinterpret_cast<const char *>(&value), 0);
-                break;
-            }
-            default:
-                int64_t value = t_expr.int_literal.value;
-                column->insert_data(reinterpret_cast<const char *>(&value), 0);
+        case TPrimitiveType::TINYINT: {
+            int8_t value = t_expr.int_literal.value;
+            column->insert_data(reinterpret_cast<const char*>(&value), 0);
+            break;
+        }
+        case TPrimitiveType::SMALLINT: {
+            int16_t value = t_expr.int_literal.value;
+            column->insert_data(reinterpret_cast<const char*>(&value), 0);
+            break;
+        }
+        case TPrimitiveType::INT: {
+            int32_t value = t_expr.int_literal.value;
+            column->insert_data(reinterpret_cast<const char*>(&value), 0);
+            break;
+        }
+        default:
+            int64_t value = t_expr.int_literal.value;
+            column->insert_data(reinterpret_cast<const char*>(&value), 0);
         }
         break;
-    } case TExprNodeType::LARGE_INT_LITERAL: {
+    }
+    case TExprNodeType::LARGE_INT_LITERAL: {
         StringParser::ParseResult parse_result = StringParser::PARSE_SUCCESS;
-        __int128 value = StringParser::string_to_int<__int128>(t_expr.large_int_literal.value.c_str(),
-                                                             t_expr.large_int_literal.value.size(),
-                                                             &parse_result);
+        __int128 value = StringParser::string_to_int<__int128>(
+                t_expr.large_int_literal.value.c_str(), t_expr.large_int_literal.value.size(),
+                &parse_result);
         if (parse_result != StringParser::PARSE_SUCCESS) {
             value = MAX_INT128;
         }
-        column->insert_data(reinterpret_cast<const char *>(&value), 0);
+        column->insert_data(reinterpret_cast<const char*>(&value), 0);
         break;
-    } case TExprNodeType::STRING_LITERAL: {
+    }
+    case TExprNodeType::STRING_LITERAL: {
         int len = t_expr.string_literal.value.size();
         const char* str_val = t_expr.string_literal.value.c_str();
         column->insert_data(str_val, len);
         break;
-    } case TExprNodeType::BOOL_LITERAL: {
-        column->insert_data(reinterpret_cast<const char *>(&t_expr.bool_literal.value), 0);
+    }
+    case TExprNodeType::BOOL_LITERAL: {
+        column->insert_data(reinterpret_cast<const char*>(&t_expr.bool_literal.value), 0);
         break;
-    } default: {
-        std::stringstream ss;
-        ss << "unsupported partition column node type, type=" << t_expr.node_type;
-        return Status::InternalError(ss.str());
+    }
+    default: {
+        return Status::InternalError("unsupported partition column node type, type={}",
+                                     t_expr.node_type);
     }
     }
     part_key->second = column->size() - 1;
