@@ -14,6 +14,9 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exprs/cast-functions.cpp
+// and modified by Doris
 
 #include "exprs/cast_functions.h"
 
@@ -24,10 +27,11 @@
 #include "exprs/anyval_util.h"
 #include "gutil/strings/numbers.h"
 #include "runtime/datetime_value.h"
-#include "runtime/string_value.h"
-#include "string_functions.h"
+#include "runtime/large_int_value.h"
+#include "util/array_parser.h"
 #include "util/mysql_global.h"
 #include "util/string_parser.hpp"
+#include "vec/runtime/vdatetime_value.h"
 
 namespace doris {
 
@@ -179,15 +183,15 @@ int float_to_string<double>(double value, char* buf) {
             return sv;                                                                         \
         }                                                                                      \
         const FunctionContext::TypeDesc& returnType = ctx->get_return_type();                  \
-        if (returnType.len == -1 || returnType.type == FunctionContext::TYPE_STRING) {         \
-            char buf[MAX_DOUBLE_STR_LENGTH + 2];                                               \
-            sv.len = float_to_string(val.val, buf);                                            \
-            memcpy(sv.ptr, buf, sv.len);                                                       \
-        } else if (returnType.len > 0) {                                                       \
+        if (returnType.len > 0) {                                                              \
             sv.len = snprintf(reinterpret_cast<char*>(sv.ptr), sv.len, format, val.val);       \
             DCHECK_GT(sv.len, 0);                                                              \
             DCHECK_LE(sv.len, MAX_FLOAT_CHARS);                                                \
             AnyValUtil::TruncateIfNecessary(returnType, &sv);                                  \
+        } else if (returnType.len == -1) {                                                     \
+            char buf[MAX_DOUBLE_STR_LENGTH + 2];                                               \
+            sv.len = float_to_string(val.val, buf);                                            \
+            memcpy(sv.ptr, buf, sv.len);                                                       \
         } else {                                                                               \
             DCHECK(false);                                                                     \
         }                                                                                      \
@@ -357,4 +361,212 @@ DateTimeVal CastFunctions::cast_to_date_val(FunctionContext* ctx, const StringVa
     return result;
 }
 
+DateTimeVal CastFunctions::cast_to_date_val(FunctionContext* ctx, const DateV2Val& val) {
+    if (val.is_null) {
+        return DateTimeVal::null();
+    }
+    vectorized::DateV2Value<doris::vectorized::DateV2ValueType> datev2_val =
+            vectorized::DateV2Value<doris::vectorized::DateV2ValueType>::from_datev2_val(val);
+    DateTimeValue datetime_value;
+    datetime_value.convert_from_date_v2<doris::vectorized::DateV2ValueType>(&datev2_val);
+    DateTimeVal result;
+    datetime_value.to_datetime_val(&result);
+    return result;
+}
+
+DateTimeVal CastFunctions::cast_to_date_val(FunctionContext* ctx, const DateTimeV2Val& val) {
+    if (val.is_null) {
+        return DateTimeVal::null();
+    }
+    vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> datev2_val =
+            vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType>::from_datetimev2_val(
+                    val);
+    DateTimeValue datetime_value;
+    datetime_value.convert_from_date_v2<doris::vectorized::DateTimeV2ValueType>(&datev2_val);
+    DateTimeVal result;
+    datetime_value.to_datetime_val(&result);
+    return result;
+}
+
+DateTimeVal CastFunctions::cast_to_datetime_val(FunctionContext* ctx, const DateV2Val& val) {
+    if (val.is_null) {
+        return DateTimeVal::null();
+    }
+    vectorized::DateV2Value<doris::vectorized::DateV2ValueType> datev2_val =
+            vectorized::DateV2Value<doris::vectorized::DateV2ValueType>::from_datev2_val(val);
+    DateTimeValue datetime_value;
+    datetime_value.convert_from_date_v2<doris::vectorized::DateV2ValueType>(&datev2_val);
+    datetime_value.set_type(TYPE_DATETIME);
+    DateTimeVal result;
+    datetime_value.to_datetime_val(&result);
+    return result;
+}
+
+DateTimeVal CastFunctions::cast_to_datetime_val(FunctionContext* ctx, const DateTimeV2Val& val) {
+    if (val.is_null) {
+        return DateTimeVal::null();
+    }
+    vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> datev2_val =
+            vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType>::from_datetimev2_val(
+                    val);
+    DateTimeValue datetime_value;
+    datetime_value.convert_from_date_v2<doris::vectorized::DateTimeV2ValueType>(&datev2_val);
+    datetime_value.set_type(TYPE_DATETIME);
+    DateTimeVal result;
+    datetime_value.to_datetime_val(&result);
+    return result;
+}
+
+#define CAST_TO_DATEV2(from_type)                                                             \
+    DateV2Val CastFunctions::cast_to_datev2_val(FunctionContext* ctx, const from_type& val) { \
+        if (val.is_null) return DateV2Val::null();                                            \
+        doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType> date_value;        \
+        if (!date_value.from_date_int64(val.val)) return DateV2Val::null();                   \
+        DateV2Val result;                                                                     \
+        date_value.to_datev2_val(&result);                                                    \
+        return result;                                                                        \
+    }
+
+#define CAST_NUMERIC_TYPES_TO_DATEV2() \
+    CAST_TO_DATEV2(TinyIntVal);        \
+    CAST_TO_DATEV2(SmallIntVal);       \
+    CAST_TO_DATEV2(IntVal);            \
+    CAST_TO_DATEV2(BigIntVal);         \
+    CAST_TO_DATEV2(LargeIntVal);       \
+    CAST_TO_DATEV2(FloatVal);          \
+    CAST_TO_DATEV2(DoubleVal);
+
+CAST_NUMERIC_TYPES_TO_DATEV2();
+
+#define CAST_TO_DATETIMEV2(from_type)                                                      \
+    DateTimeV2Val CastFunctions::cast_to_datetimev2_val(FunctionContext* ctx,              \
+                                                        const from_type& val) {            \
+        if (val.is_null) return DateTimeV2Val::null();                                     \
+        doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> date_value; \
+        if (!date_value.from_date_int64(val.val)) return DateTimeV2Val::null();            \
+        DateTimeV2Val result;                                                              \
+        date_value.to_datetimev2_val(&result);                                             \
+        return result;                                                                     \
+    }
+
+#define CAST_NUMERIC_TYPES_TO_DATETIMEV2() \
+    CAST_TO_DATETIMEV2(TinyIntVal);        \
+    CAST_TO_DATETIMEV2(SmallIntVal);       \
+    CAST_TO_DATETIMEV2(IntVal);            \
+    CAST_TO_DATETIMEV2(BigIntVal);         \
+    CAST_TO_DATETIMEV2(LargeIntVal);       \
+    CAST_TO_DATETIMEV2(FloatVal);          \
+    CAST_TO_DATETIMEV2(DoubleVal);
+
+CAST_NUMERIC_TYPES_TO_DATETIMEV2();
+
+DateV2Val CastFunctions::cast_to_datev2_val(FunctionContext* ctx, const DateV2Val& val) {
+    if (val.is_null) {
+        return DateV2Val::null();
+    }
+    return val;
+}
+
+DateV2Val CastFunctions::cast_to_datev2_val(FunctionContext* ctx, const StringVal& val) {
+    if (val.is_null) {
+        return DateV2Val::null();
+    }
+    doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType> date_value;
+    if (!date_value.from_date_str((char*)val.ptr, val.len)) {
+        return DateV2Val::null();
+    }
+    // Return null if 'val' did not parse
+    DateV2Val result;
+    date_value.to_datev2_val(&result);
+    return result;
+}
+
+DateV2Val CastFunctions::cast_to_datev2_val(FunctionContext* ctx, const DateTimeVal& val) {
+    if (val.is_null) {
+        return DateV2Val::null();
+    }
+    vectorized::VecDateTimeValue date_value = vectorized::VecDateTimeValue::from_datetime_val(val);
+
+    doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType> datev2_val;
+    datev2_val.from_date(date_value.to_date_v2());
+    DateV2Val result;
+    datev2_val.to_datev2_val(&result);
+    return result;
+}
+
+DateV2Val CastFunctions::cast_to_datev2_val(FunctionContext* ctx, const DateTimeV2Val& val) {
+    if (val.is_null) {
+        return DateV2Val::null();
+    }
+    doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> datetime_value =
+            vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType>::from_datetimev2_val(
+                    val);
+
+    doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType> datev2_val;
+    datev2_val.set_date_uint32(datetime_value.to_date_int_val() >>
+                               doris::vectorized::TIME_PART_LENGTH);
+    DateV2Val result;
+    datev2_val.to_datev2_val(&result);
+    return result;
+}
+
+DateTimeV2Val CastFunctions::cast_to_datetimev2_val(FunctionContext* ctx,
+                                                    const DateTimeV2Val& val) {
+    if (val.is_null) {
+        return DateTimeV2Val::null();
+    }
+    return val;
+}
+
+DateTimeV2Val CastFunctions::cast_to_datetimev2_val(FunctionContext* ctx, const StringVal& val) {
+    if (val.is_null) {
+        return DateTimeV2Val::null();
+    }
+    doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> date_value;
+    if (!date_value.from_date_str((char*)val.ptr, val.len)) {
+        return DateTimeV2Val::null();
+    }
+    // Return null if 'val' did not parse
+    DateTimeV2Val result;
+    date_value.to_datetimev2_val(&result);
+    return result;
+}
+
+DateTimeV2Val CastFunctions::cast_to_datetimev2_val(FunctionContext* ctx, const DateTimeVal& val) {
+    if (val.is_null) {
+        return DateTimeV2Val::null();
+    }
+    vectorized::VecDateTimeValue date_value = vectorized::VecDateTimeValue::from_datetime_val(val);
+
+    doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> datev2_val;
+    datev2_val.from_date(date_value.to_datetime_v2());
+    DateTimeV2Val result;
+    datev2_val.to_datetimev2_val(&result);
+    return result;
+}
+
+DateTimeV2Val CastFunctions::cast_to_datetimev2_val(FunctionContext* ctx, const DateV2Val& val) {
+    if (val.is_null) {
+        return DateTimeV2Val::null();
+    }
+    doris::vectorized::DateV2Value<doris::vectorized::DateV2ValueType> date_value =
+            vectorized::DateV2Value<doris::vectorized::DateV2ValueType>::from_datev2_val(val);
+
+    doris::vectorized::DateV2Value<doris::vectorized::DateTimeV2ValueType> datetimev2_val;
+    datetimev2_val.set_datetime_uint64((uint64_t)date_value.to_date_int_val()
+                                       << doris::vectorized::TIME_PART_LENGTH);
+    DateTimeV2Val result;
+    datetimev2_val.to_datetimev2_val(&result);
+    return result;
+}
+
+CollectionVal CastFunctions::cast_to_array_val(FunctionContext* context, const StringVal& val) {
+    if (val.is_null) {
+        return CollectionVal::null();
+    }
+    CollectionVal array_val;
+    Status status = ArrayParser::parse(array_val, context, val);
+    return status.ok() ? array_val : CollectionVal::null();
+}
+
 } // namespace doris
