@@ -14,12 +14,16 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exprs/expr.cpp
+// and modified by Doris
 
 #include "exprs/expr.h"
 
 #include <thrift/protocol/TDebugProtocol.h>
 
 #include <sstream>
+#include <stack>
 #include <vector>
 
 #include "common/object_pool.h"
@@ -35,20 +39,16 @@
 #include "exprs/expr_context.h"
 #include "exprs/in_predicate.h"
 #include "exprs/info_func.h"
-#include "exprs/is_null_predicate.h"
 #include "exprs/literal.h"
 #include "exprs/null_literal.h"
 #include "exprs/rpc_fn_call.h"
 #include "exprs/scalar_fn_call.h"
 #include "exprs/slot_ref.h"
 #include "exprs/tuple_is_null_predicate.h"
-#include "gen_cpp/Data_types.h"
 #include "gen_cpp/Exprs_types.h"
-#include "gen_cpp/PaloService_types.h"
-#include "runtime/raw_value.h"
+#include "runtime/primitive_type.h"
 #include "runtime/runtime_state.h"
 #include "runtime/user_function_cache.h"
-#include "util/debug_util.h"
 
 using std::vector;
 namespace doris {
@@ -91,8 +91,7 @@ Expr::Expr(const Expr& expr)
           _output_column(expr._output_column),
           _fn(expr._fn),
           _fn_context_index(expr._fn_context_index),
-          _constant_val(expr._constant_val),
-          _vector_compute_fn(expr._vector_compute_fn) {}
+          _constant_val(expr._constant_val) {}
 
 Expr::Expr(const TypeDescriptor& type)
         : _opcode(TExprOpcode::INVALID_OPCODE),
@@ -125,6 +124,7 @@ Expr::Expr(const TypeDescriptor& type)
     case TYPE_FLOAT:
     case TYPE_DOUBLE:
     case TYPE_TIME:
+    case TYPE_TIMEV2:
         _node_type = (TExprNodeType::FLOAT_LITERAL);
         break;
 
@@ -134,6 +134,8 @@ Expr::Expr(const TypeDescriptor& type)
 
     case TYPE_DATE:
     case TYPE_DATETIME:
+    case TYPE_DATEV2:
+    case TYPE_DATETIMEV2:
         _node_type = (TExprNodeType::DATE_LITERAL);
         break;
 
@@ -142,6 +144,7 @@ Expr::Expr(const TypeDescriptor& type)
     case TYPE_HLL:
     case TYPE_OBJECT:
     case TYPE_STRING:
+    case TYPE_QUANTILE_STATE:
         _node_type = (TExprNodeType::STRING_LITERAL);
         break;
 
@@ -184,6 +187,7 @@ Expr::Expr(const TypeDescriptor& type, bool is_slotref)
         case TYPE_FLOAT:
         case TYPE_DOUBLE:
         case TYPE_TIME:
+        case TYPE_TIMEV2:
             _node_type = (TExprNodeType::FLOAT_LITERAL);
             break;
 
@@ -192,6 +196,8 @@ Expr::Expr(const TypeDescriptor& type, bool is_slotref)
             break;
 
         case TYPE_DATETIME:
+        case TYPE_DATEV2:
+        case TYPE_DATETIMEV2:
             _node_type = (TExprNodeType::DATE_LITERAL);
             break;
 
@@ -199,6 +205,7 @@ Expr::Expr(const TypeDescriptor& type, bool is_slotref)
         case TYPE_VARCHAR:
         case TYPE_HLL:
         case TYPE_OBJECT:
+        case TYPE_QUANTILE_STATE:
         case TYPE_STRING:
             _node_type = (TExprNodeType::STRING_LITERAL);
             break;
@@ -249,14 +256,14 @@ Status Expr::create_expr_tree(ObjectPool* pool, const TExpr& texpr, ExprContext*
     }
     int node_idx = 0;
     Expr* e = nullptr;
-    Status status = create_tree_from_thrift(pool, texpr.nodes, nullptr, &node_idx, &e, ctx);
+    Status status = create_tree_from_thrift(pool, texpr.nodes, &node_idx, &e, ctx);
     if (status.ok() && node_idx + 1 != texpr.nodes.size()) {
         status = Status::InternalError(
                 "Expression tree only partially reconstructed. Not all thrift nodes were used.");
     }
     if (!status.ok()) {
         LOG(ERROR) << "Could not construct expr tree.\n"
-                   << status.get_error_msg() << "\n"
+                   << status << "\n"
                    << apache::thrift::ThriftDebugString(texpr);
     }
     return status;
@@ -274,33 +281,51 @@ Status Expr::create_expr_trees(ObjectPool* pool, const std::vector<TExpr>& texpr
 }
 
 Status Expr::create_tree_from_thrift(ObjectPool* pool, const std::vector<TExprNode>& nodes,
-                                     Expr* parent, int* node_idx, Expr** root_expr,
-                                     ExprContext** ctx) {
+                                     int* node_idx, Expr** root_expr, ExprContext** ctx) {
     // propagate error case
     if (*node_idx >= nodes.size()) {
         return Status::InternalError("Failed to reconstruct expression tree from thrift.");
     }
-    int num_children = nodes[*node_idx].num_children;
-    Expr* expr = nullptr;
-    RETURN_IF_ERROR(create_expr(pool, nodes[*node_idx], &expr));
-    DCHECK(expr != nullptr);
-    if (parent != nullptr) {
-        parent->add_child(expr);
-    } else {
-        DCHECK(root_expr != nullptr);
-        DCHECK(ctx != nullptr);
-        *root_expr = expr;
-        *ctx = pool->add(new ExprContext(expr));
+
+    // create root expr
+    int root_children = nodes[*node_idx].num_children;
+    Expr* root = nullptr;
+    RETURN_IF_ERROR(create_expr(pool, nodes[*node_idx], &root));
+    DCHECK(root != nullptr);
+
+    DCHECK(root_expr != nullptr);
+    DCHECK(ctx != nullptr);
+    *root_expr = root;
+    *ctx = pool->add(new ExprContext(root));
+    // short path for leaf node
+    if (root_children <= 0) {
+        return Status::OK();
     }
-    for (int i = 0; i < num_children; i++) {
-        *node_idx += 1;
-        RETURN_IF_ERROR(create_tree_from_thrift(pool, nodes, expr, node_idx, nullptr, nullptr));
-        // we are expecting a child, but have used all nodes
-        // this means we have been given a bad tree and must fail
-        if (*node_idx >= nodes.size()) {
+
+    // non-recursive traversal
+    std::stack<std::pair<Expr*, int>> s;
+    s.push({root, root_children});
+    while (!s.empty()) {
+        auto& parent = s.top();
+        if (parent.second > 1) {
+            parent.second -= 1;
+        } else {
+            s.pop();
+        }
+        if (++*node_idx >= nodes.size()) {
             return Status::InternalError("Failed to reconstruct expression tree from thrift.");
         }
+
+        Expr* expr = nullptr;
+        RETURN_IF_ERROR(create_expr(pool, nodes[*node_idx], &expr));
+        DCHECK(expr != nullptr);
+        parent.first->add_child(expr);
+        int num_children = nodes[*node_idx].num_children;
+        if (num_children > 0) {
+            s.push({expr, num_children});
+        }
     }
+
     return Status::OK();
 }
 
@@ -349,12 +374,16 @@ Status Expr::create_expr(ObjectPool* pool, const TExprNode& texpr_node, Expr** e
         }
     case TExprNodeType::COMPUTE_FUNCTION_CALL:
     case TExprNodeType::FUNCTION_CALL:
-        DCHECK(texpr_node.__isset.fn);
+        if (!texpr_node.__isset.fn) {
+            // return error to prevent crash
+            return Status::InternalError("function is not set in thrift node");
+        }
         if (texpr_node.fn.name.function_name == "if") {
             *expr = pool->add(new IfExpr(texpr_node));
         } else if (texpr_node.fn.name.function_name == "nullif") {
             *expr = pool->add(new NullIfExpr(texpr_node));
-        } else if (texpr_node.fn.name.function_name == "ifnull") {
+        } else if (texpr_node.fn.name.function_name == "ifnull" ||
+                   texpr_node.fn.name.function_name == "nvl") {
             *expr = pool->add(new IfNullExpr(texpr_node));
         } else if (texpr_node.fn.name.function_name == "coalesce") {
             *expr = pool->add(new CoalesceExpr(texpr_node));
@@ -408,9 +437,7 @@ Status Expr::create_expr(ObjectPool* pool, const TExprNode& texpr_node, Expr** e
     }
 
     default:
-        std::stringstream os;
-        os << "Unknown expr node type: " << texpr_node.node_type;
-        return Status::InternalError(os.str());
+        return Status::InternalError("Unknown expr node type: {}", texpr_node.node_type);
     }
 }
 
@@ -467,8 +494,8 @@ int Expr::compute_results_layout(const std::vector<Expr*>& exprs, std::vector<in
     int current_alignment = data[0].byte_size;
     int byte_offset = 0;
 
-    offsets->resize(exprs.size());
     offsets->clear();
+    offsets->resize(exprs.size());
     *var_result_begin = -1;
 
     for (int i = 0; i < data.size(); ++i) {
@@ -507,18 +534,26 @@ int Expr::compute_results_layout(const std::vector<ExprContext*>& ctxs, std::vec
 }
 
 Status Expr::prepare(const std::vector<ExprContext*>& ctxs, RuntimeState* state,
-                     const RowDescriptor& row_desc, const std::shared_ptr<MemTracker>& tracker) {
+                     const RowDescriptor& row_desc) {
     for (int i = 0; i < ctxs.size(); ++i) {
-        RETURN_IF_ERROR(ctxs[i]->prepare(state, row_desc, tracker));
+        RETURN_IF_ERROR(ctxs[i]->prepare(state, row_desc));
     }
     return Status::OK();
 }
 
 Status Expr::prepare(RuntimeState* state, const RowDescriptor& row_desc, ExprContext* context) {
     DCHECK(_type.type != INVALID_TYPE);
+    ++context->_depth_num;
+    if (context->_depth_num > config::max_depth_of_expr_tree) {
+        return Status::InternalError(
+                fmt::format("The depth of the expression tree is too big, make it less than {}",
+                            config::max_depth_of_expr_tree));
+    }
     for (int i = 0; i < _children.size(); ++i) {
         RETURN_IF_ERROR(_children[i]->prepare(state, row_desc, context));
     }
+
+    --context->_depth_num;
     return Status::OK();
 }
 
@@ -679,7 +714,8 @@ doris_udf::AnyVal* Expr::get_const_val(ExprContext* context) {
         break;
     }
     case TYPE_DOUBLE:
-    case TYPE_TIME: {
+    case TYPE_TIME:
+    case TYPE_TIMEV2: {
         _constant_val.reset(new DoubleVal(get_double_val(context, nullptr)));
         break;
     }
@@ -687,6 +723,7 @@ doris_udf::AnyVal* Expr::get_const_val(ExprContext* context) {
     case TYPE_VARCHAR:
     case TYPE_HLL:
     case TYPE_OBJECT:
+    case TYPE_QUANTILE_STATE:
     case TYPE_STRING: {
         _constant_val.reset(new StringVal(get_string_val(context, nullptr)));
         break;
@@ -697,10 +734,32 @@ doris_udf::AnyVal* Expr::get_const_val(ExprContext* context) {
         break;
     }
 
+    case TYPE_DATEV2: {
+        _constant_val.reset(new DateV2Val(get_datev2_val(context, nullptr)));
+        break;
+    }
+
+    case TYPE_DATETIMEV2: {
+        _constant_val.reset(new DateTimeV2Val(get_datetimev2_val(context, nullptr)));
+        break;
+    }
+
     case TYPE_DECIMALV2: {
         _constant_val.reset(new DecimalV2Val(get_decimalv2_val(context, nullptr)));
         break;
     }
+    case TYPE_DECIMAL32: {
+        _constant_val.reset(new Decimal32Val(get_decimal32_val(context, nullptr)));
+        break;
+    }
+    case TYPE_DECIMAL64: {
+        _constant_val.reset(new Decimal64Val(get_decimal64_val(context, nullptr)));
+        break;
+    }
+    case TYPE_DECIMAL128I: {
+        _constant_val.reset(new Decimal128Val(get_decimal128_val(context, nullptr)));
+        break;
+    }
     case TYPE_NULL: {
         _constant_val.reset(new AnyVal(true));
         break;
@@ -760,6 +819,18 @@ LargeIntVal Expr::get_large_int_val(ExprContext* context, TupleRow* row) {
     return LargeIntVal::null(); // (*(int64_t*)get_value(row));
 }
 
+Decimal32Val Expr::get_decimal32_val(ExprContext* context, TupleRow* row) {
+    return Decimal32Val::null(); // (*(int32_t*)get_value(row));
+}
+
+Decimal64Val Expr::get_decimal64_val(ExprContext* context, TupleRow* row) {
+    return Decimal64Val::null();
+}
+
+Decimal128Val Expr::get_decimal128_val(ExprContext* context, TupleRow* row) {
+    return Decimal128Val::null();
+}
+
 FloatVal Expr::get_float_val(ExprContext* context, TupleRow* row) {
     return FloatVal::null(); // (*(float*)get_value(row));
 }
@@ -782,6 +853,16 @@ DateTimeVal Expr::get_datetime_val(ExprContext* context, TupleRow* row) {
     return val;
 }
 
+DateV2Val Expr::get_datev2_val(ExprContext* context, TupleRow* row) {
+    DateV2Val val;
+    return val;
+}
+
+DateTimeV2Val Expr::get_datetimev2_val(ExprContext* context, TupleRow* row) {
+    DateTimeV2Val val;
+    return val;
+}
+
 DecimalV2Val Expr::get_decimalv2_val(ExprContext* context, TupleRow* row) {
     DecimalV2Val val;
     return val;
@@ -822,10 +903,9 @@ void Expr::assign_fn_ctx_idx(int* next_fn_ctx_idx) {
 }
 
 Status Expr::create(const TExpr& texpr, const RowDescriptor& row_desc, RuntimeState* state,
-                    ObjectPool* pool, Expr** scalar_expr,
-                    const std::shared_ptr<MemTracker>& tracker) {
+                    ObjectPool* pool, Expr** scalar_expr) {
     *scalar_expr = nullptr;
-    Expr* root;
+    Expr* root = nullptr;
     RETURN_IF_ERROR(create_expr(pool, texpr.nodes[0], &root));
     RETURN_IF_ERROR(create_tree(texpr, pool, root));
     // TODO pengyubing replace by Init()
@@ -846,12 +926,11 @@ Status Expr::create(const TExpr& texpr, const RowDescriptor& row_desc, RuntimeSt
 }
 
 Status Expr::create(const std::vector<TExpr>& texprs, const RowDescriptor& row_desc,
-                    RuntimeState* state, ObjectPool* pool, std::vector<Expr*>* exprs,
-                    const std::shared_ptr<MemTracker>& tracker) {
+                    RuntimeState* state, ObjectPool* pool, std::vector<Expr*>* exprs) {
     exprs->clear();
     for (const TExpr& texpr : texprs) {
-        Expr* expr;
-        RETURN_IF_ERROR(create(texpr, row_desc, state, pool, &expr, tracker));
+        Expr* expr = nullptr;
+        RETURN_IF_ERROR(create(texpr, row_desc, state, pool, &expr));
         DCHECK(expr != nullptr);
         exprs->push_back(expr);
     }
@@ -859,14 +938,13 @@ Status Expr::create(const std::vector<TExpr>& texprs, const RowDescriptor& row_d
 }
 
 Status Expr::create(const TExpr& texpr, const RowDescriptor& row_desc, RuntimeState* state,
-                    Expr** scalar_expr, const std::shared_ptr<MemTracker>& tracker) {
-    return Expr::create(texpr, row_desc, state, state->obj_pool(), scalar_expr, tracker);
+                    Expr** scalar_expr) {
+    return Expr::create(texpr, row_desc, state, state->obj_pool(), scalar_expr);
 }
 
 Status Expr::create(const std::vector<TExpr>& texprs, const RowDescriptor& row_desc,
-                    RuntimeState* state, std::vector<Expr*>* exprs,
-                    const std::shared_ptr<MemTracker>& tracker) {
-    return Expr::create(texprs, row_desc, state, state->obj_pool(), exprs, tracker);
+                    RuntimeState* state, std::vector<Expr*>* exprs) {
+    return Expr::create(texprs, row_desc, state, state->obj_pool(), exprs);
 }
 
 Status Expr::create_tree(const TExpr& texpr, ObjectPool* pool, Expr* root) {
@@ -880,7 +958,7 @@ Status Expr::create_tree(const TExpr& texpr, ObjectPool* pool, Expr* root) {
         Status status = create_tree_internal(texpr.nodes, pool, root, &child_node_idx);
         if (UNLIKELY(!status.ok())) {
             LOG(ERROR) << "Could not construct expr tree.\n"
-                       << status.get_error_msg() << "\n"
+                       << status << "\n"
                        << apache::thrift::ThriftDebugString(texpr);
             return status;
         }
