@@ -14,9 +14,11 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exprs/is-null-predicate.h
+// and modified by Doris
 
-#ifndef DORIS_BE_SRC_QUERY_EXPRS_IS_NULL_PREDICATE_H
-#define DORIS_BE_SRC_QUERY_EXPRS_IS_NULL_PREDICATE_H
+#pragma once
 
 #include <string>
 
@@ -36,4 +38,3 @@ public:
 };
 
 } // namespace doris
-#endif
