@@ -14,6 +14,9 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exprs/like-predicate.cc
+// and modified by Doris
 
 #include "exprs/like_predicate.h"
 
@@ -22,7 +25,6 @@
 #include <sstream>
 
 #include "exprs/string_functions.h"
-#include "runtime/string_value.hpp"
 
 namespace doris {
 
