@@ -14,14 +14,15 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/exprs/timestamp-functions.h
+// and modified by Doris
 
-#ifndef DORIS_BE_SRC_QUERY_EXPRS_TIMESTAMP_FUNCTIONS_H
-#define DORIS_BE_SRC_QUERY_EXPRS_TIMESTAMP_FUNCTIONS_H
+#pragma once
 
 #include <thread>
 
 #include "runtime/datetime_value.h"
-#include "runtime/string_value.h"
 
 namespace doris {
 
@@ -152,6 +153,8 @@ public:
                                             const doris_udf::StringVal& format);
     static doris_udf::DateTimeVal from_days(doris_udf::FunctionContext* ctx,
                                             const doris_udf::IntVal& days);
+    static doris_udf::DateTimeVal last_day(doris_udf::FunctionContext* ctx,
+                                           const doris_udf::DateTimeVal& ts_val);
     static doris_udf::IntVal to_days(doris_udf::FunctionContext* ctx,
                                      const doris_udf::DateTimeVal& ts_val);
     static doris_udf::DateTimeVal str_to_date(doris_udf::FunctionContext* ctx,
@@ -439,5 +442,3 @@ public:
                                  doris_udf::FunctionContext::FunctionStateScope scope);
 };
 } // namespace doris
-
-#endif
