@@ -25,8 +25,7 @@
 // and Google friendly API.
 //
 
-#ifndef UTIL_GTL_STL_UTIL_H_
-#define UTIL_GTL_STL_UTIL_H_
+#pragma once
 
 #include <stddef.h>
 #include <string.h> // for memcpy
@@ -42,7 +41,6 @@ using std::swap;
 #include <deque>
 using std::deque;
 #include <functional>
-using std::binary_function;
 using std::less;
 #include <iterator>
 using std::back_insert_iterator;
@@ -434,9 +432,9 @@ private:
 template <class STLContainer>
 class TemplatedElementDeleter : public BaseDeleter {
 public:
-    explicit TemplatedElementDeleter<STLContainer>(STLContainer* ptr) : container_ptr_(ptr) {}
+    explicit TemplatedElementDeleter(STLContainer* ptr) : container_ptr_(ptr) {}
 
-    virtual ~TemplatedElementDeleter<STLContainer>() { STLDeleteElements(container_ptr_); }
+    virtual ~TemplatedElementDeleter() { STLDeleteElements(container_ptr_); }
 
 private:
     STLContainer* container_ptr_;
@@ -467,9 +465,9 @@ private:
 template <class STLContainer>
 class TemplatedValueDeleter : public BaseDeleter {
 public:
-    explicit TemplatedValueDeleter<STLContainer>(STLContainer* ptr) : container_ptr_(ptr) {}
+    explicit TemplatedValueDeleter(STLContainer* ptr) : container_ptr_(ptr) {}
 
-    virtual ~TemplatedValueDeleter<STLContainer>() { STLDeleteValues(container_ptr_); }
+    virtual ~TemplatedValueDeleter() { STLDeleteValues(container_ptr_); }
 
 private:
     STLContainer* container_ptr_;
@@ -503,8 +501,8 @@ private:
 template <class STLContainer>
 class STLElementDeleter {
 public:
-    STLElementDeleter<STLContainer>(STLContainer* ptr) : container_ptr_(ptr) {}
-    ~STLElementDeleter<STLContainer>() { STLDeleteElements(container_ptr_); }
+    STLElementDeleter(STLContainer* ptr) : container_ptr_(ptr) {}
+    ~STLElementDeleter() { STLDeleteElements(container_ptr_); }
 
 private:
     STLContainer* container_ptr_;
@@ -513,8 +511,8 @@ private:
 template <class STLContainer>
 class STLValueDeleter {
 public:
-    STLValueDeleter<STLContainer>(STLContainer* ptr) : container_ptr_(ptr) {}
-    ~STLValueDeleter<STLContainer>() { STLDeleteValues(container_ptr_); }
+    STLValueDeleter(STLContainer* ptr) : container_ptr_(ptr) {}
+    ~STLValueDeleter() { STLDeleteValues(container_ptr_); }
 
 private:
     STLContainer* container_ptr_;
@@ -642,7 +640,7 @@ bool STLIncludes(const SortedSTLContainerA& a, const SortedSTLContainerB& b) {
 // the contents of an STL map. For other sample usage, see the unittest.
 
 template <typename Pair, typename UnaryOp>
-class UnaryOperateOnFirst : public std::unary_function<Pair, typename UnaryOp::result_type> {
+class UnaryOperateOnFirst {
 public:
     UnaryOperateOnFirst() {}
 
@@ -661,7 +659,7 @@ UnaryOperateOnFirst<Pair, UnaryOp> UnaryOperate1st(const UnaryOp& f) {
 }
 
 template <typename Pair, typename UnaryOp>
-class UnaryOperateOnSecond : public std::unary_function<Pair, typename UnaryOp::result_type> {
+class UnaryOperateOnSecond {
 public:
     UnaryOperateOnSecond() {}
 
@@ -680,8 +678,7 @@ UnaryOperateOnSecond<Pair, UnaryOp> UnaryOperate2nd(const UnaryOp& f) {
 }
 
 template <typename Pair, typename BinaryOp>
-class BinaryOperateOnFirst
-        : public std::binary_function<Pair, Pair, typename BinaryOp::result_type> {
+class BinaryOperateOnFirst {
 public:
     BinaryOperateOnFirst() {}
 
@@ -703,8 +700,7 @@ BinaryOperateOnFirst<Pair, BinaryOp> BinaryOperate1st(const BinaryOp& f) {
 }
 
 template <typename Pair, typename BinaryOp>
-class BinaryOperateOnSecond
-        : public std::binary_function<Pair, Pair, typename BinaryOp::result_type> {
+class BinaryOperateOnSecond {
 public:
     BinaryOperateOnSecond() {}
 
@@ -737,9 +733,7 @@ BinaryOperateOnSecond<Pair, BinaryOp> BinaryOperate2nd(const BinaryOp& f) {
 // F has to be a model of AdaptableBinaryFunction.
 // G1 and G2 have to be models of AdabtableUnaryFunction.
 template <typename F, typename G1, typename G2>
-class BinaryComposeBinary
-        : public binary_function<typename G1::argument_type, typename G2::argument_type,
-                                 typename F::result_type> {
+class BinaryComposeBinary {
 public:
     BinaryComposeBinary(F f, G1 g1, G2 g2) : f_(f), g1_(g1), g2_(g2) {}
 
@@ -764,49 +758,6 @@ BinaryComposeBinary<F, G1, G2> BinaryCompose2(F f, G1 g1, G2 g2) {
     return BinaryComposeBinary<F, G1, G2>(f, g1, g2);
 }
 
-// This is a wrapper for an STL allocator which keeps a count of the
-// active bytes allocated by this class of allocators.  This is NOT
-// THREAD SAFE.  This should only be used in situations where you can
-// ensure that only a single thread performs allocation and
-// deallocation.
-template <typename T, typename Alloc = std::allocator<T>>
-class STLCountingAllocator : public Alloc {
-public:
-    typedef typename Alloc::pointer pointer;
-    typedef typename Alloc::size_type size_type;
-
-    STLCountingAllocator() : bytes_used_(NULL) {}
-    STLCountingAllocator(int64* b) : bytes_used_(b) {} // TODO(user): explicit?
-
-    // Constructor used for rebinding
-    template <class U>
-    STLCountingAllocator(const STLCountingAllocator<U>& x)
-            : Alloc(x), bytes_used_(x.bytes_used()) {}
-
-    pointer allocate(size_type n, std::allocator<void>::const_pointer hint = 0) {
-        assert(bytes_used_ != NULL);
-        *bytes_used_ += n * sizeof(T);
-        return Alloc::allocate(n, hint);
-    }
-
-    void deallocate(pointer p, size_type n) {
-        Alloc::deallocate(p, n);
-        assert(bytes_used_ != NULL);
-        *bytes_used_ -= n * sizeof(T);
-    }
-
-    // Rebind allows an allocator<T> to be used for a different type
-    template <class U>
-    struct rebind {
-        typedef STLCountingAllocator<U, typename Alloc::template rebind<U>::other> other;
-    };
-
-    int64* bytes_used() const { return bytes_used_; }
-
-private:
-    int64* bytes_used_;
-};
-
 // Even though a struct has no data members, it cannot have zero size
 // according to the standard.  However, "empty base-class
 // optimization" allows an empty parent class to add no additional
@@ -899,5 +850,3 @@ T* release_ptr(T** ptr) {
     *ptr = NULL;
     return tmp;
 }
-
-#endif // UTIL_GTL_STL_UTIL_H_
