@@ -3,8 +3,7 @@
 //
 // Convert strings to numbers or numbers to strings.
 
-#ifndef STRINGS_NUMBERS_H_
-#define STRINGS_NUMBERS_H_
+#pragma once
 
 #include <stddef.h>
 #include <stdlib.h>
@@ -12,7 +11,6 @@
 #include <time.h>
 
 #include <functional>
-using std::binary_function;
 using std::less;
 #include <limits>
 using std::numeric_limits;
@@ -32,7 +30,7 @@ using std::vector;
  * @{ */
 
 // Convert a fingerprint to 16 hex digits.
-string FpToString(Fprint fp);
+string Uint64ToString(uint64 fp);
 
 // Formats a uint128 as a 32-digit hex string.
 string Uint128ToHexString(uint128 ui128);
@@ -330,25 +328,25 @@ bool AutoDigitLessThan(const char* a, int alen, const char* b, int blen);
 
 bool StrictAutoDigitLessThan(const char* a, int alen, const char* b, int blen);
 
-struct autodigit_less : public binary_function<const string&, const string&, bool> {
+struct autodigit_less {
     bool operator()(const string& a, const string& b) const {
         return AutoDigitLessThan(a.data(), a.size(), b.data(), b.size());
     }
 };
 
-struct autodigit_greater : public binary_function<const string&, const string&, bool> {
+struct autodigit_greater {
     bool operator()(const string& a, const string& b) const {
         return AutoDigitLessThan(b.data(), b.size(), a.data(), a.size());
     }
 };
 
-struct strict_autodigit_less : public binary_function<const string&, const string&, bool> {
+struct strict_autodigit_less {
     bool operator()(const string& a, const string& b) const {
         return StrictAutoDigitLessThan(a.data(), a.size(), b.data(), b.size());
     }
 };
 
-struct strict_autodigit_greater : public binary_function<const string&, const string&, bool> {
+struct strict_autodigit_greater {
     bool operator()(const string& a, const string& b) const {
         return StrictAutoDigitLessThan(b.data(), b.size(), a.data(), a.size());
     }
@@ -571,5 +569,3 @@ bool ParseDoubleRange(const char* text, int len, const char** end, double* from,
 // inline string UInt64ToString(uint64 ui64) {
 //   return StringPrintf("%7" PRIu64, ui64);
 // }
-
-#endif // STRINGS_NUMBERS_H_
