@@ -28,10 +28,10 @@
 #include "env/env.h"
 #include "gen_cpp/Types_types.h"
 #include "gen_cpp/olap_file.pb.h"
+#include "io/fs/file_system.h"
 #include "olap/olap_common.h"
 #include "olap/rowset/rowset_id_generator.h"
 #include "util/metrics.h"
-#include "util/mutex.h"
 
 namespace doris {
 
@@ -40,27 +40,23 @@ class TabletManager;
 class TabletMeta;
 class TxnManager;
 
-struct PublishStatistic {
-    size_t get_lock_time = 0;
-    size_t save_meta_time = 0;
-};
-
 // A DataDir used to manage data in same path.
 // Now, After DataDir was created, it will never be deleted for easy implementation.
 class DataDir {
 public:
     DataDir(const std::string& path, int64_t capacity_bytes = -1,
             TStorageMedium::type storage_medium = TStorageMedium::HDD,
-            const std::string& remote_path = "",
             TabletManager* tablet_manager = nullptr, TxnManager* txn_manager = nullptr);
     ~DataDir();
 
     Status init();
     void stop_bg_worker();
 
-    const std::string& path() const { return _path_desc.filepath; }
-    const FilePathDesc& path_desc() const { return _path_desc;}
+    const std::string& path() const { return _path; }
     size_t path_hash() const { return _path_hash; }
+
+    const io::FileSystemSPtr& fs() const { return _fs; }
+
     bool is_used() const { return _is_used; }
     void set_is_used(bool is_used) { _is_used = is_used; }
     int32_t cluster_id() const { return _cluster_id; }
@@ -68,7 +64,7 @@ public:
 
     DataDirInfo get_dir_info() {
         DataDirInfo info;
-        info.path_desc = _path_desc;
+        info.path = _path;
         info.path_hash = _path_hash;
         info.disk_capacity = _disk_capacity_bytes;
         info.available = _available_bytes;
@@ -83,13 +79,13 @@ public:
     Status set_cluster_id(int32_t cluster_id);
     void health_check();
 
-    OLAPStatus get_shard(uint64_t* shard);
+    Status get_shard(uint64_t* shard);
 
     OlapMeta* get_meta() { return _meta; }
 
     bool is_ssd_disk() const { return _storage_medium == TStorageMedium::SSD; }
 
-    bool is_remote() const { return _env->is_remote_env(); }
+    bool is_remote() const { return FilePathDesc::is_remote(_storage_medium); }
 
     TStorageMedium::type storage_medium() const { return _storage_medium; }
 
@@ -106,7 +102,7 @@ public:
             const std::string& schema_hash_dir_in_trash);
 
     // load data from meta and data files
-    OLAPStatus load();
+    Status load();
 
     void add_pending_ids(const std::string& id);
 
@@ -120,6 +116,10 @@ public:
 
     void perform_path_gc_by_tablet();
 
+    void perform_remote_rowset_gc();
+
+    void perform_remote_tablet_gc();
+
     // check if the capacity reach the limit after adding the incoming data
     // return true if limit reached, otherwise, return false.
     // TODO(cmy): for now we can not precisely calculate the capacity Doris used,
@@ -130,7 +130,9 @@ public:
 
     Status update_capacity();
 
-    void update_user_data_size(int64_t size);
+    void update_local_data_size(int64_t size);
+
+    void update_remote_data_size(int64_t size);
 
     size_t tablet_size() const;
 
@@ -138,9 +140,8 @@ public:
 
     void disks_compaction_num_increment(int64_t delta);
 
-    Env* env() {
-        return _env;
-    }
+    // Move tablet to trash.
+    Status move_to_trash(const std::string& tablet_path);
 
 private:
     Status _init_cluster_id();
@@ -148,13 +149,13 @@ private:
     Status _init_meta();
 
     Status _check_disk();
-    OLAPStatus _read_and_write_test_file();
+    Status _read_and_write_test_file();
     Status read_cluster_id(Env* env, const std::string& cluster_id_path, int32_t* cluster_id);
-    Status _write_cluster_id_to_path(const FilePathDesc& path_desc, int32_t cluster_id);
+    Status _write_cluster_id_to_path(const std::string& path, int32_t cluster_id);
     // Check whether has old format (hdr_ start) in olap. When doris updating to current version,
     // it may lead to data missing. When conf::storage_strict_check_incompatible_old_format is true,
     // process will log fatal.
-    OLAPStatus _check_incompatible_old_format_tablet();
+    Status _check_incompatible_old_format_tablet();
 
     void _process_garbage_path(const std::string& path);
 
@@ -163,10 +164,12 @@ private:
     bool _check_pending_ids(const std::string& id);
 
 private:
-    bool _stop_bg_worker = false;
+    std::atomic<bool> _stop_bg_worker = false;
 
-    FilePathDesc _path_desc;
+    std::string _path;
     size_t _path_hash;
+
+    io::FileSystemSPtr _fs;
     // user specified capacity
     int64_t _capacity_bytes;
     // the actual available capacity of the disk of this data dir
@@ -177,7 +180,6 @@ private:
     int64_t _disk_capacity_bytes;
     TStorageMedium::type _storage_medium;
     bool _is_used;
-    Env* _env = nullptr;
 
     TabletManager* _tablet_manager;
     TxnManager* _txn_manager;
@@ -207,7 +209,8 @@ private:
     std::shared_ptr<MetricEntity> _data_dir_metric_entity;
     IntGauge* disks_total_capacity;
     IntGauge* disks_avail_capacity;
-    IntGauge* disks_data_used_capacity;
+    IntGauge* disks_local_used_capacity;
+    IntGauge* disks_remote_used_capacity;
     IntGauge* disks_state;
     IntGauge* disks_compaction_score;
     IntGauge* disks_compaction_num;
