@@ -294,6 +294,8 @@ struct OlapReaderStatistics {
     int64_t block_init_ns = 0;
     int64_t block_init_seek_num = 0;
     int64_t block_init_seek_ns = 0;
+    int64_t block_init_get_row_range_by_keys_ns = 0;
+    int64_t block_init_get_row_range_by_conditions_ns = 0;
     int64_t first_read_ns = 0;
     int64_t block_first_read_seek_num = 0;
     int64_t block_first_read_seek_ns = 0;
