@@ -84,8 +84,6 @@ public:
 
     int32_t get_atomic_num_segment() const override { return _num_segment.load(); }
 
-    uint64_t get_num_mow_keys() { return _num_mow_keys; }
-
 private:
     template <typename RowType>
     Status _add_row(const RowType& row);
@@ -168,13 +166,9 @@ protected:
         int64_t data_size;
         int64_t index_size;
         KeyBoundsPB key_bounds;
-        std::shared_ptr<std::unordered_set<std::string>> key_set;
     };
-    std::mutex _segid_statistics_map_mutex;
     std::map<uint32_t, Statistics> _segid_statistics_map;
-
-    // used for check correctness of unique key mow keys.
-    std::atomic<uint64_t> _num_mow_keys;
+    std::mutex _segid_statistics_map_mutex;
 
     bool _is_pending = false;
     bool _already_built = false;
