@@ -31,8 +31,8 @@ namespace doris {
 // add "Engine" as task prefix to prevent duplicate name with agent task
 class EngineTask {
 public:
-    virtual OLAPStatus execute() { return OLAP_SUCCESS; }
-    virtual OLAPStatus finish() { return OLAP_SUCCESS; }
+    virtual Status execute() { return Status::OK(); }
+    virtual Status finish() { return Status::OK(); }
 };
 
 } // end namespace doris
