@@ -15,8 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#ifndef DORIS_BE_RUNTIME_BUFFER_CONTROL_BLOCK_H
-#define DORIS_BE_RUNTIME_BUFFER_CONTROL_BLOCK_H
+#pragma once
 
 #include <condition_variable>
 #include <deque>
@@ -92,6 +91,8 @@ public:
         }
     }
 
+    // TODO: The value of query peak mem usage in fe.audit.log comes from a random BE,
+    // not the BE with the largest peak mem usage
     void update_max_peak_memory_bytes() {
         if (_query_statistics.get() != nullptr) {
             int64_t max_peak_memory_bytes = _query_statistics->calculate_max_peak_memory_bytes();
@@ -105,7 +106,7 @@ private:
     // result's query id
     TUniqueId _fragment_id;
     bool _is_close;
-    bool _is_cancelled;
+    std::atomic_bool _is_cancelled;
     Status _status;
     int _buffer_rows;
     int _buffer_limit;
@@ -129,5 +130,3 @@ private:
 };
 
 } // namespace doris
-
-#endif
