@@ -14,20 +14,21 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/runtime/buffered-block-mgr2.cc
+// and modified by Doris
 
 #include "runtime/buffered_block_mgr2.h"
 
 #include "exec/exec_node.h"
 #include "runtime/exec_env.h"
-#include "runtime/mem_pool.h"
-#include "runtime/mem_tracker.h"
+#include "runtime/memory/mem_tracker.h"
 #include "runtime/runtime_state.h"
 #include "runtime/tmp_file_mgr.h"
 #include "util/bit_util.h"
 #include "util/debug_util.h"
 #include "util/disk_info.h"
 #include "util/doris_metrics.h"
-#include "util/filesystem_util.h"
 #include "util/pretty_printer.h"
 #include "util/runtime_profile.h"
 #include "util/stack_util.h"
@@ -47,23 +48,20 @@ using std::shared_ptr;
 using std::unique_lock;
 
 namespace doris {
+using namespace ErrorCode;
 
 BufferedBlockMgr2::BlockMgrsMap BufferedBlockMgr2::_s_query_to_block_mgrs;
 SpinLock BufferedBlockMgr2::_s_block_mgrs_lock;
 
 class BufferedBlockMgr2::Client {
 public:
-    Client(BufferedBlockMgr2* mgr, int num_reserved_buffers,
-           const std::shared_ptr<MemTracker>& tracker, RuntimeState* state)
+    Client(BufferedBlockMgr2* mgr, int num_reserved_buffers, RuntimeState* state)
             : _mgr(mgr),
               _state(state),
-              _tracker(tracker),
-              _query_tracker(_mgr->_mem_tracker->parent()),
+              _tracker(std::make_unique<MemTracker>("BufferedBlockMgr2::Client")),
               _num_reserved_buffers(num_reserved_buffers),
               _num_tmp_reserved_buffers(0),
-              _num_pinned_buffers(0) {
-        DCHECK(tracker != nullptr);
-    }
+              _num_pinned_buffers(0) {}
 
     // A null dtor to pass codestyle check
     ~Client() {}
@@ -81,11 +79,7 @@ public:
     // enforced. Even when we give a buffer to a client, the buffer is still owned and
     // counts against the block mgr tracker (i.e. there is a fixed pool of buffers
     // regardless of if they are in the block mgr or the clients).
-    std::shared_ptr<MemTracker> _tracker;
-
-    // This is the common ancestor between the block mgr tracker and the client tracker.
-    // When memory is transferred to the client, we want it to stop at this tracker.
-    std::shared_ptr<MemTracker> _query_tracker;
+    std::unique_ptr<MemTracker> _tracker;
 
     // Number of buffers reserved by this client.
     int _num_reserved_buffers;
@@ -100,8 +94,7 @@ public:
         DCHECK(buffer != nullptr);
         if (buffer->len == _mgr->max_block_size()) {
             ++_num_pinned_buffers;
-            _tracker->ConsumeLocal(buffer->len, _query_tracker.get());
-            // _tracker->Consume(buffer->len);
+            _tracker->consume(buffer->len);
         }
     }
 
@@ -110,8 +103,7 @@ public:
         if (buffer->len == _mgr->max_block_size()) {
             DCHECK_GT(_num_pinned_buffers, 0);
             --_num_pinned_buffers;
-            _tracker->ReleaseLocal(buffer->len, _query_tracker.get());
-            // _tracker->Release(buffer->len);
+            _tracker->release(buffer->len);
         }
     }
 
@@ -221,11 +213,9 @@ BufferedBlockMgr2::BufferedBlockMgr2(RuntimeState* state, TmpFileMgr* tmp_file_m
           _writes_issued(0),
           _state(state) {}
 
-Status BufferedBlockMgr2::create(RuntimeState* state, const std::shared_ptr<MemTracker>& parent,
-                                 RuntimeProfile* profile, TmpFileMgr* tmp_file_mgr,
-                                 int64_t mem_limit, int64_t block_size,
+Status BufferedBlockMgr2::create(RuntimeState* state, RuntimeProfile* profile,
+                                 TmpFileMgr* tmp_file_mgr, int64_t block_size,
                                  std::shared_ptr<BufferedBlockMgr2>* block_mgr) {
-    DCHECK(parent != nullptr);
     block_mgr->reset();
     {
         // we do not use global BlockMgrsMap for now, to avoid mem-exceeded different fragments
@@ -247,7 +237,7 @@ Status BufferedBlockMgr2::create(RuntimeState* state, const std::shared_ptr<MemT
             // _s_query_to_block_mgrs[state->query_id()] = *block_mgr;
         }
     }
-    (*block_mgr)->init(state->exec_env()->disk_io_mgr(), profile, parent, mem_limit);
+    (*block_mgr)->init(state->exec_env()->disk_io_mgr(), profile);
     return Status::OK();
 }
 
@@ -261,16 +251,15 @@ int64_t BufferedBlockMgr2::available_buffers(Client* client) const {
 int64_t BufferedBlockMgr2::remaining_unreserved_buffers() const {
     int64_t num_buffers =
             _free_io_buffers.size() + _unpinned_blocks.size() + _non_local_outstanding_writes;
-    num_buffers += _mem_tracker->SpareCapacity(MemLimit::HARD) / max_block_size();
+    num_buffers += thread_context()->thread_mem_tracker()->spare_capacity() / max_block_size();
     num_buffers -= _unfullfilled_reserved_buffers;
     return num_buffers;
 }
 
-Status BufferedBlockMgr2::register_client(int num_reserved_buffers,
-                                          const std::shared_ptr<MemTracker>& tracker,
-                                          RuntimeState* state, Client** client) {
+Status BufferedBlockMgr2::register_client(int num_reserved_buffers, RuntimeState* state,
+                                          Client** client) {
     DCHECK_GE(num_reserved_buffers, 0);
-    Client* a_client = new Client(this, num_reserved_buffers, tracker, state);
+    Client* a_client = new Client(this, num_reserved_buffers, state);
     lock_guard<mutex> lock(_lock);
     *client = _obj_pool.add(a_client);
     _unfullfilled_reserved_buffers += num_reserved_buffers;
@@ -310,105 +299,6 @@ bool BufferedBlockMgr2::try_acquire_tmp_reservation(Client* client, int num_buff
     return true;
 }
 
-bool BufferedBlockMgr2::consume_memory(Client* client, int64_t size) {
-    // Later, we use this interface to manage the consumption of memory of hashtable instead of ReservationTracker.
-    // So it is possible to allocate 0, which has no additional impact on the behavior of BufferedBlockMgr.
-    // The process of memory allocation still by BufferPool, Because bufferpool has done a lot of optimization in memory allocation
-    // which is better than using the new operator directly.
-    if (size == 0) return true;
-    // Workaround IMPALA-1619. Return immediately if the allocation size will cause
-    // an arithmetic overflow.
-    if (UNLIKELY(size >= (1LL << 31))) {
-        LOG(WARNING) << "Trying to allocate memory >=2GB (" << size << ")B." << get_stack_trace();
-        return false;
-    }
-    int buffers_needed = BitUtil::ceil(size, max_block_size());
-    unique_lock<mutex> lock(_lock);
-    if (size < max_block_size() && _mem_tracker->TryConsume(size)) {
-        // For small allocations (less than a block size), just let the allocation through.
-        client->_tracker->ConsumeLocal(size, client->_query_tracker.get());
-        // client->_tracker->Consume(size);
-        return true;
-    }
-
-    if (available_buffers(client) + client->_num_tmp_reserved_buffers < buffers_needed) {
-        return false;
-    }
-    Status st = _mem_tracker->TryConsume(size);
-    WARN_IF_ERROR(st, "consume failed");
-    if (st) {
-        // There was still unallocated memory, don't need to recycle allocated blocks.
-        client->_tracker->ConsumeLocal(size, client->_query_tracker.get());
-        // client->_tracker->Consume(size);
-        return true;
-    }
-
-    // Bump up client->_num_tmp_reserved_buffers to satisfy this request. We don't want
-    // another client to grab the buffer.
-    int additional_tmp_reservations = 0;
-    if (client->_num_tmp_reserved_buffers < buffers_needed) {
-        additional_tmp_reservations = buffers_needed - client->_num_tmp_reserved_buffers;
-        client->_num_tmp_reserved_buffers += additional_tmp_reservations;
-        _unfullfilled_reserved_buffers += additional_tmp_reservations;
-    }
-
-    // Loop until we have freed enough memory.
-    // We free all the memory at the end. We don't want another component to steal the
-    // memory.
-    int buffers_acquired = 0;
-    do {
-        BufferDescriptor* buffer_desc = nullptr;
-        Status s = find_buffer(lock, &buffer_desc); // This waits on the lock.
-        if (buffer_desc == nullptr) {
-            break;
-        }
-        DCHECK(s.ok());
-        _all_io_buffers.erase(buffer_desc->all_buffers_it);
-        if (buffer_desc->block != nullptr) {
-            buffer_desc->block->_buffer_desc = nullptr;
-        }
-        delete[] buffer_desc->buffer;
-        ++buffers_acquired;
-    } while (buffers_acquired != buffers_needed);
-
-    Status status = Status::OK();
-    if (buffers_acquired == buffers_needed) {
-        status = write_unpinned_blocks();
-    }
-    // If we either couldn't acquire enough buffers or write_unpinned_blocks() failed, undo
-    // the reservation.
-    if (buffers_acquired != buffers_needed || !status.ok()) {
-        if (!status.ok()) {
-            VLOG_QUERY << "Query: " << _query_id << " write unpinned buffers failed.";
-            client->_state->log_error(status);
-        }
-        client->_num_tmp_reserved_buffers -= additional_tmp_reservations;
-        _unfullfilled_reserved_buffers -= additional_tmp_reservations;
-        _mem_tracker->Release(buffers_acquired * max_block_size());
-        return false;
-    }
-
-    client->_num_tmp_reserved_buffers -= buffers_acquired;
-    _unfullfilled_reserved_buffers -= buffers_acquired;
-
-    DCHECK_GE(buffers_acquired * max_block_size(), size);
-    _mem_tracker->Release(buffers_acquired * max_block_size());
-    st = _mem_tracker->TryConsume(size);
-    WARN_IF_ERROR(st, "consume failed");
-    if (!st) {
-        return false;
-    }
-    client->_tracker->ConsumeLocal(size, client->_query_tracker.get());
-    // client->_tracker->Consume(size);
-    DCHECK(validate()) << endl << debug_internal();
-    return true;
-}
-
-void BufferedBlockMgr2::release_memory(Client* client, int64_t size) {
-    _mem_tracker->Release(size);
-    client->_tracker->ReleaseLocal(size, client->_query_tracker.get());
-}
-
 void BufferedBlockMgr2::cancel() {
     {
         lock_guard<mutex> lock(_lock);
@@ -467,9 +357,10 @@ Status BufferedBlockMgr2::get_new_block(Client* client, Block* unpin_block, Bloc
 
         if (len > 0 && len < _max_block_size) {
             DCHECK(unpin_block == nullptr);
-            Status st = client->_tracker->TryConsume(len);
+            Status st = thread_context()->thread_mem_tracker()->check_limit(len);
             WARN_IF_ERROR(st, "get_new_block failed");
             if (st) {
+                client->_tracker->consume(len);
                 // TODO: Have a cache of unused blocks of size 'len' (0, _max_block_size)
                 uint8_t* buffer = new uint8_t[len];
                 // Descriptors for non-I/O sized buffers are deleted when the block is deleted.
@@ -563,7 +454,7 @@ BufferedBlockMgr2::~BufferedBlockMgr2() {
         lock_guard<SpinLock> lock(_s_block_mgrs_lock);
         BlockMgrsMap::iterator it = _s_query_to_block_mgrs.find(_query_id);
         // IMPALA-2286: Another fragment may have called create() for this _query_id and
-        // saw that this BufferedBlockMgr2 is being destructed.  That fragement will
+        // saw that this BufferedBlockMgr2 is being destructed.  That fragment will
         // overwrite the map entry for _query_id, pointing it to a different
         // BufferedBlockMgr2 object.  We should let that object's destructor remove the
         // entry.  On the other hand, if the second BufferedBlockMgr2 is destructed before
@@ -598,11 +489,9 @@ BufferedBlockMgr2::~BufferedBlockMgr2() {
 
     // Free memory resources.
     for (BufferDescriptor* buffer : _all_io_buffers) {
-        _mem_tracker->Release(buffer->len);
+        _mem_tracker->release(buffer->len);
         delete[] buffer->buffer;
     }
-    DCHECK_EQ(_mem_tracker->consumption(), 0);
-    _mem_tracker.reset();
 }
 
 int64_t BufferedBlockMgr2::bytes_allocated() const {
@@ -617,8 +506,8 @@ int BufferedBlockMgr2::num_reserved_buffers_remaining(Client* client) const {
     return std::max(client->_num_reserved_buffers - client->_num_pinned_buffers, 0);
 }
 
-std::shared_ptr<MemTracker> BufferedBlockMgr2::get_tracker(Client* client) const {
-    return client->_tracker;
+MemTracker* BufferedBlockMgr2::get_tracker(Client* client) const {
+    return client->_tracker.get();
 }
 
 // TODO: It would be good if we had a sync primitive that supports is_mine() calls, see
@@ -827,14 +716,14 @@ Status BufferedBlockMgr2::allocate_scratch_space(int64_t block_size, TmpFileMgr:
         }
         // Log error and try other files if there was a problem. Problematic files will be
         // blacklisted so we will not repeatedly log the same error.
-        LOG(WARNING) << "Error while allocating temporary file range: " << status.get_error_msg()
+        LOG(WARNING) << "Error while allocating temporary file range: " << status
                      << ". Will try another temporary file.";
-        errs.emplace_back(status.message().data, status.message().size);
+        errs.emplace_back(status.to_string());
     }
     Status err_status = Status::InternalError(
             "No usable temporary files: space could not be allocated on any temporary device.");
     for (int i = 0; i < errs.size(); ++i) {
-        err_status = err_status.clone_and_append(errs[i]);
+        err_status.append(errs[i]);
     }
     return err_status;
 }
@@ -893,21 +782,20 @@ void BufferedBlockMgr2::write_complete(Block* block, const Status& write_status)
         VLOG_FILE << "Query: " << _query_id
                   << ". Write did not complete successfully: "
                      "write_status="
-                  << write_status.get_error_msg() << ", status=" << status.get_error_msg()
-                  << ". _is_cancelled=" << _is_cancelled;
+                  << write_status << ", status=" << status << ". _is_cancelled=" << _is_cancelled;
 
         // If the instance is already cancelled, don't confuse things with these errors.
-        if (!write_status.is_cancelled() && !state->is_cancelled()) {
+        if (!write_status.is<CANCELLED>() && !state->is_cancelled()) {
             if (!write_status.ok()) {
                 // Report but do not attempt to recover from write error.
                 DCHECK(block->_tmp_file != nullptr);
-                block->_tmp_file->report_io_error(write_status.get_error_msg());
+                block->_tmp_file->report_io_error(write_status.to_string());
                 VLOG_QUERY << "Query: " << _query_id << " write complete callback with error.";
-                state->log_error(write_status.get_error_msg());
+                state->log_error(write_status.to_string());
             }
             if (!status.ok()) {
                 VLOG_QUERY << "Query: " << _query_id << " error while writing unpinned blocks.";
-                state->log_error(status.get_error_msg());
+                state->log_error(status.to_string());
             }
         }
         // Set cancelled and wake up waiting threads if an error occurred.  Note that in
@@ -952,7 +840,7 @@ void BufferedBlockMgr2::delete_block(Block* block) {
         if (block->_buffer_desc->len != _max_block_size) {
             // Just delete the block for now.
             delete[] block->_buffer_desc->buffer;
-            block->_client->_tracker->Release(block->_buffer_desc->len);
+            block->_client->_tracker->release(block->_buffer_desc->len);
             delete block->_buffer_desc;
             block->_buffer_desc = nullptr;
         } else {
@@ -1094,7 +982,8 @@ Status BufferedBlockMgr2::find_buffer(unique_lock<mutex>& lock, BufferDescriptor
 
     // First, try to allocate a new buffer.
     if (_free_io_buffers.size() < _block_write_threshold &&
-        _mem_tracker->TryConsume(_max_block_size)) {
+        thread_context()->thread_mem_tracker()->check_limit(_max_block_size)) {
+        _mem_tracker->consume(_max_block_size);
         uint8_t* new_buffer = new uint8_t[_max_block_size];
         *buffer_desc = _obj_pool.add(new BufferDescriptor(new_buffer, _max_block_size));
         (*buffer_desc)->all_buffers_it =
@@ -1259,15 +1148,16 @@ string BufferedBlockMgr2::debug_internal() const {
        << "  Num available buffers: " << remaining_unreserved_buffers() << endl
        << "  Total pinned buffers: " << _total_pinned_buffers << endl
        << "  Unfullfilled reserved buffers: " << _unfullfilled_reserved_buffers << endl
-       << "  Remaining memory: " << _mem_tracker->SpareCapacity(MemLimit::HARD)
-       << " (#blocks=" << (_mem_tracker->SpareCapacity(MemLimit::HARD) / _max_block_size) << ")"
+       << "  BUffer Block Mgr Used memory: " << _mem_tracker->consumption()
+       << "  Instance remaining memory: "
+       << thread_context()->thread_mem_tracker()->spare_capacity() << " (#blocks="
+       << (thread_context()->thread_mem_tracker()->spare_capacity() / _max_block_size) << ")"
        << endl
        << "  Block write threshold: " << _block_write_threshold;
     return ss.str();
 }
 
-void BufferedBlockMgr2::init(DiskIoMgr* io_mgr, RuntimeProfile* parent_profile,
-                             const std::shared_ptr<MemTracker>& parent_tracker, int64_t mem_limit) {
+void BufferedBlockMgr2::init(DiskIoMgr* io_mgr, RuntimeProfile* parent_profile) {
     unique_lock<mutex> l(_lock);
     if (_initialized) {
         return;
@@ -1292,7 +1182,7 @@ void BufferedBlockMgr2::init(DiskIoMgr* io_mgr, RuntimeProfile* parent_profile,
     _integrity_check_timer = ADD_TIMER(_profile.get(), "TotalIntegrityCheckTime");
 
     // Create a new mem_tracker and allocate buffers.
-    _mem_tracker = MemTracker::CreateTracker(mem_limit, "BufferedBlockMgr2", parent_tracker);
+    _mem_tracker = std::make_unique<MemTracker>("BufferedBlockMgr2");
 
     _initialized = true;
 }
