@@ -15,8 +15,7 @@
 // specific language governing permissions and limitations
 // under the License.
 
-#ifndef DORIS_BE_RUNTIME_DATETIME_VALUE_H
-#define DORIS_BE_RUNTIME_DATETIME_VALUE_H
+#pragma once
 
 #include <re2/re2.h>
 #include <stdint.h>
@@ -31,6 +30,7 @@
 #include "util/hash_util.hpp"
 #include "util/timezone_utils.h"
 #include "vec/runtime/vdatetime_value.h"
+
 namespace doris {
 
 enum TimeUnit {
@@ -175,8 +175,18 @@ public:
               _day(0),
               _microsecond(0) {}
 
-    explicit DateTimeValue(int64_t t) { from_date_int64(t); }
-
+    explicit DateTimeValue(int64_t t)
+            : _neg(0),
+              _type(TIME_DATETIME),
+              _hour(0),
+              _minute(0),
+              _second(0),
+              _year(0),
+              _month(0),
+              _day(0),
+              _microsecond(0) {
+        from_date_int64(t);
+    }
     void set_time(uint32_t year, uint32_t month, uint32_t day, uint32_t hour, uint32_t minute,
                   uint32_t second, uint32_t microsecond);
 
@@ -359,7 +369,7 @@ public:
         return true;
     };
 
-    inline uint64_t daynr() const { return calc_daynr(_year, _month, _day); }
+    uint64_t daynr() const { return calc_daynr(_year, _month, _day); }
 
     // Calculate how many days since 0000-01-01
     // 0000-01-01 is 1st B.C.
@@ -401,8 +411,8 @@ public:
     void to_datetime() { _type = TIME_DATETIME; }
 
     // Weekday, from 0(Mon) to 6(Sun)
-    inline uint8_t weekday() const { return calc_weekday(daynr(), false); }
-    inline auto day_of_week() const { return (weekday() + 1) % 7 + 1; }
+    uint8_t weekday() const { return calc_weekday(daynr(), false); }
+    auto day_of_week() const { return (weekday() + 1) % 7 + 1; }
 
     // The bits in week_format has the following meaning:
     // WEEK_MONDAY_FIRST (0)
@@ -414,7 +424,7 @@ public:
     // WEEK_YEAR (1)
     //  If not set:
     //      Week is in range 0-53
-    //      Week 0 is returned for the the last week of the previous year (for
+    //      Week 0 is returned for the last week of the previous year (for
     //      a date at start of january) In this case one can get 53 for the
     //      first week of next year.  This flag ensures that the week is
     //      relevant for the given year. Note that this flag is only
@@ -485,20 +495,25 @@ public:
 
     const char* day_name() const;
 
-    DateTimeValue& operator++() {
+    DateTimeValue& operator+=(int64_t count) {
+        bool is_neg = false;
+        if (count < 0) {
+            is_neg = true;
+            count = -count;
+        }
         switch (_type) {
         case TIME_DATE: {
-            TimeInterval interval(DAY, 1, false);
+            TimeInterval interval(DAY, count, is_neg);
             date_add_interval(interval, DAY);
             break;
         }
         case TIME_DATETIME: {
-            TimeInterval interval(SECOND, 1, false);
+            TimeInterval interval(SECOND, count, is_neg);
             date_add_interval(interval, SECOND);
             break;
         }
         case TIME_TIME: {
-            TimeInterval interval(SECOND, 1, false);
+            TimeInterval interval(SECOND, count, is_neg);
             date_add_interval(interval, SECOND);
             break;
         }
@@ -506,6 +521,12 @@ public:
         return *this;
     }
 
+    DateTimeValue& operator-=(int64_t count) { return *this += -count; }
+
+    DateTimeValue& operator++() { return *this += 1; }
+
+    DateTimeValue& operator--() { return *this += -1; }
+
     void to_datetime_val(doris_udf::DateTimeVal* tv) const {
         tv->packed_time = to_int64_datetime_packed();
         tv->type = _type;
@@ -565,12 +586,37 @@ public:
                _month > 0 && _day > 0;
     }
 
+    template <typename T>
+    void convert_from_date_v2(doris::vectorized::DateV2Value<T>* dt) {
+        if constexpr (doris::vectorized::DateV2Value<T>::is_datetime) {
+            this->_type = TIME_DATETIME;
+            this->_hour = dt->hour();
+            this->_minute = dt->minute();
+            this->_second = dt->second();
+        } else {
+            this->_type = TIME_DATE;
+            this->_hour = 0;
+            this->_minute = 0;
+            this->_second = 0;
+        }
+        this->_neg = 0;
+        this->_year = dt->year();
+        this->_month = dt->month();
+        this->_day = dt->day();
+        this->_microsecond = 0;
+    }
+
+    template <typename T>
+    void convert_to_date_v2(doris::vectorized::DateV2Value<T>* dt) {
+        dt->set_time(dt->year(), dt->month(), dt->_day, dt->hour(), dt->minute(), dt->second(), 0);
+    }
+
 private:
     // Used to make sure sizeof DateTimeValue
     friend class UnusedClass;
-    friend void doris::vectorized::VecDateTimeValue::convert_vec_dt_to_dt(DateTimeValue* dt); 
+    friend void doris::vectorized::VecDateTimeValue::convert_vec_dt_to_dt(DateTimeValue* dt) const;
     friend void doris::vectorized::VecDateTimeValue::convert_dt_to_vec_dt(DateTimeValue* dt);
-    
+
     void from_packed_time(int64_t packed_time) {
         _microsecond = packed_time % (1LL << 24);
         int64_t ymdhms = packed_time >> 24;
@@ -673,11 +719,7 @@ std::size_t hash_value(DateTimeValue const& value);
 
 } // namespace doris
 
-namespace std {
 template <>
-struct hash<doris::DateTimeValue> {
+struct std::hash<doris::DateTimeValue> {
     size_t operator()(const doris::DateTimeValue& v) const { return doris::hash_value(v); }
 };
-} // namespace std
-
-#endif
