@@ -21,8 +21,6 @@
 
 #include "common/logging.h"
 #include "env/env.h"
-#include "exec/broker_reader.h"
-#include "exec/broker_writer.h"
 #include "gen_cpp/FrontendService.h"
 #include "gen_cpp/FrontendService_types.h"
 #include "gen_cpp/HeartbeatService_types.h"
@@ -36,22 +34,12 @@
 #include "runtime/exec_env.h"
 #include "util/broker_storage_backend.h"
 #include "util/file_utils.h"
+#include "util/hdfs_storage_backend.h"
 #include "util/s3_storage_backend.h"
 #include "util/thrift_rpc_helper.h"
 
 namespace doris {
 
-SnapshotLoader::SnapshotLoader(ExecEnv* env, int64_t job_id, int64_t task_id,
-                               const TNetworkAddress& broker_addr,
-                               const std::map<std::string, std::string>& broker_prop)
-        : _env(env),
-          _job_id(job_id),
-          _task_id(task_id),
-          _broker_addr(broker_addr),
-          _prop(broker_prop) {
-    _storage_backend.reset(new BrokerStorageBackend(_env, _broker_addr, _prop));
-}
-
 SnapshotLoader::SnapshotLoader(ExecEnv* env, int64_t job_id, int64_t task_id)
         : _env(env),
           _job_id(job_id),
@@ -60,14 +48,21 @@ SnapshotLoader::SnapshotLoader(ExecEnv* env, int64_t job_id, int64_t task_id)
           _prop(std::map<std::string, std::string>()),
           _storage_backend(nullptr) {}
 
-SnapshotLoader::SnapshotLoader(ExecEnv* env, int64_t job_id, int64_t task_id, const std::map<std::string, std::string>& prop)
-        : _env(env),
-          _job_id(job_id),
-          _task_id(task_id),
-          _broker_addr(TNetworkAddress()),
-          _prop(prop) {
-              _storage_backend.reset(new S3StorageBackend(_prop));
-          }
+SnapshotLoader::SnapshotLoader(ExecEnv* env, int64_t job_id, int64_t task_id,
+                               const TNetworkAddress& broker_addr,
+                               const std::map<std::string, std::string>& prop,
+                               TStorageBackendType::type type)
+        : _env(env), _job_id(job_id), _task_id(task_id), _broker_addr(broker_addr), _prop(prop) {
+    if (TStorageBackendType::type::S3 == type) {
+        _storage_backend.reset(new S3StorageBackend(_prop));
+    } else if (TStorageBackendType::type::HDFS == type) {
+        _storage_backend.reset(new HDFSStorageBackend(_prop));
+    } else if (TStorageBackendType::type::BROKER == type) {
+        _storage_backend.reset(new BrokerStorageBackend(_env, _broker_addr, _prop));
+    } else {
+        _storage_backend = nullptr;
+    }
+}
 
 SnapshotLoader::~SnapshotLoader() = default;
 
@@ -126,8 +121,7 @@ Status SnapshotLoader::upload(const std::map<std::string, std::string>& src_to_d
             status = FileUtils::md5sum(src_path + "/" + local_file, &md5sum);
             if (!status.ok()) {
                 std::stringstream ss;
-                ss << "failed to get md5sum of file: " << local_file << ": "
-                   << status.get_error_msg();
+                ss << "failed to get md5sum of file: " << local_file << ": " << status;
                 LOG(WARNING) << ss.str();
                 return Status::InternalError(ss.str());
             }
@@ -157,7 +151,8 @@ Status SnapshotLoader::upload(const std::map<std::string, std::string>& src_to_d
             // upload
             std::string full_remote_file = dest_path + "/" + local_file;
             std::string full_local_file = src_path + "/" + local_file;
-            RETURN_IF_ERROR(_storage_backend->upload_with_checksum(full_local_file, full_remote_file, md5sum));
+            RETURN_IF_ERROR(_storage_backend->upload_with_checksum(full_local_file,
+                                                                   full_remote_file, md5sum));
         } // end for each tablet's local files
 
         tablet_files->emplace(tablet_id, local_files_with_checksum);
@@ -173,7 +168,7 @@ Status SnapshotLoader::upload(const std::map<std::string, std::string>& src_to_d
 /*
  * Download snapshot files from remote.
  * After downloaded, the local dir should contains all files existing in remote,
- * may also contains severval useless files.
+ * may also contains several useless files.
  */
 Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to_dest_path,
                                 std::vector<int64_t>* downloaded_tablet_ids) {
@@ -208,8 +203,9 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
 
         int64_t remote_tablet_id;
         RETURN_IF_ERROR(_get_tablet_id_from_remote_path(remote_path, &remote_tablet_id));
-        VLOG_CRITICAL << "get local tablet id: " << local_tablet_id << ", schema hash: " << schema_hash
-                << ", remote tablet id: " << remote_tablet_id;
+        VLOG_CRITICAL << "get local tablet id: " << local_tablet_id
+                      << ", schema hash: " << schema_hash
+                      << ", remote tablet id: " << remote_tablet_id;
 
         // 2.1. get local files
         std::vector<std::string> local_files;
@@ -226,7 +222,7 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
         }
 
         TabletSharedPtr tablet =
-                _env->storage_engine()->tablet_manager()->get_tablet(local_tablet_id, schema_hash);
+                _env->storage_engine()->tablet_manager()->get_tablet(local_tablet_id);
         if (tablet == nullptr) {
             std::stringstream ss;
             ss << "failed to get local tablet: " << local_tablet_id;
@@ -256,11 +252,11 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
                     Status st = FileUtils::md5sum(local_path + "/" + remote_file, &local_md5sum);
                     if (!st.ok()) {
                         LOG(WARNING) << "failed to get md5sum of local file: " << remote_file
-                                     << ". msg: " << st.get_error_msg() << ". download it";
+                                     << ". msg: " << st << ". download it";
                         need_download = true;
                     } else {
                         VLOG_CRITICAL << "get local file checksum: " << remote_file << ": "
-                                << local_md5sum;
+                                      << local_md5sum;
                         if (file_stat.md5 != local_md5sum) {
                             // file's checksum does not equal, download it.
                             need_download = true;
@@ -298,12 +294,12 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
             status = FileUtils::md5sum(full_local_file, &downloaded_md5sum);
             if (!status.ok()) {
                 std::stringstream ss;
-                ss << "failed to get md5sum of file: " << full_local_file << ", err: " << status.get_error_msg();
+                ss << "failed to get md5sum of file: " << full_local_file << ", err: " << status;
                 LOG(WARNING) << ss.str();
                 return Status::InternalError(ss.str());
             }
             VLOG_CRITICAL << "get downloaded file checksum: " << full_local_file << ": "
-                    << downloaded_md5sum;
+                          << downloaded_md5sum;
             if (downloaded_md5sum != file_stat.md5) {
                 std::stringstream ss;
                 ss << "invalid md5 of downloaded file: " << full_local_file
@@ -325,8 +321,8 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
             std::string new_name;
             Status st = _replace_tablet_id(local_file, remote_tablet_id, &new_name);
             if (!st.ok()) {
-                LOG(WARNING) << "failed to replace tablet id. unknown local file: "
-                             << st.get_error_msg() << ". ignore it";
+                LOG(WARNING) << "failed to replace tablet id. unknown local file: " << st
+                             << ". ignore it";
                 continue;
             }
             VLOG_CRITICAL << "new file name after replace tablet id: " << new_name;
@@ -338,7 +334,7 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
             // delete
             std::string full_local_file = local_path + "/" + local_file;
             VLOG_CRITICAL << "begin to delete local snapshot file: " << full_local_file
-                    << ", it does not exist in remote";
+                          << ", it does not exist in remote";
             if (remove(full_local_file.c_str()) != 0) {
                 LOG(WARNING) << "failed to delete unknown local file: " << full_local_file
                              << ", ignore it";
@@ -360,8 +356,8 @@ Status SnapshotLoader::download(const std::map<std::string, std::string>& src_to
 // MUST hold tablet's header lock, push lock, cumulative lock and base compaction lock
 Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr tablet,
                             bool overwrite) {
-    std::string tablet_path = tablet->tablet_path_desc().filepath;
-    std::string store_path = tablet->data_dir()->path_desc().filepath;
+    auto tablet_path = tablet->tablet_path();
+    auto store_path = tablet->data_dir()->path();
     LOG(INFO) << "begin to move snapshot files. from: " << snapshot_path << ", to: " << tablet_path
               << ", store: " << store_path << ", job: " << _job_id << ", task id: " << _task_id;
 
@@ -394,16 +390,14 @@ Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr ta
         return Status::InternalError(ss.str());
     }
 
-    std::filesystem::path tablet_dir(tablet_path);
-    std::filesystem::path snapshot_dir(snapshot_path);
-    if (!std::filesystem::exists(tablet_dir)) {
+    if (!std::filesystem::exists(tablet_path)) {
         std::stringstream ss;
         ss << "tablet path does not exist: " << tablet_path;
         LOG(WARNING) << ss.str();
         return Status::InternalError(ss.str());
     }
 
-    if (!std::filesystem::exists(snapshot_dir)) {
+    if (!std::filesystem::exists(snapshot_path)) {
         std::stringstream ss;
         ss << "snapshot path does not exist: " << snapshot_path;
         LOG(WARNING) << ss.str();
@@ -411,9 +405,9 @@ Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr ta
     }
 
     // rename the rowset ids and tabletid info in rowset meta
-    OLAPStatus convert_status =
-            SnapshotManager::instance()->convert_rowset_ids(snapshot_path, tablet_id, schema_hash);
-    if (convert_status != OLAP_SUCCESS) {
+    Status convert_status = SnapshotManager::instance()->convert_rowset_ids(
+            snapshot_path, tablet_id, tablet->replica_id(), schema_hash);
+    if (convert_status != Status::OK()) {
         std::stringstream ss;
         ss << "failed to convert rowsetids in snapshot: " << snapshot_path
            << ", tablet path: " << tablet_path;
@@ -430,10 +424,10 @@ Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr ta
             // This remove seems soft enough, because we already get
             // tablet id and schema hash from this path, which
             // means this path is a valid path.
-            std::filesystem::remove_all(tablet_dir);
-            VLOG_CRITICAL << "remove dir: " << tablet_dir;
-            std::filesystem::create_directory(tablet_dir);
-            VLOG_CRITICAL << "re-create dir: " << tablet_dir;
+            std::filesystem::remove_all(tablet_path);
+            VLOG_CRITICAL << "remove dir: " << tablet_path;
+            std::filesystem::create_directory(tablet_path);
+            VLOG_CRITICAL << "re-create dir: " << tablet_path;
         } catch (const std::filesystem::filesystem_error& e) {
             std::stringstream ss;
             ss << "failed to move tablet path: " << tablet_path << ". err: " << e.what();
@@ -445,8 +439,8 @@ Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr ta
         // files in snapshot dir will be moved in snapshot clean process
         std::vector<std::string> linked_files;
         for (auto& file : snapshot_files) {
-            std::string full_src_path = snapshot_path + "/" + file;
-            std::string full_dest_path = tablet_path + "/" + file;
+            auto full_src_path = fmt::format("{}/{}", snapshot_path, file);
+            auto full_dest_path = fmt::format("{}/{}", tablet_path, file);
             if (link(full_src_path.c_str(), full_dest_path.c_str()) != 0) {
                 LOG(WARNING) << "failed to link file from " << full_src_path << " to "
                              << full_dest_path << ", err: " << std::strerror(errno);
@@ -469,9 +463,9 @@ Status SnapshotLoader::move(const std::string& snapshot_path, TabletSharedPtr ta
     // snapshot loader not need to change tablet uid
     // fixme: there is no header now and can not call load_one_tablet here
     // reload header
-    OLAPStatus ost = StorageEngine::instance()->tablet_manager()->load_tablet_from_dir(
+    Status ost = StorageEngine::instance()->tablet_manager()->load_tablet_from_dir(
             store, tablet_id, schema_hash, tablet_path, true);
-    if (ost != OLAP_SUCCESS) {
+    if (!ost.ok()) {
         std::stringstream ss;
         ss << "failed to reload header of tablet: " << tablet_id;
         LOG(WARNING) << ss.str();
@@ -497,7 +491,7 @@ Status SnapshotLoader::_get_tablet_id_and_schema_hash_from_file_path(const std::
     // we try to extract tablet_id from path
     size_t pos = src_path.find_last_of("/");
     if (pos == std::string::npos || pos == src_path.length() - 1) {
-        return Status::InternalError("failed to get tablet id from path: " + src_path);
+        return Status::InternalError("failed to get tablet id from path: {}", src_path);
     }
 
     std::string schema_hash_str = src_path.substr(pos + 1);
@@ -508,7 +502,7 @@ Status SnapshotLoader::_get_tablet_id_and_schema_hash_from_file_path(const std::
     // skip schema hash part
     size_t pos2 = src_path.find_last_of("/", pos - 1);
     if (pos2 == std::string::npos) {
-        return Status::InternalError("failed to get tablet id from path: " + src_path);
+        return Status::InternalError("failed to get tablet id from path: {}", src_path);
     }
 
     std::string tablet_str = src_path.substr(pos2 + 1, pos - pos2);
@@ -517,7 +511,7 @@ Status SnapshotLoader::_get_tablet_id_and_schema_hash_from_file_path(const std::
     ss2 >> *tablet_id;
 
     VLOG_CRITICAL << "get tablet id " << *tablet_id << ", schema hash: " << *schema_hash
-            << " from path: " << src_path;
+                  << " from path: " << src_path;
     return Status::OK();
 }
 
@@ -546,8 +540,7 @@ Status SnapshotLoader::_get_existing_files_from_local(const std::string& local_p
     Status status = FileUtils::list_files(Env::Default(), local_path, local_files);
     if (!status.ok()) {
         std::stringstream ss;
-        ss << "failed to list files in local path: " << local_path
-           << ", msg: " << status.get_error_msg();
+        ss << "failed to list files in local path: " << local_path << ", msg: " << status;
         LOG(WARNING) << ss.str();
         return status;
     }
@@ -571,7 +564,7 @@ Status SnapshotLoader::_replace_tablet_id(const std::string& file_name, int64_t
         *new_file_name = file_name;
         return Status::OK();
     } else {
-        return Status::InternalError("invalid tablet file name: " + file_name);
+        return Status::InternalError("invalid tablet file name: {}", file_name);
     }
 }
 
@@ -581,7 +574,7 @@ Status SnapshotLoader::_get_tablet_id_from_remote_path(const std::string& remote
     // bos://xxx/../__tbl_10004/__part_10003/__idx_10004/__10005
     size_t pos = remote_path.find_last_of("_");
     if (pos == std::string::npos) {
-        return Status::InternalError("invalid remove file path: " + remote_path);
+        return Status::InternalError("invalid remove file path: {}", remote_path);
     }
 
     std::string tablet_id_str = remote_path.substr(pos + 1);
