@@ -14,9 +14,11 @@
 // KIND, either express or implied.  See the License for the
 // specific language governing permissions and limitations
 // under the License.
+// This file is copied from
+// https://github.com/apache/impala/blob/branch-2.9.0/be/src/util/fake-lock.h
+// and modified by Doris
 
-#ifndef DORIS_BE_SRC_UTIL_FAKE_LOCK_H
-#define DORIS_BE_SRC_UTIL_FAKE_LOCK_H
+#pragma once
 
 #include "gutil/macros.h"
 
@@ -36,5 +38,3 @@ private:
 };
 
 } // namespace doris
-
-#endif // DORIS_BE_SRC_UTIL_FAKE_LOCK_H
