@@ -19,10 +19,11 @@
 
 #include "olap/decimal12.h"
 #include "olap/uint24.h"
+#include "runtime/mem_pool.h"
+#include "runtime/primitive_type.h"
 #include "runtime/string_value.h"
 #include "vec/columns/column.h"
 #include "vec/columns/column_decimal.h"
-#include "vec/columns/column_impl.h"
 #include "vec/columns/column_string.h"
 #include "vec/columns/column_vector.h"
 #include "vec/core/types.h"
@@ -34,12 +35,13 @@ namespace doris::vectorized {
  *
  *  T = predicate column type
  */
-template <typename T>
-class PredicateColumnType final : public COWHelper<IColumn, PredicateColumnType<T>> {
+template <PrimitiveType Type>
+class PredicateColumnType final : public COWHelper<IColumn, PredicateColumnType<Type>> {
 private:
     PredicateColumnType() {}
     PredicateColumnType(const size_t n) : data(n) {}
-    friend class COWHelper<IColumn, PredicateColumnType<T>>;
+    friend class COWHelper<IColumn, PredicateColumnType<Type>>;
+    using T = typename PredicatePrimitiveTypeTraits<Type>::PredicateFieldType;
 
     PredicateColumnType(const PredicateColumnType& src) : data(src.data.begin(), src.data.end()) {}
 
@@ -63,6 +65,20 @@ private:
         }
     }
 
+    void insert_date32_to_res_column(const uint16_t* sel, size_t sel_size,
+                                     vectorized::ColumnVector<Int64>* res_ptr) {
+        res_ptr->reserve(sel_size);
+        auto& res_data = res_ptr->get_data();
+
+        for (size_t i = 0; i < sel_size; i++) {
+            uint64_t val = data[sel[i]];
+            VecDateTimeValue date;
+            date.set_olap_date(val);
+            res_data.push_back_without_reserve(
+                    unaligned_load<Int64>(reinterpret_cast<char*>(&date)));
+        }
+    }
+
     void insert_datetime_to_res_column(const uint16_t* sel, size_t sel_size,
                                        vectorized::ColumnVector<Int64>* res_ptr) {
         for (size_t i = 0; i < sel_size; i++) {
@@ -75,11 +91,18 @@ private:
 
     void insert_string_to_res_column(const uint16_t* sel, size_t sel_size,
                                      vectorized::ColumnString* res_ptr) {
+        StringRef refs[sel_size];
+        size_t length = 0;
         for (size_t i = 0; i < sel_size; i++) {
             uint16_t n = sel[i];
             auto& sv = reinterpret_cast<StringValue&>(data[n]);
-            res_ptr->insert_data(sv.ptr, sv.len);
+            refs[i].data = sv.ptr;
+            refs[i].size = sv.len;
+            length += sv.len;
         }
+        res_ptr->get_offsets().reserve(sel_size + res_ptr->get_offsets().size());
+        res_ptr->get_chars().reserve(length + res_ptr->get_chars().size());
+        res_ptr->insert_many_strings_without_reserve(refs, sel_size);
     }
 
     void insert_decimal_to_res_column(const uint16_t* sel, size_t sel_size,
@@ -115,22 +138,16 @@ private:
         }
     }
 
-    // note(wb): Write data one by one has a slight performance improvement than memcpy directly
     void insert_many_default_type(const char* data_ptr, size_t num) {
-        T* input_val_ptr = (T*)data_ptr;
-        T* res_val_ptr = (T*)data.get_end_ptr();
-        for (int i = 0; i < num; i++) {
-            res_val_ptr[i] = input_val_ptr[i];
-        }
-        res_val_ptr += num;
-        data.set_end_ptr(res_val_ptr);
+        auto old_size = data.size();
+        data.resize(old_size + num);
+        memcpy(data.data() + old_size, data_ptr, num * sizeof(T));
     }
 
     void insert_many_in_copy_way(const char* data_ptr, size_t num) {
-        char* res_ptr = (char*)data.get_end_ptr();
-        memcpy(res_ptr, data_ptr, num * sizeof(T));
-        res_ptr += num * sizeof(T);
-        data.set_end_ptr(res_ptr);
+        auto old_size = data.size();
+        data.resize(old_size + num);
+        memcpy(data.data() + old_size, data_ptr, num * sizeof(T));
     }
 
 public:
@@ -205,6 +222,21 @@ public:
         }
     }
 
+    void insert_many_date(const char* data_ptr, size_t num) {
+        size_t intput_type_size = sizeof(uint24_t);
+        size_t res_type_size = sizeof(uint32_t);
+        char* input_data_ptr = const_cast<char*>(data_ptr);
+
+        char* res_ptr = (char*)data.get_end_ptr();
+        memset(res_ptr, 0, res_type_size * num);
+        for (int i = 0; i < num; i++) {
+            memcpy(res_ptr, input_data_ptr, intput_type_size);
+            res_ptr += res_type_size;
+            input_data_ptr += intput_type_size;
+        }
+        data.set_end_ptr(res_ptr);
+    }
+
     void insert_many_fix_len_data(const char* data_ptr, size_t num) override {
         if constexpr (std::is_same_v<T, decimal12_t>) {
             insert_many_in_copy_way(data_ptr, num);
@@ -212,6 +244,8 @@ public:
             insert_many_in_copy_way(data_ptr, num);
         } else if constexpr (std::is_same_v<T, StringValue>) {
             // here is unreachable, just for compilation to be able to pass
+        } else if constexpr (Type == TYPE_DATE) {
+            insert_many_date(data_ptr, num);
         } else {
             insert_many_default_type(data_ptr, num);
         }
@@ -227,11 +261,38 @@ public:
         }
     }
 
-    void insert_many_binary_data(char* data_array, uint32_t* len_array,
-                                 uint32_t* start_offset_array, size_t num) override {
+    void insert_many_continuous_binary_data(const char* data_, const uint32_t* offsets,
+                                            const size_t num) override {
+        if (UNLIKELY(num == 0)) {
+            return;
+        }
         if constexpr (std::is_same_v<T, StringValue>) {
             if (_pool == nullptr) {
-                _pool.reset(new MemPool("PredicateStringColumn"));
+                _pool.reset(new MemPool());
+            }
+            const auto total_mem_size = offsets[num] - offsets[0];
+            char* destination = (char*)_pool->allocate(total_mem_size);
+            memcpy(destination, data_ + offsets[0], total_mem_size);
+            size_t org_elem_num = data.size();
+            data.resize(org_elem_num + num);
+
+            auto* data_ptr = &data[org_elem_num];
+            for (size_t i = 0; i != num; ++i) {
+                data_ptr[i].ptr = destination + offsets[i] - offsets[0];
+                data_ptr[i].len = offsets[i + 1] - offsets[i];
+            }
+            DCHECK(data_ptr[num - 1].ptr + data_ptr[num - 1].len == destination + total_mem_size);
+        }
+    }
+
+    void insert_many_binary_data(char* data_array, uint32_t* len_array,
+                                 uint32_t* start_offset_array, size_t num) override {
+        if (num == 0) {
+            return;
+        }
+        if constexpr (std::is_same_v<T, StringValue>) {
+            if (_pool == nullptr) {
+                _pool.reset(new MemPool());
             }
 
             size_t total_mem_size = 0;
@@ -240,14 +301,29 @@ public:
             }
 
             char* destination = (char*)_pool->allocate(total_mem_size);
+            char* org_dst = destination;
+            size_t org_elem_num = data.size();
+            data.resize(org_elem_num + num);
+            uint32_t fragment_start_offset = start_offset_array[0];
+            size_t fragment_len = 0;
             for (size_t i = 0; i < num; i++) {
-                uint32_t len = len_array[i];
-                uint32_t start_offset = start_offset_array[i];
-                memcpy(destination, data_array + start_offset, len);
-                StringValue sv(destination, len);
-                data.push_back_without_reserve(sv);
-                destination += len;
+                data[org_elem_num + i].ptr = destination + fragment_len;
+                data[org_elem_num + i].len = len_array[i];
+                fragment_len += len_array[i];
+                // Compute the largest continuous memcpy block and copy them.
+                // If this is the last element in data array, then should copy the current memory block.
+                if (i == num - 1 ||
+                    start_offset_array[i + 1] != start_offset_array[i] + len_array[i]) {
+                    memcpy(destination, data_array + fragment_start_offset, fragment_len);
+                    destination += fragment_len;
+                    fragment_start_offset = (i == num - 1 ? 0 : start_offset_array[i + 1]);
+                    fragment_len = 0;
+                }
             }
+            CHECK(destination - org_dst == total_mem_size)
+                    << "Copied size not equal to expected size";
+        } else {
+            LOG(FATAL) << "Method insert_many_binary_data is not supported";
         }
     }
 
@@ -311,7 +387,7 @@ public:
         LOG(FATAL) << "get field not supported in PredicateColumnType";
     }
 
-    // it's impossable to use ComplexType as key , so we don't have to implemnt them
+    // it's impossible to use ComplexType as key , so we don't have to implement them
     [[noreturn]] StringRef serialize_value_into_arena(size_t n, Arena& arena,
                                                       char const*& begin) const override {
         LOG(FATAL) << "serialize_value_into_arena not supported in PredicateColumnType";
@@ -365,6 +441,11 @@ public:
         LOG(FATAL) << "scatter not supported in PredicateColumnType";
     }
 
+    void append_data_by_selector(MutableColumnPtr& res,
+                                 const IColumn::Selector& selector) const override {
+        LOG(FATAL) << "append_data_by_selector is not supported in PredicateColumnType!";
+    }
+
     Status filter_by_selector(const uint16_t* sel, size_t sel_size, IColumn* col_ptr) override {
         if constexpr (std::is_same_v<T, StringValue>) {
             insert_string_to_res_column(sel, sel_size,
@@ -400,11 +481,31 @@ public:
                     reinterpret_cast<vectorized::ColumnVector<doris::vectorized::Float64>*>(
                             col_ptr));
         } else if constexpr (std::is_same_v<T, uint64_t>) {
-            insert_datetime_to_res_column(
-                    sel, sel_size, reinterpret_cast<vectorized::ColumnVector<Int64>*>(col_ptr));
+            if (const vectorized::ColumnVector<UInt64>* date_col =
+                        check_and_get_column<vectorized::ColumnVector<UInt64>>(
+                                const_cast<const IColumn*>(col_ptr))) {
+                insert_default_value_res_column(
+                        sel, sel_size, const_cast<vectorized::ColumnVector<UInt64>*>(date_col));
+            } else {
+                insert_datetime_to_res_column(
+                        sel, sel_size, reinterpret_cast<vectorized::ColumnVector<Int64>*>(col_ptr));
+            }
         } else if constexpr (std::is_same_v<T, uint24_t>) {
             insert_date_to_res_column(sel, sel_size,
                                       reinterpret_cast<vectorized::ColumnVector<Int64>*>(col_ptr));
+        } else if constexpr (std::is_same_v<T, uint32_t>) {
+            if (const vectorized::ColumnVector<Int64>* date_col =
+                        check_and_get_column<vectorized::ColumnVector<Int64>>(
+                                const_cast<const IColumn*>(col_ptr))) {
+                // a trick type judge, need refactor it.
+                insert_date32_to_res_column(sel, sel_size,
+                                            const_cast<vectorized::ColumnVector<Int64>*>(date_col));
+            } else {
+                insert_default_value_res_column(
+                        sel, sel_size,
+                        reinterpret_cast<vectorized::ColumnVector<doris::vectorized::UInt32>*>(
+                                col_ptr));
+            }
         } else if constexpr (std::is_same_v<T, doris::vectorized::Int128>) {
             insert_default_value_res_column(
                     sel, sel_size,
@@ -431,6 +532,5 @@ private:
     // manages the memory for slice's data(For string type)
     std::unique_ptr<MemPool> _pool;
 };
-using ColumnStringValue = PredicateColumnType<StringValue>;
 
 } // namespace doris::vectorized
