@@ -142,13 +142,16 @@ private:
 
         Shift shift;
         if (decimal0 && decimal1) {
-            auto result_type = decimal_result_type(*decimal0, *decimal1, false, false);
-            shift.a = result_type.scale_factor_for(*decimal0, false);
-            shift.b = result_type.scale_factor_for(*decimal1, false);
-        } else if (decimal0)
+            using Type = std::conditional_t<sizeof(T) >= sizeof(U), T, U>;
+            auto type_ptr = decimal_result_type(*decimal0, *decimal1, false, false, false);
+            const DataTypeDecimal<Type>* result_type = check_decimal<Type>(*type_ptr);
+            shift.a = result_type->scale_factor_for(*decimal0, false);
+            shift.b = result_type->scale_factor_for(*decimal1, false);
+        } else if (decimal0) {
             shift.b = decimal0->get_scale_multiplier();
-        else if (decimal1)
+        } else if (decimal1) {
             shift.a = decimal1->get_scale_multiplier();
+        }
 
         return shift;
     }
