@@ -29,7 +29,7 @@ namespace doris::vectorized {
 
 doris::Status VCastExpr::prepare(doris::RuntimeState* state, const doris::RowDescriptor& desc,
                                  VExprContext* context) {
-    RETURN_IF_ERROR(VExpr::prepare(state, desc, context));
+    RETURN_IF_ERROR_OR_PREPARED(VExpr::prepare(state, desc, context));
 
     DCHECK_EQ(_children.size(), 1);
     auto child = _children[0];
@@ -38,23 +38,22 @@ doris::Status VCastExpr::prepare(doris::RuntimeState* state, const doris::RowDes
 
     // create a const string column
     _target_data_type = _data_type;
-    _target_data_type_name = DataTypeFactory::instance().get(_target_data_type);
-    _cast_param_data_type = std::make_shared<DataTypeString>();
-    _cast_param = _cast_param_data_type->create_column_const(1, _target_data_type_name);
+    _target_data_type_name = _target_data_type->get_name();
+    _cast_param_data_type = _target_data_type;
+    _cast_param = _cast_param_data_type->create_column_const_with_default_value(1);
 
     ColumnsWithTypeAndName argument_template;
     argument_template.reserve(2);
     argument_template.emplace_back(std::move(child_column), child->data_type(), child_name);
     argument_template.emplace_back(_cast_param, _cast_param_data_type, _target_data_type_name);
-
-    _function = SimpleFunctionFactory::instance().get_function(function_name, argument_template, _data_type);
+    _function = SimpleFunctionFactory::instance().get_function(function_name, argument_template,
+                                                               _data_type);
 
     if (_function == nullptr) {
-        return Status::NotSupported(
-                fmt::format("Function {} is not implemented", _fn.name.function_name));
+        return Status::NotSupported("Function {} is not implemented", _fn.name.function_name);
     }
     VExpr::register_function_context(state, context);
-    _expr_name = fmt::format("(CAST {}, TO {})", child_name, _target_data_type_name);
+    _expr_name = fmt::format("(CAST {} TO {})", child_name, _target_data_type_name);
     return Status::OK();
 }
 
@@ -94,4 +93,21 @@ doris::Status VCastExpr::execute(VExprContext* context, doris::vectorized::Block
 const std::string& VCastExpr::expr_name() const {
     return _expr_name;
 }
-} // namespace doris::vectorized
\ No newline at end of file
+
+std::string VCastExpr::debug_string() const {
+    std::stringstream out;
+    out << "CastExpr(CAST " << _cast_param_data_type->get_name() << " to "
+        << _target_data_type->get_name() << "){";
+    bool first = true;
+    for (VExpr* input_expr : children()) {
+        if (first) {
+            first = false;
+        } else {
+            out << ",";
+        }
+        out << input_expr->debug_string();
+    }
+    out << "}";
+    return out.str();
+}
+} // namespace doris::vectorized
