@@ -20,11 +20,12 @@
 #include "fmt/format.h"
 #include "fmt/ranges.h"
 #include "runtime/descriptors.h"
+#include "vec/aggregate_functions/aggregate_function_java_udaf.h"
+#include "vec/aggregate_functions/aggregate_function_rpc.h"
 #include "vec/aggregate_functions/aggregate_function_simple_factory.h"
-#include "vec/columns/column_nullable.h"
+#include "vec/aggregate_functions/aggregate_function_sort.h"
 #include "vec/core/materialize_block.h"
 #include "vec/data_types/data_type_factory.hpp"
-#include "vec/data_types/data_type_nullable.h"
 #include "vec/exprs/vexpr.h"
 
 namespace doris::vectorized {
@@ -38,20 +39,23 @@ AggFnEvaluator::AggFnEvaluator(const TExprNode& desc)
           _exec_timer(nullptr),
           _merge_timer(nullptr),
           _expr_timer(nullptr) {
+    bool nullable = true;
     if (desc.__isset.is_nullable) {
-        _data_type = IDataType::from_thrift(_return_type.type, desc.is_nullable);
-    } else {
-        _data_type = IDataType::from_thrift(_return_type.type);
+        nullable = desc.is_nullable;
     }
+    _data_type = DataTypeFactory::instance().create_data_type(_return_type, nullable);
+
     if (desc.agg_expr.__isset.param_types) {
         auto& param_types = desc.agg_expr.param_types;
-        for (auto raw_type : param_types) {
-            _argument_types.push_back(DataTypeFactory::instance().create_data_type(raw_type));
+        for (int i = 0; i < param_types.size(); i++) {
+            _argument_types_with_sort.push_back(
+                    DataTypeFactory::instance().create_data_type(param_types[i]));
         }
     }
 }
 
-Status AggFnEvaluator::create(ObjectPool* pool, const TExpr& desc, AggFnEvaluator** result) {
+Status AggFnEvaluator::create(ObjectPool* pool, const TExpr& desc, const TSortInfo& sort_info,
+                              AggFnEvaluator** result) {
     *result = pool->add(new AggFnEvaluator(desc.nodes[0]));
     auto& agg_fn_evaluator = *result;
     int node_idx = 0;
@@ -59,24 +63,38 @@ Status AggFnEvaluator::create(ObjectPool* pool, const TExpr& desc, AggFnEvaluato
         ++node_idx;
         VExpr* expr = nullptr;
         VExprContext* ctx = nullptr;
-        RETURN_IF_ERROR(
-                VExpr::create_tree_from_thrift(pool, desc.nodes, NULL, &node_idx, &expr, &ctx));
+        RETURN_IF_ERROR(VExpr::create_tree_from_thrift(pool, desc.nodes, &node_idx, &expr, &ctx));
         agg_fn_evaluator->_input_exprs_ctxs.push_back(ctx);
     }
+
+    auto sort_size = sort_info.ordering_exprs.size();
+    auto real_arguments_size = agg_fn_evaluator->_argument_types_with_sort.size() - sort_size;
+    // Child arguments contains [real arguments, order by arguments], we pass the arguments
+    // to the order by functions
+    for (int i = 0; i < sort_size; ++i) {
+        agg_fn_evaluator->_sort_description.emplace_back(real_arguments_size + i,
+                                                         sort_info.is_asc_order[i] ? 1 : -1,
+                                                         sort_info.nulls_first[i] ? -1 : 1);
+    }
+
+    // Pass the real arguments to get functions
+    for (int i = 0; i < real_arguments_size; ++i) {
+        agg_fn_evaluator->_real_argument_types.emplace_back(
+                agg_fn_evaluator->_argument_types_with_sort[i]);
+    }
     return Status::OK();
 }
 
 Status AggFnEvaluator::prepare(RuntimeState* state, const RowDescriptor& desc, MemPool* pool,
                                const SlotDescriptor* intermediate_slot_desc,
-                               const SlotDescriptor* output_slot_desc,
-                               const std::shared_ptr<MemTracker>& mem_tracker) {
-    DCHECK(pool != NULL);
-    DCHECK(intermediate_slot_desc != NULL);
-    DCHECK(_intermediate_slot_desc == NULL);
+                               const SlotDescriptor* output_slot_desc) {
+    DCHECK(pool != nullptr);
+    DCHECK(intermediate_slot_desc != nullptr);
+    DCHECK(_intermediate_slot_desc == nullptr);
     _output_slot_desc = output_slot_desc;
     _intermediate_slot_desc = intermediate_slot_desc;
 
-    Status status = VExpr::prepare(_input_exprs_ctxs, state, desc, mem_tracker);
+    Status status = VExpr::prepare(_input_exprs_ctxs, state, desc);
     RETURN_IF_ERROR(status);
 
     DataTypes tmp_argument_types;
@@ -91,14 +109,32 @@ Status AggFnEvaluator::prepare(RuntimeState* state, const RowDescriptor& desc, M
         child_expr_name.emplace_back(_input_exprs_ctxs[i]->root()->expr_name());
     }
 
-    _function = AggregateFunctionSimpleFactory::instance().get(
-            _fn.name.function_name, _argument_types.empty() ? tmp_argument_types : _argument_types,
-            {}, _data_type->is_nullable());
+    const DataTypes& argument_types =
+            _real_argument_types.empty() ? tmp_argument_types : _real_argument_types;
+
+    if (_fn.binary_type == TFunctionBinaryType::JAVA_UDF) {
+        if (config::enable_java_support) {
+            _function = AggregateJavaUdaf::create(_fn, argument_types, {}, _data_type);
+            RETURN_IF_ERROR(static_cast<AggregateJavaUdaf*>(_function.get())->check_udaf(_fn));
+        } else {
+            return Status::InternalError(
+                    "Java UDAF is not enabled, you can change be config enable_java_support to "
+                    "true and restart be.");
+        }
+    } else if (_fn.binary_type == TFunctionBinaryType::RPC) {
+        _function = AggregateRpcUdaf::create(_fn, argument_types, {}, _data_type);
+    } else {
+        _function = AggregateFunctionSimpleFactory::instance().get(
+                _fn.name.function_name, argument_types, {}, _data_type->is_nullable());
+    }
     if (_function == nullptr) {
-        return Status::InternalError(
-                fmt::format("Agg Function {} is not implemented", _fn.name.function_name));
+        return Status::InternalError("Agg Function {} is not implemented", _fn.signature);
     }
 
+    if (!_sort_description.empty()) {
+        _function = transform_to_sort_agg_function(_function, _argument_types_with_sort,
+                                                   _sort_description, state);
+    }
     _expr_name = fmt::format("{}({})", _fn.name.function_name, child_expr_name);
     return Status::OK();
 }
@@ -117,23 +153,54 @@ void AggFnEvaluator::destroy(AggregateDataPtr place) {
     _function->destroy(place);
 }
 
-void AggFnEvaluator::execute_single_add(Block* block, AggregateDataPtr place, Arena* arena) {
-    _calc_argment_columns(block);
+Status AggFnEvaluator::execute_single_add(Block* block, AggregateDataPtr place, Arena* arena) {
+    RETURN_IF_ERROR(_calc_argment_columns(block));
     SCOPED_TIMER(_exec_timer);
     _function->add_batch_single_place(block->rows(), place, _agg_columns.data(), arena);
+    return Status::OK();
 }
 
-void AggFnEvaluator::execute_batch_add(Block* block, size_t offset, AggregateDataPtr* places,
-                                       Arena* arena) {
-    _calc_argment_columns(block);
+Status AggFnEvaluator::execute_batch_add(Block* block, size_t offset, AggregateDataPtr* places,
+                                         Arena* arena, bool agg_many) {
+    RETURN_IF_ERROR(_calc_argment_columns(block));
     SCOPED_TIMER(_exec_timer);
-    _function->add_batch(block->rows(), places, offset, _agg_columns.data(), arena);
+    _function->add_batch(block->rows(), places, offset, _agg_columns.data(), arena, agg_many);
+    return Status::OK();
+}
+
+Status AggFnEvaluator::execute_batch_add_selected(Block* block, size_t offset,
+                                                  AggregateDataPtr* places, Arena* arena) {
+    RETURN_IF_ERROR(_calc_argment_columns(block));
+    SCOPED_TIMER(_exec_timer);
+    _function->add_batch_selected(block->rows(), places, offset, _agg_columns.data(), arena);
+    return Status::OK();
+}
+
+Status AggFnEvaluator::streaming_agg_serialize(Block* block, BufferWritable& buf,
+                                               const size_t num_rows, Arena* arena) {
+    RETURN_IF_ERROR(_calc_argment_columns(block));
+    SCOPED_TIMER(_exec_timer);
+    _function->streaming_agg_serialize(_agg_columns.data(), buf, num_rows, arena);
+    return Status::OK();
+}
+
+Status AggFnEvaluator::streaming_agg_serialize_to_column(Block* block, MutableColumnPtr& dst,
+                                                         const size_t num_rows, Arena* arena) {
+    RETURN_IF_ERROR(_calc_argment_columns(block));
+    SCOPED_TIMER(_exec_timer);
+    _function->streaming_agg_serialize_to_column(_agg_columns.data(), dst, num_rows, arena);
+    return Status::OK();
 }
 
 void AggFnEvaluator::insert_result_info(AggregateDataPtr place, IColumn* column) {
     _function->insert_result_into(place, *column);
 }
 
+void AggFnEvaluator::insert_result_info_vec(const std::vector<AggregateDataPtr>& places,
+                                            size_t offset, IColumn* column, const size_t num_rows) {
+    _function->insert_result_into_vec(places, offset, *column, num_rows);
+}
+
 void AggFnEvaluator::reset(AggregateDataPtr place) {
     _function->reset(place);
 }
@@ -157,19 +224,20 @@ std::string AggFnEvaluator::debug_string() const {
     return out.str();
 }
 
-void AggFnEvaluator::_calc_argment_columns(Block* block) {
+Status AggFnEvaluator::_calc_argment_columns(Block* block) {
     SCOPED_TIMER(_expr_timer);
     _agg_columns.resize(_input_exprs_ctxs.size());
     int column_ids[_input_exprs_ctxs.size()];
     for (int i = 0; i < _input_exprs_ctxs.size(); ++i) {
         int column_id = -1;
-        _input_exprs_ctxs[i]->execute(block, &column_id);
+        RETURN_IF_ERROR(_input_exprs_ctxs[i]->execute(block, &column_id));
         column_ids[i] = column_id;
     }
     materialize_block_inplace(*block, column_ids, column_ids + _input_exprs_ctxs.size());
     for (int i = 0; i < _input_exprs_ctxs.size(); ++i) {
         _agg_columns[i] = block->get_by_position(column_ids[i]).column.get();
     }
+    return Status::OK();
 }
 
 } // namespace doris::vectorized
