@@ -25,11 +25,21 @@
 #include "common/status.h"
 #include "vec/core/block.h"
 #include "vec/core/column_numbers.h"
-#include "vec/core/names.h"
 #include "vec/data_types/data_type.h"
 
 namespace doris::vectorized {
 
+#define RETURN_REAL_TYPE_FOR_DATEV2_FUNCTION(TYPE)                                       \
+    bool is_nullable = false;                                                            \
+    bool is_datev2 = false;                                                              \
+    for (auto it : arguments) {                                                          \
+        is_nullable = is_nullable || it.type->is_nullable();                             \
+        is_datev2 = is_datev2 || WhichDataType(remove_nullable(it.type)).is_date_v2() || \
+                    WhichDataType(remove_nullable(it.type)).is_date_time_v2();           \
+    }                                                                                    \
+    return is_nullable || !is_datev2 ? make_nullable(std::make_shared<TYPE>())           \
+                                     : std::make_shared<TYPE>();
+
 class Field;
 
 // Only use dispose the variadic argument
@@ -37,6 +47,14 @@ template <typename T>
 auto has_variadic_argument_types(T&& arg) -> decltype(T::get_variadic_argument_types()) {};
 void has_variadic_argument_types(...);
 
+struct NullPresence {
+    bool has_nullable = false;
+    bool has_null_constant = false;
+};
+
+NullPresence get_null_presence(const Block& block, const ColumnNumbers& args);
+[[maybe_unused]] NullPresence get_null_presence(const ColumnsWithTypeAndName& args);
+
 /// The simplest executable object.
 /// Motivation:
 ///  * Prepare something heavy once before main execution loop instead of doing it for each block.
@@ -293,8 +311,36 @@ public:
                 is_date_or_datetime(get_return_type(arguments)->is_nullable()
                                             ? ((DataTypeNullable*)get_return_type(arguments).get())
                                                       ->get_nested_type()
-                                            : get_return_type(arguments))))
-                << " with " << return_type->get_name() << " and " << func_return_type->get_name();
+                                            : get_return_type(arguments))) ||
+               (is_date_v2_or_datetime_v2(
+                        return_type->is_nullable()
+                                ? ((DataTypeNullable*)return_type.get())->get_nested_type()
+                                : return_type) &&
+                is_date_v2_or_datetime_v2(
+                        get_return_type(arguments)->is_nullable()
+                                ? ((DataTypeNullable*)get_return_type(arguments).get())
+                                          ->get_nested_type()
+                                : get_return_type(arguments))) ||
+               // For some date functions such as str_to_date(string, string), return_type will
+               // be datetimev2 if users enable datev2 but get_return_type(arguments) will still
+               // return datetime. We need keep backward compatibility here.
+               (is_date_v2_or_datetime_v2(
+                        return_type->is_nullable()
+                                ? ((DataTypeNullable*)return_type.get())->get_nested_type()
+                                : return_type) &&
+                is_date_or_datetime(get_return_type(arguments)->is_nullable()
+                                            ? ((DataTypeNullable*)get_return_type(arguments).get())
+                                                      ->get_nested_type()
+                                            : get_return_type(arguments))) ||
+               (is_decimal(return_type->is_nullable()
+                                   ? ((DataTypeNullable*)return_type.get())->get_nested_type()
+                                   : return_type) &&
+                is_decimal(get_return_type(arguments)->is_nullable()
+                                   ? ((DataTypeNullable*)get_return_type(arguments).get())
+                                             ->get_nested_type()
+                                   : get_return_type(arguments))))
+                << " for function '" << this->get_name() << "' with " << return_type->get_name()
+                << " and " << func_return_type->get_name();
 
         return build_impl(arguments, return_type);
     }
