@@ -21,13 +21,18 @@
 #include "gutil/strings/numbers.h"
 #include "gutil/strings/split.h"
 #include "util/string_parser.hpp"
+#include "vec/columns/column.h"
+#include "vec/columns/column_array.h"
+#include "vec/columns/columns_number.h"
+#include "vec/data_types/data_type_array.h"
+#include "vec/data_types/data_type_number.h"
+#include "vec/data_types/data_type_string.h"
 #include "vec/functions/function_always_not_nullable.h"
 #include "vec/functions/function_bitmap_min_or_max.h"
 #include "vec/functions/function_const.h"
 #include "vec/functions/function_string.h"
 #include "vec/functions/function_totype.h"
 #include "vec/functions/simple_function_factory.h"
-
 namespace doris::vectorized {
 
 struct BitmapEmpty {
@@ -41,34 +46,52 @@ struct ToBitmap {
     static constexpr auto name = "to_bitmap";
     using ReturnType = DataTypeBitMap;
 
-    static void vector(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                       MutableColumnPtr& col_res) {
-        execute<false>(data, offsets, nullptr, col_res);
+    template <typename ColumnType>
+    static void vector(const ColumnType* col, MutableColumnPtr& col_res) {
+        execute<ColumnType, false>(col, nullptr, col_res);
     }
-
-    static void vector_nullable(const ColumnString::Chars& data,
-                                const ColumnString::Offsets& offsets, const NullMap& nullmap,
+    template <typename ColumnType>
+    static void vector_nullable(const ColumnType* col, const NullMap& nullmap,
                                 MutableColumnPtr& col_res) {
-        execute<true>(data, offsets, &nullmap, col_res);
+        execute<ColumnType, true>(col, &nullmap, col_res);
     }
-    template <bool arg_is_nullable>
-    static void execute(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                        const NullMap* nullmap, MutableColumnPtr& col_res) {
-        auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
-        auto& res_data = res_column->get_data();
-        size_t size = offsets.size();
+    template <typename ColumnType, bool arg_is_nullable>
+    static void execute(const ColumnType* col, const NullMap* nullmap, MutableColumnPtr& col_res) {
+        if constexpr (std::is_same_v<ColumnType, ColumnString>) {
+            const ColumnString::Chars& data = col->get_chars();
+            const ColumnString::Offsets& offsets = col->get_offsets();
 
-        for (size_t i = 0; i < size; ++i) {
-            if (arg_is_nullable && ((*nullmap)[i])) {
-                continue;
-            } else {
-                const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
-                size_t str_size = offsets[i] - offsets[i - 1] - 1;
-                StringParser::ParseResult parse_result = StringParser::PARSE_SUCCESS;
-                uint64_t int_value = StringParser::string_to_unsigned_int<uint64_t>(
-                        raw_str, str_size, &parse_result);
-                if (LIKELY(parse_result == StringParser::PARSE_SUCCESS)) {
-                    res_data[i].add(int_value);
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = offsets.size();
+
+            for (size_t i = 0; i < size; ++i) {
+                if (arg_is_nullable && ((*nullmap)[i])) {
+                    continue;
+                } else {
+                    const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
+                    size_t str_size = offsets[i] - offsets[i - 1];
+                    StringParser::ParseResult parse_result = StringParser::PARSE_SUCCESS;
+                    uint64_t int_value = StringParser::string_to_unsigned_int<uint64_t>(
+                            raw_str, str_size, &parse_result);
+                    if (LIKELY(parse_result == StringParser::PARSE_SUCCESS)) {
+                        res_data[i].add(int_value);
+                    }
+                }
+            }
+        } else if constexpr (std::is_same_v<ColumnType, ColumnInt64>) {
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = col->size();
+
+            for (size_t i = 0; i < size; ++i) {
+                if (arg_is_nullable && ((*nullmap)[i])) {
+                    continue;
+                } else {
+                    int64_t int_value = col->get_data()[i];
+                    if (LIKELY(int_value >= 0)) {
+                        res_data[i].add(int_value);
+                    }
                 }
             }
         }
@@ -79,61 +102,100 @@ struct ToBitmapWithCheck {
     static constexpr auto name = "to_bitmap_with_check";
     using ReturnType = DataTypeBitMap;
 
-    static Status vector(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                         MutableColumnPtr& col_res) {
-        return execute<false>(data, offsets, nullptr, col_res);
+    template <typename ColumnType>
+    static Status vector(const ColumnType* col, MutableColumnPtr& col_res) {
+        return execute<ColumnType, false>(col, nullptr, col_res);
     }
-
-    static Status vector_nullable(const ColumnString::Chars& data,
-                                  const ColumnString::Offsets& offsets, const NullMap& nullmap,
+    template <typename ColumnType>
+    static Status vector_nullable(const ColumnType* col, const NullMap& nullmap,
                                   MutableColumnPtr& col_res) {
-        return execute<true>(data, offsets, &nullmap, col_res);
+        return execute<ColumnType, true>(col, &nullmap, col_res);
     }
-    template <bool arg_is_nullable>
-    static Status execute(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                          const NullMap* nullmap, MutableColumnPtr& col_res) {
-        auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
-        auto& res_data = res_column->get_data();
-        size_t size = offsets.size();
+    template <typename ColumnType, bool arg_is_nullable>
+    static Status execute(const ColumnType* col, const NullMap* nullmap,
+                          MutableColumnPtr& col_res) {
+        if constexpr (std::is_same_v<ColumnType, ColumnString>) {
+            const ColumnString::Chars& data = col->get_chars();
+            const ColumnString::Offsets& offsets = col->get_offsets();
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = offsets.size();
 
-        for (size_t i = 0; i < size; ++i) {
-            if (arg_is_nullable && ((*nullmap)[i])) {
-                continue;
-            } else {
-                const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
-                size_t str_size = offsets[i] - offsets[i - 1] - 1;
-                StringParser::ParseResult parse_result = StringParser::PARSE_SUCCESS;
-                uint64_t int_value = StringParser::string_to_unsigned_int<uint64_t>(
-                        raw_str, str_size, &parse_result);
-                if (LIKELY(parse_result == StringParser::PARSE_SUCCESS)) {
-                    res_data[i].add(int_value);
+            for (size_t i = 0; i < size; ++i) {
+                if (arg_is_nullable && ((*nullmap)[i])) {
+                    continue;
                 } else {
-                    std::stringstream ss;
-                    ss << "The input: " << std::string(raw_str, str_size)
-                       << " is not valid, to_bitmap only support bigint value from 0 to "
-                          "18446744073709551615 currently, cannot create MV with to_bitmap on "
-                          "column with negative values or cannot load negative values to column "
-                          "with to_bitmap MV on it.";
-                    LOG(WARNING) << ss.str();
-                    return Status::InternalError(ss.str());
+                    const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
+                    size_t str_size = offsets[i] - offsets[i - 1];
+                    StringParser::ParseResult parse_result = StringParser::PARSE_SUCCESS;
+                    uint64_t int_value = StringParser::string_to_unsigned_int<uint64_t>(
+                            raw_str, str_size, &parse_result);
+                    if (LIKELY(parse_result == StringParser::PARSE_SUCCESS)) {
+                        res_data[i].add(int_value);
+                    } else {
+                        std::stringstream ss;
+                        ss << "The input: " << std::string(raw_str, str_size)
+                           << " is not valid, to_bitmap only support bigint value from 0 to "
+                              "18446744073709551615 currently, cannot create MV with to_bitmap on "
+                              "column with negative values or cannot load negative values to "
+                              "column "
+                              "with to_bitmap MV on it.";
+                        LOG(WARNING) << ss.str();
+                        return Status::InternalError(ss.str());
+                    }
                 }
             }
+        } else if constexpr (std::is_same_v<ColumnType, ColumnInt64>) {
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = col->size();
+
+            for (size_t i = 0; i < size; ++i) {
+                if (arg_is_nullable && ((*nullmap)[i])) {
+                    continue;
+                } else {
+                    int64_t int_value = col->get_data()[i];
+                    if (LIKELY(int_value >= 0)) {
+                        res_data[i].add(int_value);
+                    } else {
+                        std::stringstream ss;
+                        ss << "The input: " << int_value
+                           << " is not valid, to_bitmap only support bigint value from 0 to "
+                              "18446744073709551615 currently, cannot create MV with to_bitmap on "
+                              "column with negative values or cannot load negative values to "
+                              "column "
+                              "with to_bitmap MV on it.";
+                        LOG(WARNING) << ss.str();
+                        return Status::InternalError(ss.str());
+                    }
+                }
+            }
+        } else {
+            return Status::InternalError("not support type");
         }
         return Status::OK();
     }
 };
 
 struct BitmapFromString {
+    using ArgumentType = DataTypeString;
+
     static constexpr auto name = "bitmap_from_string";
 
     static Status vector(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                         std::vector<BitmapValue>& res, NullMap& null_map) {
-        auto size = offsets.size();
-        res.reserve(size);
+                         std::vector<BitmapValue>& res, NullMap& null_map,
+                         size_t input_rows_count) {
+        res.reserve(input_rows_count);
         std::vector<uint64_t> bits;
-        for (size_t i = 0; i < size; ++i) {
+        if (offsets.size() == 0 && input_rows_count == 1) {
+            // For NULL constant
+            res.emplace_back();
+            null_map[0] = 1;
+            return Status::OK();
+        }
+        for (size_t i = 0; i < input_rows_count; ++i) {
             const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
-            int64_t str_size = offsets[i] - offsets[i - 1] - 1;
+            int64_t str_size = offsets[i] - offsets[i - 1];
 
             if ((str_size > INT32_MAX) ||
                 !(SplitStringAndParse({raw_str, (int)str_size}, ",", &safe_strtou64, &bits))) {
@@ -148,6 +210,42 @@ struct BitmapFromString {
     }
 };
 
+struct BitmapFromArray {
+    using ArgumentType = DataTypeArray;
+    static constexpr auto name = "bitmap_from_array";
+
+    template <typename ColumnType>
+    static Status vector(const ColumnArray::Offsets64& offset_column_data,
+                         const IColumn& nested_column, const NullMap& nested_null_map,
+                         std::vector<BitmapValue>& res, NullMap& null_map) {
+        const auto& nested_column_data = static_cast<const ColumnType&>(nested_column).get_data();
+        auto size = offset_column_data.size();
+        res.reserve(size);
+        std::vector<uint64_t> bits;
+        for (size_t i = 0; i < size; ++i) {
+            auto curr_offset = offset_column_data[i];
+            auto prev_offset = offset_column_data[i - 1];
+            for (auto j = prev_offset; j < curr_offset; ++j) {
+                auto data = nested_column_data[j];
+                // invaild value
+                if (UNLIKELY(data < 0) || UNLIKELY(nested_null_map[j])) {
+                    res.emplace_back();
+                    null_map[i] = 1;
+                    break;
+                } else {
+                    bits.push_back(data);
+                }
+            }
+            //input is valid value
+            if (!null_map[i]) {
+                res.emplace_back(bits);
+                bits.clear();
+            }
+        }
+        return Status::OK();
+    }
+};
+
 template <typename Impl>
 class FunctionBitmapAlwaysNull : public IFunction {
 public:
@@ -176,12 +274,39 @@ public:
 
         ColumnPtr argument_column =
                 block.get_by_position(arguments[0]).column->convert_to_full_column_if_const();
-        const ColumnString* str_column = check_and_get_column<ColumnString>(argument_column.get());
-        const ColumnString::Chars& data = str_column->get_chars();
-        const ColumnString::Offsets& offsets = str_column->get_offsets();
-
-        Impl::vector(data, offsets, res, null_map);
-
+        if constexpr (std::is_same_v<typename Impl::ArgumentType, DataTypeString>) {
+            const auto& str_column = static_cast<const ColumnString&>(*argument_column);
+            const ColumnString::Chars& data = str_column.get_chars();
+            const ColumnString::Offsets& offsets = str_column.get_offsets();
+            Impl::vector(data, offsets, res, null_map, input_rows_count);
+        } else if constexpr (std::is_same_v<typename Impl::ArgumentType, DataTypeArray>) {
+            auto argument_type = remove_nullable(
+                    assert_cast<const DataTypeArray&>(*block.get_by_position(arguments[0]).type)
+                            .get_nested_type());
+            const auto& array_column = static_cast<const ColumnArray&>(*argument_column);
+            const auto& offset_column_data = array_column.get_offsets();
+            const auto& nested_nullable_column =
+                    static_cast<const ColumnNullable&>(array_column.get_data());
+            const auto& nested_column = nested_nullable_column.get_nested_column();
+            const auto& nested_null_map = nested_nullable_column.get_null_map_column().get_data();
+            if (check_column<ColumnInt8>(nested_column)) {
+                Impl::template vector<ColumnInt8>(offset_column_data, nested_column,
+                                                  nested_null_map, res, null_map);
+            } else if (check_column<ColumnInt16>(nested_column)) {
+                Impl::template vector<ColumnInt16>(offset_column_data, nested_column,
+                                                   nested_null_map, res, null_map);
+            } else if (check_column<ColumnInt32>(nested_column)) {
+                Impl::template vector<ColumnInt32>(offset_column_data, nested_column,
+                                                   nested_null_map, res, null_map);
+            } else if (check_column<ColumnInt64>(nested_column)) {
+                Impl::template vector<ColumnInt64>(offset_column_data, nested_column,
+                                                   nested_null_map, res, null_map);
+            }
+        } else {
+            return Status::RuntimeError("Illegal column {} of argument of function {}",
+                                        block.get_by_position(arguments[0]).column->get_name(),
+                                        get_name());
+        }
         block.get_by_position(result).column =
                 ColumnNullable::create(std::move(res_data_column), std::move(res_null_map));
         return Status::OK();
@@ -207,40 +332,18 @@ struct BitmapHash {
 
     using ReturnType = DataTypeBitMap;
 
-    static void vector(const ColumnString::Chars& data, const ColumnString::Offsets& offsets,
-                       MutableColumnPtr& col_res) {
-        auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
-        auto& res_data = res_column->get_data();
-        size_t size = offsets.size();
+    template <typename ColumnType>
+    static void vector(const ColumnType* col, MutableColumnPtr& col_res) {
+        if constexpr (std::is_same_v<ColumnType, ColumnString>) {
+            const ColumnString::Chars& data = col->get_chars();
+            const ColumnString::Offsets& offsets = col->get_offsets();
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = offsets.size();
 
-        for (size_t i = 0; i < size; ++i) {
-            const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
-            size_t str_size = offsets[i] - offsets[i - 1] - 1;
-            if constexpr (HashBits == 32) {
-                uint32_t hash_value =
-                        HashUtil::murmur_hash3_32(raw_str, str_size, HashUtil::MURMUR3_32_SEED);
-                res_data[i].add(hash_value);
-            } else {
-                uint64_t hash_value = 0;
-                murmur_hash3_x64_64(raw_str, str_size, 0, &hash_value);
-                res_data[i].add(hash_value);
-            }
-        }
-    }
-
-    static void vector_nullable(const ColumnString::Chars& data,
-                                const ColumnString::Offsets& offsets, const NullMap& nullmap,
-                                MutableColumnPtr& col_res) {
-        auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
-        auto& res_data = res_column->get_data();
-        size_t size = offsets.size();
-
-        for (size_t i = 0; i < size; ++i) {
-            if (nullmap[i]) {
-                continue;
-            } else {
+            for (size_t i = 0; i < size; ++i) {
                 const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
-                size_t str_size = offsets[i] - offsets[i - 1] - 1;
+                size_t str_size = offsets[i] - offsets[i - 1];
                 if constexpr (HashBits == 32) {
                     uint32_t hash_value =
                             HashUtil::murmur_hash3_32(raw_str, str_size, HashUtil::MURMUR3_32_SEED);
@@ -253,6 +356,36 @@ struct BitmapHash {
             }
         }
     }
+
+    template <typename ColumnType>
+    static void vector_nullable(const ColumnType* col, const NullMap& nullmap,
+                                MutableColumnPtr& col_res) {
+        if constexpr (std::is_same_v<ColumnType, ColumnString>) {
+            const ColumnString::Chars& data = col->get_chars();
+            const ColumnString::Offsets& offsets = col->get_offsets();
+            auto* res_column = reinterpret_cast<ColumnBitmap*>(col_res.get());
+            auto& res_data = res_column->get_data();
+            size_t size = offsets.size();
+
+            for (size_t i = 0; i < size; ++i) {
+                if (nullmap[i]) {
+                    continue;
+                } else {
+                    const char* raw_str = reinterpret_cast<const char*>(&data[offsets[i - 1]]);
+                    size_t str_size = offsets[i] - offsets[i - 1];
+                    if constexpr (HashBits == 32) {
+                        uint32_t hash_value = HashUtil::murmur_hash3_32(raw_str, str_size,
+                                                                        HashUtil::MURMUR3_32_SEED);
+                        res_data[i].add(hash_value);
+                    } else {
+                        uint64_t hash_value = 0;
+                        murmur_hash3_x64_64(raw_str, str_size, 0, &hash_value);
+                        res_data[i].add(hash_value);
+                    }
+                }
+            }
+        }
+    }
 };
 
 class FunctionBitmapCount : public IFunction {
@@ -357,9 +490,9 @@ struct BitmapAndNotCount {
     using T0 = typename LeftDataType::FieldType;
     using T1 = typename RightDataType::FieldType;
     using TData = std::vector<BitmapValue>;
-    using ResTData = typename ColumnVector<Int64>::Container;
+    using ResTData = typename ColumnVector<Int64>::Container::value_type;
 
-    static Status vector_vector(const TData& lvec, const TData& rvec, ResTData& res) {
+    static Status vector_vector(const TData& lvec, const TData& rvec, ResTData* res) {
         size_t size = lvec.size();
         BitmapValue mid_data;
         for (size_t i = 0; i < size; ++i) {
@@ -372,6 +505,153 @@ struct BitmapAndNotCount {
     }
 };
 
+void update_bitmap_op_count(int64_t* __restrict count, const NullMap& null_map) {
+    static constexpr int64_t flags[2] = {-1, 0};
+    size_t size = null_map.size();
+    auto* __restrict null_map_data = null_map.data();
+    for (size_t i = 0; i < size; ++i) {
+        count[i] &= flags[null_map_data[i]];
+    }
+}
+
+// for bitmap_and_count, bitmap_xor_count and bitmap_and_not_count,
+// result is 0 for rows that if any column is null value
+ColumnPtr handle_bitmap_op_count_null_value(ColumnPtr& src, const Block& block,
+                                            const ColumnNumbers& args, size_t result,
+                                            size_t input_rows_count) {
+    auto* nullable = assert_cast<const ColumnNullable*>(src.get());
+    ColumnPtr src_not_nullable = nullable->get_nested_column_ptr();
+    MutableColumnPtr src_not_nullable_mutable = (*std::move(src_not_nullable)).assume_mutable();
+    auto* __restrict count_data =
+            assert_cast<ColumnInt64*>(src_not_nullable_mutable.get())->get_data().data();
+
+    for (const auto& arg : args) {
+        const ColumnWithTypeAndName& elem = block.get_by_position(arg);
+        if (!elem.type->is_nullable()) {
+            continue;
+        }
+
+        bool is_const = is_column_const(*elem.column);
+        /// Const Nullable that are NULL.
+        if (is_const && assert_cast<const ColumnConst*>(elem.column.get())->only_null()) {
+            return block.get_by_position(result).type->create_column_const(input_rows_count, 0);
+        }
+        if (is_const) {
+            continue;
+        }
+
+        if (auto* nullable = assert_cast<const ColumnNullable*>(elem.column.get())) {
+            const ColumnPtr& null_map_column = nullable->get_null_map_column_ptr();
+            const NullMap& src_null_map =
+                    assert_cast<const ColumnUInt8&>(*null_map_column).get_data();
+
+            update_bitmap_op_count(count_data, src_null_map);
+        }
+    }
+
+    return src;
+}
+
+Status execute_bitmap_op_count_null_to_zero(
+        FunctionContext* context, Block& block, const ColumnNumbers& arguments, size_t result,
+        size_t input_rows_count,
+        const std::function<Status(FunctionContext*, Block&, const ColumnNumbers&, size_t, size_t)>&
+                exec_impl_func) {
+    NullPresence null_presence = get_null_presence(block, arguments);
+
+    if (null_presence.has_null_constant) {
+        block.get_by_position(result).column =
+                block.get_by_position(result).type->create_column_const(input_rows_count, 0);
+    } else if (null_presence.has_nullable) {
+        auto [temporary_block, new_args, new_result] =
+                create_block_with_nested_columns(block, arguments, result);
+        RETURN_IF_ERROR(exec_impl_func(context, temporary_block, new_args, new_result,
+                                       temporary_block.rows()));
+        block.get_by_position(result).column = handle_bitmap_op_count_null_value(
+                temporary_block.get_by_position(new_result).column, block, arguments, result,
+                input_rows_count);
+    } else {
+        return exec_impl_func(context, block, arguments, result, input_rows_count);
+    }
+    return Status::OK();
+}
+
+class FunctionBitmapAndNotCount : public IFunction {
+public:
+    using LeftDataType = DataTypeBitMap;
+    using RightDataType = DataTypeBitMap;
+    using ResultDataType = typename BitmapAndNotCount<LeftDataType, RightDataType>::ResultDataType;
+
+    static constexpr auto name = "bitmap_and_not_count";
+    static FunctionPtr create() { return std::make_shared<FunctionBitmapAndNotCount>(); }
+    String get_name() const override { return name; }
+    size_t get_number_of_arguments() const override { return 2; }
+    DataTypePtr get_return_type_impl(const DataTypes& arguments) const override {
+        bool return_nullable = false;
+        // result is nullable only when any columns is nullable for bitmap_and_not_count
+        for (size_t i = 0; i < arguments.size(); ++i) {
+            if (arguments[i]->is_nullable()) {
+                return_nullable = true;
+                break;
+            }
+        }
+        auto result_type = std::make_shared<ResultDataType>();
+        return return_nullable ? make_nullable(result_type) : result_type;
+    }
+
+    bool use_default_implementation_for_constants() const override { return true; }
+
+    bool use_default_implementation_for_nulls() const override {
+        // for bitmap_and_not_count, result is always not null, and if the bitmap op result is null,
+        // the count is 0
+        return false;
+    }
+
+    Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
+                        size_t result, size_t input_rows_count) override {
+        DCHECK_EQ(arguments.size(), 2);
+
+        return execute_bitmap_op_count_null_to_zero(
+                context, block, arguments, result, input_rows_count,
+                std::bind((Status(FunctionBitmapAndNotCount::*)(
+                                  FunctionContext*, Block&, const ColumnNumbers&, size_t, size_t)) &
+                                  FunctionBitmapAndNotCount::execute_impl_internal,
+                          this, std::placeholders::_1, std::placeholders::_2, std::placeholders::_3,
+                          std::placeholders::_4, std::placeholders::_5));
+    }
+
+    Status execute_impl_internal(FunctionContext* context, Block& block,
+                                 const ColumnNumbers& arguments, size_t result,
+                                 size_t input_rows_count) {
+        const auto& left = block.get_by_position(arguments[0]);
+        auto lcol = left.column->convert_to_full_column_if_const();
+        const auto& right = block.get_by_position(arguments[1]);
+        auto rcol = right.column->convert_to_full_column_if_const();
+
+        using ResultType = typename ResultDataType::FieldType;
+        using ColVecResult = ColumnVector<ResultType>;
+
+        typename ColVecResult::MutablePtr col_res = ColVecResult::create();
+        auto& vec_res = col_res->get_data();
+        vec_res.resize(block.rows());
+
+        const ColumnBitmap* l_bitmap_col = assert_cast<const ColumnBitmap*>(lcol.get());
+        const ColumnBitmap* r_bitmap_col = assert_cast<const ColumnBitmap*>(rcol.get());
+        BitmapAndNotCount<LeftDataType, RightDataType>::vector_vector(
+                l_bitmap_col->get_data(), r_bitmap_col->get_data(), vec_res.data());
+
+        auto& result_info = block.get_by_position(result);
+        if (result_info.type->is_nullable()) {
+            block.replace_by_position(
+                    result, ColumnNullable::create(std::move(col_res),
+                                                   ColumnUInt8::create(input_rows_count, 0)));
+        } else {
+            block.replace_by_position(result, std::move(col_res));
+        }
+        return Status::OK();
+    }
+};
+
 struct NameBitmapContains {
     static constexpr auto name = "bitmap_contains";
 };
@@ -582,10 +862,61 @@ public:
     }
 };
 
+class FunctionBitmapToArray : public IFunction {
+public:
+    static constexpr auto name = "bitmap_to_array";
+
+    String get_name() const override { return name; }
+
+    static FunctionPtr create() { return std::make_shared<FunctionBitmapToArray>(); }
+
+    DataTypePtr get_return_type_impl(const DataTypes& arguments) const override {
+        auto nested_type = make_nullable(std::make_shared<DataTypeInt64>());
+        return std::make_shared<DataTypeArray>(nested_type);
+    }
+
+    size_t get_number_of_arguments() const override { return 1; }
+
+    bool use_default_implementation_for_nulls() const override { return true; }
+
+    Status execute_impl(FunctionContext* context, Block& block, const ColumnNumbers& arguments,
+                        size_t result, size_t input_rows_count) override {
+        auto return_nested_type = make_nullable(std::make_shared<DataTypeInt64>());
+        auto dest_array_column_ptr = ColumnArray::create(return_nested_type->create_column(),
+                                                         ColumnArray::ColumnOffsets::create());
+
+        IColumn* dest_nested_column = &dest_array_column_ptr->get_data();
+        ColumnNullable* dest_nested_nullable_col =
+                reinterpret_cast<ColumnNullable*>(dest_nested_column);
+        dest_nested_column = dest_nested_nullable_col->get_nested_column_ptr();
+        auto& dest_nested_null_map = dest_nested_nullable_col->get_null_map_column().get_data();
+
+        auto arg_col =
+                block.get_by_position(arguments[0]).column->convert_to_full_column_if_const();
+        auto bitmap_col = assert_cast<const ColumnBitmap*>(arg_col.get());
+        const auto& bitmap_col_data = bitmap_col->get_data();
+        auto& nested_column_data =
+                assert_cast<ColumnVector<Int64>*>(dest_nested_column)->get_data();
+        auto& dest_offsets = dest_array_column_ptr->get_offsets();
+        dest_offsets.reserve(input_rows_count);
+
+        for (int i = 0; i < input_rows_count; ++i) {
+            bitmap_col_data[i].to_array(nested_column_data);
+            dest_nested_null_map.resize_fill(nested_column_data.size(), 0);
+            dest_offsets.push_back(nested_column_data.size());
+        }
+
+        block.replace_by_position(result, std::move(dest_array_column_ptr));
+        return Status::OK();
+    }
+};
+
 using FunctionBitmapEmpty = FunctionConst<BitmapEmpty, false>;
 using FunctionToBitmap = FunctionAlwaysNotNullable<ToBitmap>;
 using FunctionToBitmapWithCheck = FunctionAlwaysNotNullable<ToBitmapWithCheck, true>;
+
 using FunctionBitmapFromString = FunctionBitmapAlwaysNull<BitmapFromString>;
+using FunctionBitmapFromArray = FunctionBitmapAlwaysNull<BitmapFromArray>;
 using FunctionBitmapHash = FunctionAlwaysNotNullable<BitmapHash<32>>;
 using FunctionBitmapHash64 = FunctionAlwaysNotNullable<BitmapHash<64>>;
 
@@ -597,8 +928,6 @@ using FunctionBitmapNot =
         FunctionBinaryToType<DataTypeBitMap, DataTypeBitMap, BitmapNot, NameBitmapNot>;
 using FunctionBitmapAndNot =
         FunctionBinaryToType<DataTypeBitMap, DataTypeBitMap, BitmapAndNot, NameBitmapAndNot>;
-using FunctionBitmapAndNotCount = FunctionBinaryToType<DataTypeBitMap, DataTypeBitMap,
-                                                       BitmapAndNotCount, NameBitmapAndNotCount>;
 using FunctionBitmapContains =
         FunctionBinaryToType<DataTypeBitMap, DataTypeInt64, BitmapContains, NameBitmapContains>;
 
@@ -615,6 +944,7 @@ void register_function_bitmap(SimpleFunctionFactory& factory) {
     factory.register_function<FunctionToBitmap>();
     factory.register_function<FunctionToBitmapWithCheck>();
     factory.register_function<FunctionBitmapFromString>();
+    factory.register_function<FunctionBitmapFromArray>();
     factory.register_function<FunctionBitmapHash>();
     factory.register_function<FunctionBitmapHash64>();
     factory.register_function<FunctionBitmapCount>();
@@ -630,6 +960,7 @@ void register_function_bitmap(SimpleFunctionFactory& factory) {
     factory.register_function<FunctionSubBitmap>();
     factory.register_function<FunctionBitmapSubsetLimit>();
     factory.register_function<FunctionBitmapSubsetInRange>();
+    factory.register_function<FunctionBitmapToArray>();
 }
 
 } // namespace doris::vectorized
