@@ -130,7 +130,7 @@ public:
             : vec(in[in.size() - N]->get_data()), next(in) {}
 
     /// Returns a combination of values in the i-th row of all columns stored in the constructor.
-    inline ResultValueType apply(const size_t i) const {
+    ResultValueType apply(const size_t i) const {
         const auto& a = vec[i];
         if constexpr (Op::is_saturable())
             return Op::is_saturated_value(a) ? a : Op::apply(a, next.apply(i));
@@ -150,7 +150,7 @@ class AssociativeApplierImpl<Op, 1> {
 public:
     AssociativeApplierImpl(const UInt8ColumnPtrs& in) : vec(in[in.size() - 1]->get_data()) {}
 
-    inline ResultValueType apply(const size_t i) const { return vec[i]; }
+    ResultValueType apply(const size_t i) const { return vec[i]; }
 
 private:
     const UInt8Container& vec;
@@ -207,7 +207,7 @@ public:
             : val_getter {ValueGetterBuilder::build(in[in.size() - N])}, next {in} {}
 
     /// Returns a combination of values in the i-th row of all columns stored in the constructor.
-    inline ResultValueType apply(const size_t i) const {
+    ResultValueType apply(const size_t i) const {
         const auto a = val_getter(i);
         if constexpr (Op::is_saturable())
             return Op::is_saturated_value(a) ? a : Op::apply(a, next.apply(i));
@@ -449,20 +449,14 @@ Status FunctionAnyArityLogical<Impl, Name>::execute_impl(FunctionContext* contex
                                                          size_t result_index,
                                                          size_t input_rows_count) {
     ColumnRawPtrs args_in;
-    bool is_nullable = false;
-    for (const auto arg_index : arguments) {
-        auto& data = block.get_by_position(arg_index);
-        args_in.push_back(data.column.get());
-        is_nullable |= data.column->is_nullable();
-    }
+    for (const auto arg_index : arguments)
+        args_in.push_back(block.get_by_position(arg_index).column.get());
 
     auto& result_info = block.get_by_position(result_index);
-    if (is_nullable) {
-        result_info.type = make_nullable(result_info.type);
+    if (result_info.type->is_nullable())
         execute_for_ternary_logic_impl<Impl>(std::move(args_in), result_info, input_rows_count);
-    } else {
+    else
         basic_execute_impl<Impl>(std::move(args_in), result_info, input_rows_count);
-    }
     return Status::OK();
 }
 
