@@ -206,7 +206,6 @@ public:
         auto call = [&](const auto& types) -> bool {
             using Types = std::decay_t<decltype(types)>;
             using T0 = typename Types::LeftType;
-            using T1 = typename Types::RightType;
             using result_type = typename Types::LeftType;
 
             // for doris, args type and return type must be sanme beacause of type cast has already done before, so here just need one type;
@@ -293,9 +292,10 @@ public:
                             make_nullable_column_if_not(arg_else.column);
                 }
             } else {
-                status = Status::InternalError("Illegal column " + arg_cond.column->get_name() +
-                                               " of first argument of function " + get_name() +
-                                               ". Must be ColumnUInt8 or ColumnConstUInt8.");
+                status = Status::InternalError(
+                        "Illegal column {} of first argument of function {}. Must be ColumnUInt8 "
+                        "or ColumnConstUInt8.",
+                        arg_cond.column->get_name(), get_name());
             }
             return true;
         }
@@ -337,9 +337,10 @@ public:
                                     input_rows_count);
                 }
             } else {
-                status = Status::InternalError("Illegal column " + arg_cond.column->get_name() +
-                                               " of first argument of function " + get_name() +
-                                               ". Must be ColumnUInt8 or ColumnConstUInt8.");
+                status = Status::InternalError(
+                        "Illegal column {} of first argument of function {}. Must be ColumnUInt8 "
+                        "or ColumnConstUInt8.",
+                        arg_cond.column->get_name(), get_name());
             }
             return true;
         }
@@ -486,9 +487,10 @@ public:
         }
 
         if (!cond_col) {
-            return Status::InvalidArgument("Illegal column " + arg_cond.column->get_name() +
-                                           " of first argument of function " + get_name() +
-                                           ",Must be ColumnUInt8 or ColumnConstUInt8.");
+            return Status::InvalidArgument(
+                    "Illegal column {} of first argument of function {},Must be ColumnUInt8 or "
+                    "ColumnConstUInt8.",
+                    arg_cond.column->get_name(), get_name());
         }
 
         WhichDataType which_type(arg_then.type);
