@@ -17,13 +17,13 @@
 
 #pragma once
 
+#include "common/status.h"
 #ifdef USE_LIBCPP
 #include <queue>
 #else
 #include <ext/pb_ds/priority_queue.hpp>
 #endif
 
-#include "olap/olap_define.h"
 #include "olap/reader.h"
 #include "olap/rowset/rowset_reader.h"
 #include "vec/core/block.h"
@@ -34,37 +34,43 @@ class TabletSchema;
 
 namespace vectorized {
 
-struct IteratorRowRef {
-    std::shared_ptr<Block> block;
-    int16_t row_pos;
-    bool is_same;
-};
-
 class VCollectIterator {
 public:
-    VCollectIterator();
     // Hold reader point to get reader params
     ~VCollectIterator();
 
-    void init(TabletReader* reader);
+    void init(TabletReader* reader, bool ori_data_overlapping, bool force_merge, bool is_reverse);
 
-    OLAPStatus add_child(RowsetReaderSharedPtr rs_reader);
+    Status add_child(RowsetReaderSharedPtr rs_reader);
 
-    OLAPStatus build_heap(std::vector<RowsetReaderSharedPtr>& rs_readers);
+    Status build_heap(std::vector<RowsetReaderSharedPtr>& rs_readers);
     // Get top row of the heap, nullptr if reach end.
-    OLAPStatus current_row(IteratorRowRef* ref) const;
+    Status current_row(IteratorRowRef* ref) const;
 
     // Read nest order row in Block.
     // Returns
-    //      OLAP_SUCCESS when read successfully.
-    //      OLAP_ERR_DATA_EOF and set *row to nullptr when EOF is reached.
+    //      OK when read successfully.
+    //      Status::Error<END_OF_FILE>() and set *row to nullptr when EOF is reached.
     //      Others when error happens
-    OLAPStatus next(IteratorRowRef* ref);
+    Status next(IteratorRowRef* ref);
 
-    OLAPStatus next(Block* block);
+    Status next(Block* block);
 
     bool is_merge() const { return _merge; }
 
+    RowLocation current_row_location() { return _inner_iter->current_row_location(); }
+
+    Status current_block_row_locations(std::vector<RowLocation>* block_row_locations) {
+        return _inner_iter->current_block_row_locations(block_row_locations);
+    }
+
+    bool update_profile(RuntimeProfile* profile) {
+        if (_inner_iter != nullptr) {
+            return _inner_iter->update_profile(profile);
+        }
+        return false;
+    }
+
 private:
     // This interface is the actual implementation of the new version of iterator.
     // It currently contains two implementations, one is Level0Iterator,
@@ -74,41 +80,58 @@ private:
     // then merged with other rowset readers.
     class LevelIterator {
     public:
-        LevelIterator(TabletReader* reader) : _schema(reader->tablet()->tablet_schema()) {};
+        LevelIterator(TabletReader* reader)
+                : _schema(reader->tablet_schema()),
+                  _compare_columns(reader->_reader_context.read_orderby_key_columns) {};
 
-        virtual OLAPStatus init() = 0;
+        virtual Status init(bool get_data_by_ref = false) = 0;
+        virtual Status init_for_union(bool is_first_child, bool get_data_by_ref = false) {
+            return Status::OK();
+        };
 
         virtual int64_t version() const = 0;
 
         const IteratorRowRef* current_row_ref() const { return &_ref; }
 
-        virtual OLAPStatus next(IteratorRowRef* ref) = 0;
+        virtual Status next(IteratorRowRef* ref) = 0;
 
-        virtual OLAPStatus next(Block* block) = 0;
+        virtual Status next(Block* block) = 0;
 
         void set_same(bool same) { _ref.is_same = same; }
 
-        bool is_same() { return _ref.is_same; }
+        bool is_same() const { return _ref.is_same; }
 
         virtual ~LevelIterator() = default;
 
         const TabletSchema& tablet_schema() const { return _schema; };
 
+        const inline std::vector<uint32_t>* compare_columns() const { return _compare_columns; };
+
+        virtual RowLocation current_row_location() = 0;
+
+        virtual Status current_block_row_locations(std::vector<RowLocation>* row_location) = 0;
+
+        virtual bool update_profile(RuntimeProfile* profile) = 0;
+
     protected:
         const TabletSchema& _schema;
         IteratorRowRef _ref;
+        std::vector<uint32_t>* _compare_columns;
     };
 
     // Compare row cursors between multiple merge elements,
     // if row cursors equal, compare data version.
     class LevelIteratorComparator {
     public:
-        LevelIteratorComparator(int sequence = -1) : _sequence(sequence) {}
+        LevelIteratorComparator(int sequence, bool is_reverse)
+                : _sequence(sequence), _is_reverse(is_reverse) {}
 
         bool operator()(LevelIterator* lhs, LevelIterator* rhs);
 
     private:
         int _sequence;
+        // reverse the compare order
+        bool _is_reverse = false;
     };
 
 #ifdef USE_LIBCPP
@@ -123,46 +146,116 @@ private:
     class Level0Iterator : public LevelIterator {
     public:
         Level0Iterator(RowsetReaderSharedPtr rs_reader, TabletReader* reader);
-        virtual ~Level0Iterator() {}
+        ~Level0Iterator() override = default;
 
-        OLAPStatus init() override;
+        Status init(bool get_data_by_ref = false) override;
+        Status init_for_union(bool is_first_child, bool get_data_by_ref = false) override;
 
         int64_t version() const override;
 
-        OLAPStatus next(IteratorRowRef* ref) override;
+        Status next(IteratorRowRef* ref) override;
 
-        OLAPStatus next(Block* block) override;
+        Status next(Block* block) override;
+
+        RowLocation current_row_location() override;
+
+        Status current_block_row_locations(std::vector<RowLocation>* block_row_locations) override;
+
+        bool update_profile(RuntimeProfile* profile) override {
+            if (_rs_reader != nullptr) {
+                return _rs_reader->update_profile(profile);
+            }
+            return false;
+        }
 
     private:
-        OLAPStatus _refresh_current_row();
+        Status _refresh_current_row();
+        Status _next_by_ref(IteratorRowRef* ref);
+        Status _refresh_current_row_by_ref();
+
+        bool _is_empty() {
+            if (_get_data_by_ref) {
+                return _block_view.empty();
+            } else {
+                return _block->rows() == 0;
+            }
+        }
+
+        bool _current_valid() {
+            if (_get_data_by_ref) {
+                return _current < _block_view.size();
+            } else {
+                return _ref.row_pos < _block->rows();
+            }
+        }
+
+        void _reset() {
+            if (_get_data_by_ref) {
+                _block_view.clear();
+                _ref.reset();
+                _current = 0;
+            } else {
+                _ref.is_same = false;
+                _ref.row_pos = 0;
+                _block->clear_column_data();
+            }
+        }
+
+        Status _refresh() {
+            if (_get_data_by_ref) {
+                return _rs_reader->next_block_view(&_block_view);
+            } else {
+                return _rs_reader->next_block(_block.get());
+            }
+        }
 
         RowsetReaderSharedPtr _rs_reader;
         TabletReader* _reader = nullptr;
         std::shared_ptr<Block> _block;
+
+        int _current;
+        BlockView _block_view;
+        std::vector<RowLocation> _block_row_locations;
+        bool _get_data_by_ref = false;
     };
 
     // Iterate from LevelIterators (maybe Level0Iterators or Level1Iterator or mixed)
     class Level1Iterator : public LevelIterator {
     public:
         Level1Iterator(const std::list<LevelIterator*>& children, TabletReader* reader, bool merge,
-                       bool skip_same);
+                       bool is_reverse, bool skip_same);
 
-        OLAPStatus init() override;
+        Status init(bool get_data_by_ref = false) override;
 
         int64_t version() const override;
 
-        OLAPStatus next(IteratorRowRef* ref) override;
+        Status next(IteratorRowRef* ref) override;
 
-        OLAPStatus next(Block* block) override;
+        Status next(Block* block) override;
 
-        virtual ~Level1Iterator();
+        RowLocation current_row_location() override { return _cur_child->current_row_location(); }
+
+        Status current_block_row_locations(std::vector<RowLocation>* block_row_locations) override;
+
+        ~Level1Iterator() override;
+
+        bool update_profile(RuntimeProfile* profile) override {
+            if (_cur_child != nullptr) {
+                return _cur_child->update_profile(profile);
+            }
+            return false;
+        }
+
+        Status init_level0_iterators_for_union();
 
     private:
-        inline OLAPStatus _merge_next(IteratorRowRef* ref);
+        Status _merge_next(IteratorRowRef* ref);
 
-        inline OLAPStatus _normal_next(IteratorRowRef* ref);
+        Status _normal_next(IteratorRowRef* ref);
 
-        inline OLAPStatus _normal_next(Block* block);
+        Status _normal_next(Block* block);
+
+        Status _merge_next(Block* block);
 
         // Each LevelIterator corresponds to a rowset reader,
         // it will be cleared after '_heap' has been initialized when '_merge == true'.
@@ -178,10 +271,17 @@ private:
         // from the first rowset, the second rowset, .., the last rowset. The output of CollectorIterator is also
         // *partially* ordered.
         bool _merge = true;
+        // reverse the compare order
+        bool _is_reverse = false;
 
         bool _skip_same;
         // used when `_merge == true`
         std::unique_ptr<MergeHeap> _heap;
+
+        // batch size, get from TabletReader
+        int _batch_size;
+
+        std::vector<RowLocation> _block_row_locations;
     };
 
     std::unique_ptr<LevelIterator> _inner_iter;
@@ -191,6 +291,8 @@ private:
     std::list<LevelIterator*> _children;
 
     bool _merge = true;
+    // reverse the compare order
+    bool _is_reverse = false;
     // Hold reader point to access read params, such as fetch conditions.
     TabletReader* _reader = nullptr;
 
