@@ -24,11 +24,11 @@
 
 #include "common/object_pool.h"
 #include "exec/broker_scan_node.h"
-#include "exec/local_file_reader.h"
 #include "exprs/cast_functions.h"
 #include "exprs/decimalv2_operators.h"
 #include "gen_cpp/Descriptors_types.h"
 #include "gen_cpp/PlanNodes_types.h"
+#include "io/local_file_reader.h"
 #include "runtime/descriptors.h"
 #include "runtime/exec_env.h"
 #include "runtime/row_batch.h"
@@ -42,7 +42,7 @@ class JsonScannerTest : public testing::Test {
 public:
     JsonScannerTest() : _runtime_state(TQueryGlobals()) {
         init();
-        _runtime_state._instance_mem_tracker.reset(new MemTracker());
+        _runtime_state.init_mem_trackers();
         _runtime_state._exec_env = ExecEnv::GetInstance();
     }
     void init();
@@ -529,103 +529,4 @@ void JsonScannerTest::init() {
     _tnode.__isset.broker_scan_node = true;
 }
 
-TEST_F(JsonScannerTest, normal_simple_arrayjson) {
-    BrokerScanNode scan_node(&_obj_pool, _tnode, *_desc_tbl);
-    scan_node.init(_tnode);
-    auto status = scan_node.prepare(&_runtime_state);
-    EXPECT_TRUE(status.ok());
-
-    // set scan range
-    std::vector<TScanRangeParams> scan_ranges;
-    {
-        TScanRangeParams scan_range_params;
-
-        TBrokerScanRange broker_scan_range;
-        broker_scan_range.params = _params;
-        TBrokerRangeDesc range;
-        range.start_offset = 0;
-        range.size = -1;
-        range.format_type = TFileFormatType::FORMAT_JSON;
-        range.strip_outer_array = true;
-        range.__isset.strip_outer_array = true;
-        range.splittable = true;
-        range.path = "./be/test/exec/test_data/json_scanner/test_simple2.json";
-        range.file_type = TFileType::FILE_LOCAL;
-        broker_scan_range.ranges.push_back(range);
-        scan_range_params.scan_range.__set_broker_scan_range(broker_scan_range);
-        scan_ranges.push_back(scan_range_params);
-    }
-
-    scan_node.set_scan_ranges(scan_ranges);
-    status = scan_node.open(&_runtime_state);
-    EXPECT_TRUE(status.ok());
-
-    MemTracker tracker;
-    // Get batch
-    RowBatch batch(scan_node.row_desc(), _runtime_state.batch_size(), &tracker);
-    bool eof = false;
-    status = scan_node.get_next(&_runtime_state, &batch, &eof);
-    EXPECT_TRUE(status.ok());
-    EXPECT_EQ(2, batch.num_rows());
-    // Do not use num_as_string, so largeint is too big is null and decimal value loss precision
-    auto tuple_str =
-            batch.get_row(1)->get_tuple(0)->to_string(*scan_node.row_desc().tuple_descriptors()[0]);
-    EXPECT_TRUE(tuple_str.find("1180591620717411303424") == tuple_str.npos);
-    EXPECT_TRUE(tuple_str.find("9999999999999.999999") == tuple_str.npos);
-    EXPECT_FALSE(eof);
-    batch.reset();
-
-    status = scan_node.get_next(&_runtime_state, &batch, &eof);
-    EXPECT_TRUE(status.ok());
-    EXPECT_EQ(0, batch.num_rows());
-    EXPECT_TRUE(eof);
-
-    // Use num_as_string load data again
-    BrokerScanNode scan_node2(&_obj_pool, _tnode, *_desc_tbl);
-    scan_node2.init(_tnode);
-    status = scan_node2.prepare(&_runtime_state);
-    EXPECT_TRUE(status.ok());
-    scan_ranges.clear();
-    {
-        TScanRangeParams scan_range_params;
-
-        TBrokerScanRange broker_scan_range;
-        broker_scan_range.params = _params;
-        TBrokerRangeDesc range;
-        range.start_offset = 0;
-        range.size = -1;
-        range.format_type = TFileFormatType::FORMAT_JSON;
-        range.strip_outer_array = true;
-        range.num_as_string = true;
-        range.__isset.strip_outer_array = true;
-        range.__isset.num_as_string = true;
-        range.splittable = true;
-        range.path = "./be/test/exec/test_data/json_scanner/test_simple2.json";
-        range.file_type = TFileType::FILE_LOCAL;
-        broker_scan_range.ranges.push_back(range);
-        scan_range_params.scan_range.__set_broker_scan_range(broker_scan_range);
-        scan_ranges.push_back(scan_range_params);
-    }
-    scan_node2.set_scan_ranges(scan_ranges);
-    status = scan_node2.open(&_runtime_state);
-    EXPECT_TRUE(status.ok());
-
-    status = scan_node2.get_next(&_runtime_state, &batch, &eof);
-    EXPECT_TRUE(status.ok());
-    EXPECT_EQ(2, batch.num_rows());
-    // Use num as string, load largeint, decimal successfully
-    tuple_str = batch.get_row(1)->get_tuple(0)->to_string(
-            *scan_node2.row_desc().tuple_descriptors()[0]);
-    EXPECT_FALSE(tuple_str.find("1180591620717411303424") == tuple_str.npos);
-    EXPECT_FALSE(tuple_str.find("9999999999999.999999") == tuple_str.npos);
-
-    scan_node.close(&_runtime_state);
-    scan_node2.close(&_runtime_state);
-    {
-        std::stringstream ss;
-        scan_node.runtime_profile()->pretty_print(&ss);
-        LOG(INFO) << ss.str();
-    }
-}
-
 } // namespace doris
