@@ -20,7 +20,7 @@
 #include <gtest/gtest.h>
 
 #include "runtime/descriptor_helper.h"
-#include "runtime/mem_tracker.h"
+#include "runtime/memory/mem_tracker.h"
 #include "runtime/row_batch.h"
 #include "runtime/tuple_row.h"
 
@@ -144,8 +144,7 @@ TEST_F(OlapTablePartitionParamTest, normal) {
     EXPECT_TRUE(st.ok());
     RowDescriptor row_desc(*desc_tbl, {0}, {false});
     TupleDescriptor* tuple_desc = desc_tbl->get_tuple_descriptor(0);
-    auto tracker = std::make_shared<MemTracker>();
-    RowBatch batch(row_desc, 1024, tracker.get());
+    RowBatch batch(row_desc, 1024);
     // 12, 9, "abc"
     {
         Tuple* tuple = (Tuple*)batch.tuple_data_pool()->allocate(tuple_desc->byte_size());
@@ -337,8 +336,7 @@ TEST_F(OlapTablePartitionParamTest, single_list_partition) {
     EXPECT_TRUE(st.ok());
     RowDescriptor row_desc(*desc_tbl, {0}, {false});
     TupleDescriptor* tuple_desc = desc_tbl->get_tuple_descriptor(0);
-    auto tracker = std::make_shared<MemTracker>();
-    RowBatch batch(row_desc, 1024, tracker.get());
+    RowBatch batch(row_desc, 1024);
     // 12, 1, "abc"
     {
         Tuple* tuple = (Tuple*)batch.tuple_data_pool()->allocate(tuple_desc->byte_size());
@@ -539,7 +537,7 @@ TEST_F(OlapTablePartitionParamTest, multi_list_partition) {
 
     OlapTablePartitionParam part(schema, t_partition_param);
     st = part.init();
-    LOG(INFO) << st.get_error_msg();
+    LOG(INFO) << st;
     EXPECT_TRUE(st.ok());
     LOG(INFO) << part.debug_string();
 
@@ -549,8 +547,7 @@ TEST_F(OlapTablePartitionParamTest, multi_list_partition) {
     EXPECT_TRUE(st.ok());
     RowDescriptor row_desc(*desc_tbl, {0}, {false});
     TupleDescriptor* tuple_desc = desc_tbl->get_tuple_descriptor(0);
-    auto tracker = std::make_shared<MemTracker>();
-    RowBatch batch(row_desc, 1024, tracker.get());
+    RowBatch batch(row_desc, 1024);
     // 12, 1, "beijing"
     {
         Tuple* tuple = (Tuple*)batch.tuple_data_pool()->allocate(tuple_desc->byte_size());
@@ -682,8 +679,7 @@ TEST_F(OlapTablePartitionParamTest, unpartitioned) {
     EXPECT_TRUE(st.ok());
     RowDescriptor row_desc(*desc_tbl, {0}, {false});
     TupleDescriptor* tuple_desc = desc_tbl->get_tuple_descriptor(0);
-    auto tracker = std::make_shared<MemTracker>();
-    RowBatch batch(row_desc, 1024, tracker.get());
+    RowBatch batch(row_desc, 1024);
     // 12, 9, "abc"
     {
         Tuple* tuple = (Tuple*)batch.tuple_data_pool()->allocate(tuple_desc->byte_size());
