@@ -27,290 +27,6 @@
 
 namespace doris {
 
-class TestNumBasedCumulativeCompactionPolicy : public testing::Test {
-public:
-    TestNumBasedCumulativeCompactionPolicy() {}
-    void SetUp() {
-        _tablet_meta = static_cast<TabletMetaSharedPtr>(new TabletMeta(
-                1, 2, 15673, 4, 5, TTabletSchema(), 6, {{7, 8}}, UniqueId(9, 10),
-                TTabletType::TABLET_TYPE_DISK, TStorageMedium::HDD, TCompressionType::LZ4F));
-
-        _json_rowset_meta = R"({
-            "rowset_id": 540081,
-            "tablet_id": 15673,
-            "txn_id": 4042,
-            "tablet_schema_hash": 567997577,
-            "rowset_type": "BETA_ROWSET",
-            "rowset_state": "VISIBLE",
-            "start_version": 2,
-            "end_version": 2,
-            "num_rows": 3929,
-            "total_disk_size": 84699,
-            "data_disk_size": 84464,
-            "index_disk_size": 235,
-            "empty": false,
-            "load_id": {
-                "hi": -5350970832824939812,
-                "lo": -6717994719194512122
-            },
-            "creation_time": 1553765670,
-            "alpha_rowset_extra_meta_pb": {
-                "segment_groups": [
-                {
-                    "segment_group_id": 0,
-                    "num_segments": 2,
-                    "index_size": 132,
-                    "data_size": 576,
-                    "num_rows": 5,
-                    "zone_maps": [
-                    {
-                        "min": "MQ==",
-                        "max": "NQ==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "MQ==",
-                        "max": "Mw==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "J2J1c2gn",
-                        "max": "J3RvbSc=",
-                        "null_flag": false
-                    }
-                    ],
-                    "empty": false
-                },
-                {
-                    "segment_group_id": 1,
-                    "num_segments": 1,
-                    "index_size": 132,
-                    "data_size": 576,
-                    "num_rows": 5,
-                    "zone_maps": [
-                    {
-                        "min": "MQ==",
-                        "max": "NQ==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "MQ==",
-                        "max": "Mw==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "J2J1c2gn",
-                        "max": "J3RvbSc=",
-                        "null_flag": false
-                    }
-                    ],
-                    "empty": false
-                }
-                ]
-            }
-        })";
-    }
-    void TearDown() {}
-
-    void init_rs_meta(RowsetMetaSharedPtr& pb1, int64_t start, int64_t end) {
-        pb1->init_from_json(_json_rowset_meta);
-        pb1->set_start_version(start);
-        pb1->set_end_version(end);
-        pb1->set_creation_time(10000);
-    }
-
-    void init_all_rs_meta(std::vector<RowsetMetaSharedPtr>* rs_metas) {
-        RowsetMetaSharedPtr ptr1(new RowsetMeta());
-        init_rs_meta(ptr1, 0, 0);
-        rs_metas->push_back(ptr1);
-
-        RowsetMetaSharedPtr ptr2(new RowsetMeta());
-        init_rs_meta(ptr2, 1, 1);
-        rs_metas->push_back(ptr2);
-
-        RowsetMetaSharedPtr ptr3(new RowsetMeta());
-        init_rs_meta(ptr3, 2, 2);
-        rs_metas->push_back(ptr3);
-
-        RowsetMetaSharedPtr ptr4(new RowsetMeta());
-        init_rs_meta(ptr4, 3, 3);
-        rs_metas->push_back(ptr4);
-
-        RowsetMetaSharedPtr ptr5(new RowsetMeta());
-        init_rs_meta(ptr5, 4, 4);
-        rs_metas->push_back(ptr5);
-    }
-
-    void init_all_rs_meta_cal_point(std::vector<RowsetMetaSharedPtr>* rs_metas) {
-        RowsetMetaSharedPtr ptr1(new RowsetMeta());
-        init_rs_meta(ptr1, 0, 1);
-        ptr1->set_segments_overlap(NONOVERLAPPING);
-        rs_metas->push_back(ptr1);
-
-        RowsetMetaSharedPtr ptr2(new RowsetMeta());
-        init_rs_meta(ptr2, 2, 3);
-        ptr2->set_segments_overlap(NONOVERLAPPING);
-        rs_metas->push_back(ptr2);
-
-        RowsetMetaSharedPtr ptr3(new RowsetMeta());
-        init_rs_meta(ptr3, 4, 4);
-        ptr3->set_segments_overlap(OVERLAPPING);
-        rs_metas->push_back(ptr3);
-
-        RowsetMetaSharedPtr ptr4(new RowsetMeta());
-        init_rs_meta(ptr4, 5, 5);
-        ptr4->set_segments_overlap(OVERLAPPING);
-        rs_metas->push_back(ptr4);
-    }
-
-    void init_all_rs_meta_delete(std::vector<RowsetMetaSharedPtr>* rs_metas) {
-        RowsetMetaSharedPtr ptr1(new RowsetMeta());
-        init_rs_meta(ptr1, 0, 1);
-        ptr1->set_segments_overlap(NONOVERLAPPING);
-        rs_metas->push_back(ptr1);
-
-        RowsetMetaSharedPtr ptr2(new RowsetMeta());
-        init_rs_meta(ptr2, 2, 3);
-        ptr2->set_segments_overlap(NONOVERLAPPING);
-        rs_metas->push_back(ptr2);
-
-        RowsetMetaSharedPtr ptr3(new RowsetMeta());
-        init_rs_meta(ptr3, 4, 4);
-        ptr3->set_segments_overlap(OVERLAPPING);
-        rs_metas->push_back(ptr3);
-
-        RowsetMetaSharedPtr ptr4(new RowsetMeta());
-        init_rs_meta(ptr4, 5, 5);
-        DeletePredicatePB del;
-        del.add_sub_predicates("a = 1");
-        del.set_version(5);
-        ptr4->set_delete_predicate(del);
-        ptr4->set_segments_overlap(OVERLAP_UNKNOWN);
-        rs_metas->push_back(ptr4);
-
-        RowsetMetaSharedPtr ptr5(new RowsetMeta());
-        init_rs_meta(ptr5, 6, 6);
-        ptr5->set_segments_overlap(OVERLAPPING);
-        rs_metas->push_back(ptr5);
-    }
-
-protected:
-    std::string _json_rowset_meta;
-    TabletMetaSharedPtr _tablet_meta;
-};
-
-TEST_F(TestNumBasedCumulativeCompactionPolicy, calc_cumulative_compaction_score) {
-    std::vector<RowsetMetaSharedPtr> rs_metas;
-    init_all_rs_meta(&rs_metas);
-
-    for (auto& rowset : rs_metas) {
-        _tablet_meta->add_rs_meta(rowset);
-    }
-
-    TabletSharedPtr _tablet(new Tablet(_tablet_meta, nullptr, CUMULATIVE_NUM_BASED_POLICY));
-    _tablet->init();
-    std::shared_ptr<CumulativeCompactionPolicy> cumulative_compaction_policy =
-            CumulativeCompactionPolicyFactory::create_cumulative_compaction_policy(
-                    CUMULATIVE_NUM_BASED_POLICY);
-
-    const uint32_t score = _tablet->calc_compaction_score(CompactionType::CUMULATIVE_COMPACTION,
-                                                          cumulative_compaction_policy);
-
-    EXPECT_EQ(15, score);
-}
-
-TEST_F(TestNumBasedCumulativeCompactionPolicy, calculate_cumulative_point) {
-    std::vector<RowsetMetaSharedPtr> rs_metas;
-    init_all_rs_meta_cal_point(&rs_metas);
-
-    for (auto& rowset : rs_metas) {
-        _tablet_meta->add_rs_meta(rowset);
-    }
-
-    TabletSharedPtr _tablet(new Tablet(_tablet_meta, nullptr, CUMULATIVE_NUM_BASED_POLICY));
-    _tablet->init();
-    _tablet->calculate_cumulative_point();
-
-    EXPECT_EQ(4, _tablet->cumulative_layer_point());
-}
-
-TEST_F(TestNumBasedCumulativeCompactionPolicy, pick_candidate_rowsets) {
-    std::vector<RowsetMetaSharedPtr> rs_metas;
-    init_all_rs_meta_cal_point(&rs_metas);
-
-    for (auto& rowset : rs_metas) {
-        _tablet_meta->add_rs_meta(rowset);
-    }
-
-    TabletSharedPtr _tablet(new Tablet(_tablet_meta, nullptr, CUMULATIVE_NUM_BASED_POLICY));
-    _tablet->init();
-    _tablet->calculate_cumulative_point();
-
-    std::vector<RowsetSharedPtr> candidate_rowsets;
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
-
-    EXPECT_EQ(2, candidate_rowsets.size());
-}
-
-TEST_F(TestNumBasedCumulativeCompactionPolicy, pick_input_rowsets_normal) {
-    std::vector<RowsetMetaSharedPtr> rs_metas;
-    init_all_rs_meta_cal_point(&rs_metas);
-
-    for (auto& rowset : rs_metas) {
-        _tablet_meta->add_rs_meta(rowset);
-    }
-
-    TabletSharedPtr _tablet(new Tablet(_tablet_meta, nullptr, CUMULATIVE_NUM_BASED_POLICY));
-    _tablet->init();
-    _tablet->calculate_cumulative_point();
-
-    NumBasedCumulativeCompactionPolicy policy;
-    std::vector<RowsetSharedPtr> candidate_rowsets;
-
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
-
-    std::vector<RowsetSharedPtr> input_rowsets;
-    Version last_delete_version {-1, -1};
-    size_t compaction_score = 0;
-    policy.pick_input_rowsets(_tablet.get(), candidate_rowsets, 10, 5, &input_rowsets,
-                              &last_delete_version, &compaction_score);
-
-    EXPECT_EQ(2, input_rowsets.size());
-    EXPECT_EQ(6, compaction_score);
-    EXPECT_EQ(-1, last_delete_version.first);
-    EXPECT_EQ(-1, last_delete_version.second);
-}
-
-TEST_F(TestNumBasedCumulativeCompactionPolicy, pick_input_rowsets_delete) {
-    std::vector<RowsetMetaSharedPtr> rs_metas;
-    init_all_rs_meta_delete(&rs_metas);
-
-    for (auto& rowset : rs_metas) {
-        _tablet_meta->add_rs_meta(rowset);
-    }
-
-    TabletSharedPtr _tablet(new Tablet(_tablet_meta, nullptr, CUMULATIVE_NUM_BASED_POLICY));
-    _tablet->init();
-    _tablet->calculate_cumulative_point();
-
-    NumBasedCumulativeCompactionPolicy policy;
-    std::vector<RowsetSharedPtr> candidate_rowsets;
-
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
-
-    std::vector<RowsetSharedPtr> input_rowsets;
-    Version last_delete_version {-1, -1};
-    size_t compaction_score = 0;
-
-    policy.pick_input_rowsets(_tablet.get(), candidate_rowsets, 10, 5, &input_rowsets,
-                              &last_delete_version, &compaction_score);
-
-    EXPECT_EQ(1, input_rowsets.size());
-    EXPECT_EQ(3, compaction_score);
-    EXPECT_EQ(5, last_delete_version.first);
-    EXPECT_EQ(5, last_delete_version.second);
-}
-
 class TestSizeBasedCumulativeCompactionPolicy : public testing::Test {
 public:
     TestSizeBasedCumulativeCompactionPolicy() {}
@@ -321,8 +37,8 @@ public:
         config::cumulative_size_based_compaction_lower_size_mbytes = 64;
 
         _tablet_meta = static_cast<TabletMetaSharedPtr>(new TabletMeta(
-                1, 2, 15673, 4, 5, TTabletSchema(), 6, {{7, 8}}, UniqueId(9, 10),
-                TTabletType::TABLET_TYPE_DISK, TStorageMedium::HDD, TCompressionType::LZ4F));
+                1, 2, 15673, 15674, 4, 5, TTabletSchema(), 6, {{7, 8}}, UniqueId(9, 10),
+                TTabletType::TABLET_TYPE_DISK, TCompressionType::LZ4F));
 
         _json_rowset_meta = R"({
             "rowset_id": 540081,
@@ -343,60 +59,7 @@ public:
                 "lo": -6717994719194512122
             },
             "creation_time": 1553765670,
-            "alpha_rowset_extra_meta_pb": {
-                "segment_groups": [
-                {
-                    "segment_group_id": 0,
-                    "num_segments": 2,
-                    "index_size": 132,
-                    "data_size": 576,
-                    "num_rows": 5,
-                    "zone_maps": [
-                    {
-                        "min": "MQ==",
-                        "max": "NQ==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "MQ==",
-                        "max": "Mw==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "J2J1c2gn",
-                        "max": "J3RvbSc=",
-                        "null_flag": false
-                    }
-                    ],
-                    "empty": false
-                },
-                {
-                    "segment_group_id": 1,
-                    "num_segments": 1,
-                    "index_size": 132,
-                    "data_size": 576,
-                    "num_rows": 5,
-                    "zone_maps": [
-                    {
-                        "min": "MQ==",
-                        "max": "NQ==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "MQ==",
-                        "max": "Mw==",
-                        "null_flag": false
-                    },
-                    {
-                        "min": "J2J1c2gn",
-                        "max": "J3RvbSc=",
-                        "null_flag": false
-                    }
-                    ],
-                    "empty": false
-                }
-                ]
-            }
+            "num_segments": 3
         })";
     }
     void TearDown() {}
@@ -407,6 +70,7 @@ public:
         pb1->set_end_version(end);
         pb1->set_total_disk_size(41);
         pb1->set_creation_time(10000);
+        pb1->set_tablet_schema(_tablet_meta->tablet_schema());
     }
 
     void init_rs_meta_small_base(std::vector<RowsetMetaSharedPtr>* rs_metas) {
@@ -668,8 +332,7 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, calc_cumulative_compaction_score
     _tablet->calculate_cumulative_point();
 
     std::shared_ptr<CumulativeCompactionPolicy> cumulative_compaction_policy =
-            CumulativeCompactionPolicyFactory::create_cumulative_compaction_policy(
-                    CUMULATIVE_SIZE_BASED_POLICY);
+            CumulativeCompactionPolicyFactory::create_cumulative_compaction_policy();
     const uint32_t score = _tablet->calc_compaction_score(CompactionType::CUMULATIVE_COMPACTION,
                                                           cumulative_compaction_policy);
 
@@ -688,8 +351,7 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, calc_cumulative_compaction_score
     _tablet->init();
     _tablet->calculate_cumulative_point();
     std::shared_ptr<CumulativeCompactionPolicy> cumulative_compaction_policy =
-            CumulativeCompactionPolicyFactory::create_cumulative_compaction_policy(
-                    CUMULATIVE_SIZE_BASED_POLICY);
+            CumulativeCompactionPolicyFactory::create_cumulative_compaction_policy();
     const uint32_t score = _tablet->calc_compaction_score(CompactionType::CUMULATIVE_COMPACTION,
                                                           cumulative_compaction_policy);
 
@@ -739,7 +401,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_candidate_rowsets) {
     _tablet->calculate_cumulative_point();
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     EXPECT_EQ(3, candidate_rowsets.size());
 }
@@ -757,7 +420,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_candidate_rowsets_big_base)
     _tablet->calculate_cumulative_point();
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     EXPECT_EQ(3, candidate_rowsets.size());
 }
@@ -776,7 +440,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_normal) {
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -805,7 +470,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_big_base) {
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -834,7 +500,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_promotion) {
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -863,7 +530,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_not_same_leve
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -892,7 +560,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_empty) {
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -921,7 +590,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_not_reach_min
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -950,7 +620,8 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, pick_input_rowsets_delete) {
 
     std::vector<RowsetSharedPtr> candidate_rowsets;
 
-    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets);
+    std::shared_lock rdlock(_tablet->get_header_lock());
+    _tablet->pick_candidate_rowsets_to_cumulative_compaction(&candidate_rowsets, rdlock);
 
     std::vector<RowsetSharedPtr> input_rowsets;
     Version last_delete_version {-1, -1};
@@ -1011,7 +682,6 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, _level_size) {
             dynamic_cast<SizeBasedCumulativeCompactionPolicy*>(
                     _tablet->_cumulative_compaction_policy.get());
 
-    EXPECT_EQ(20, policy->_levels.size());
     EXPECT_EQ(536870912, policy->_levels[0]);
     EXPECT_EQ(268435456, policy->_levels[1]);
     EXPECT_EQ(134217728, policy->_levels[2]);
@@ -1035,8 +705,7 @@ TEST_F(TestSizeBasedCumulativeCompactionPolicy, _pick_missing_version_cumulative
     rowsets.push_back(_tablet->get_rowset_by_version({1, 1}));
     rowsets.push_back(_tablet->get_rowset_by_version({2, 2}));
     rowsets.push_back(_tablet->get_rowset_by_version({4, 4}));
-    std::shared_ptr<MemTracker> mem_tracker(new MemTracker());
-    CumulativeCompaction compaction(_tablet, "label", mem_tracker);
+    CumulativeCompaction compaction(_tablet);
     compaction.find_longest_consecutive_version(&rowsets, nullptr);
     EXPECT_EQ(3, rowsets.size());
     EXPECT_EQ(2, rowsets[2]->end_version());
