@@ -21,8 +21,8 @@
 
 #include <vector>
 
+#include "runtime/memory/mem_tracker_limiter.h"
 #include "testutil/test_util.h"
-#include "util/logging.h"
 
 using namespace doris;
 using namespace std;
@@ -49,7 +49,7 @@ const CacheKey EncodeKey(std::string* result, int k) {
 }
 
 static int DecodeKey(const CacheKey& k) {
-    assert(k.size() == 4);
+    EXPECT_EQ(k.size(), 4);
     return DecodeFixed32(k.data());
 }
 static void* EncodeValue(uintptr_t v) {
@@ -222,52 +222,51 @@ static void insert_LRUCache(LRUCache& cache, const CacheKey& key, int value,
                             CachePriority priority) {
     uint32_t hash = key.hash(key.data(), key.size(), 0);
     static std::unique_ptr<MemTrackerLimiter> lru_cache_tracker =
-            std::make_unique<MemTrackerLimiter>(-1, "TestLruCache");
+            std::make_unique<MemTrackerLimiter>(MemTrackerLimiter::Type::GLOBAL, "TestLruCache");
     cache.release(cache.insert(key, hash, EncodeValue(value), value, &deleter,
-                               lru_cache_tracker.get(), priority));
+                               lru_cache_tracker.get(), priority, value));
 }
 
 TEST_F(CacheTest, Usage) {
     LRUCache cache(LRUCacheType::SIZE);
-    cache.set_capacity(1200);
+    cache.set_capacity(1040);
 
-    // The lru usage is handle_size + charge = 104 - 1 = 103
-    // 103 + 3 means handle_size + key size
+    // The lru usage is handle_size + charge.
+    // handle_size = sizeof(handle) - 1 + key size = 104 - 1 + 3 = 106
     CacheKey key1("100");
     insert_LRUCache(cache, key1, 100, CachePriority::NORMAL);
-    EXPECT_EQ(206, cache.get_usage());
+    ASSERT_EQ(206, cache.get_usage()); // 100 + 106
 
     CacheKey key2("200");
     insert_LRUCache(cache, key2, 200, CachePriority::DURABLE);
-    EXPECT_EQ(512, cache.get_usage());
+    ASSERT_EQ(512, cache.get_usage()); // 206 + 306(d), d = DURABLE
 
     CacheKey key3("300");
     insert_LRUCache(cache, key3, 300, CachePriority::NORMAL);
-    EXPECT_EQ(918, cache.get_usage());
+    ASSERT_EQ(918, cache.get_usage()); // 206 + 306(d) + 406
 
     CacheKey key4("400");
     insert_LRUCache(cache, key4, 400, CachePriority::NORMAL);
-    EXPECT_EQ(812, cache.get_usage());
+    ASSERT_EQ(812, cache.get_usage()); // 306(d) + 506, evict 206 406
 
     CacheKey key5("500");
     insert_LRUCache(cache, key5, 500, CachePriority::NORMAL);
-    EXPECT_EQ(912, cache.get_usage());
+    ASSERT_EQ(912, cache.get_usage()); // 306(d) + 606, evict 506
 
     CacheKey key6("600");
     insert_LRUCache(cache, key6, 600, CachePriority::NORMAL);
-    EXPECT_EQ(1012, cache.get_usage());
+    ASSERT_EQ(1012, cache.get_usage()); // 306(d) + 706, evict 506
 
     CacheKey key7("950");
     insert_LRUCache(cache, key7, 950, CachePriority::DURABLE);
-    EXPECT_EQ(1056, cache.get_usage());
+    ASSERT_EQ(0, cache.get_usage()); // evict 306 706, because 950 + 106 > 1040, so insert failed
 }
 
 TEST_F(CacheTest, Prune) {
     LRUCache cache(LRUCacheType::NUMBER);
     cache.set_capacity(5);
 
-    // The lru usage is handle_size + charge = 96 - 1 = 95
-    // 95 + 3 means handle_size + key size
+    // The lru usage is 1, add one entry
     CacheKey key1("100");
     insert_LRUCache(cache, key1, 100, CachePriority::NORMAL);
     EXPECT_EQ(1, cache.get_usage());
@@ -315,6 +314,56 @@ TEST_F(CacheTest, Prune) {
     EXPECT_EQ(0, cache.get_usage());
 }
 
+TEST_F(CacheTest, PruneIfLazyMode) {
+    LRUCache cache(LRUCacheType::NUMBER);
+    cache.set_capacity(10);
+
+    // The lru usage is 1, add one entry
+    CacheKey key1("100");
+    insert_LRUCache(cache, key1, 100, CachePriority::NORMAL);
+    EXPECT_EQ(1, cache.get_usage());
+
+    CacheKey key2("200");
+    insert_LRUCache(cache, key2, 200, CachePriority::DURABLE);
+    EXPECT_EQ(2, cache.get_usage());
+
+    CacheKey key3("300");
+    insert_LRUCache(cache, key3, 300, CachePriority::NORMAL);
+    EXPECT_EQ(3, cache.get_usage());
+
+    CacheKey key4("666");
+    insert_LRUCache(cache, key4, 666, CachePriority::NORMAL);
+    EXPECT_EQ(4, cache.get_usage());
+
+    CacheKey key5("500");
+    insert_LRUCache(cache, key5, 500, CachePriority::NORMAL);
+    EXPECT_EQ(5, cache.get_usage());
+
+    CacheKey key6("600");
+    insert_LRUCache(cache, key6, 600, CachePriority::NORMAL);
+    EXPECT_EQ(6, cache.get_usage());
+
+    CacheKey key7("700");
+    insert_LRUCache(cache, key7, 700, CachePriority::DURABLE);
+    EXPECT_EQ(7, cache.get_usage());
+
+    auto pred = [](const void* value) -> bool { return false; };
+    cache.prune_if(pred, true);
+    EXPECT_EQ(7, cache.get_usage());
+
+    // in lazy mode, the first item not satisfied the pred2, `prune_if` then stopped
+    // and no item's removed.
+    auto pred2 = [](const void* value) -> bool { return DecodeValue((void*)value) > 400; };
+    cache.prune_if(pred2, true);
+    EXPECT_EQ(7, cache.get_usage());
+
+    // in normal priority, 100, 300 are removed
+    // in durable priority, 200 is removed
+    auto pred3 = [](const void* value) -> bool { return DecodeValue((void*)value) <= 600; };
+    EXPECT_EQ(3, cache.prune_if(pred3, true));
+    EXPECT_EQ(4, cache.get_usage());
+}
+
 TEST_F(CacheTest, HeavyEntries) {
     // Add a bunch of light and heavy entries and then count the combined
     // size of items still in the cache, which must be approximately the
@@ -363,9 +412,7 @@ TEST(CacheHandleTest, HandleTableTest) {
     HandleTable ht;
 
     for (uint32_t i = 0; i < ht._length; ++i) {
-        EXPECT_NE(ht._list[i], nullptr);
-        EXPECT_EQ(ht._list[i]->next_hash, nullptr);
-        EXPECT_EQ(ht._list[i]->prev_hash, nullptr);
+        EXPECT_EQ(ht._list[i], nullptr);
     }
 
     const int count = 10;
@@ -383,7 +430,6 @@ TEST(CacheHandleTest, HandleTableTest) {
         h->hash = 1; // make them in a same hash table linked-list
         h->refs = 0;
         h->next = h->prev = nullptr;
-        h->prev_hash = nullptr;
         h->next_hash = nullptr;
         h->in_cache = false;
         h->priority = CachePriority::NORMAL;
@@ -395,18 +441,15 @@ TEST(CacheHandleTest, HandleTableTest) {
         hs[i] = h;
     }
     EXPECT_EQ(ht._elems, count);
-    LRUHandle* h = ht.lookup(CacheKey(std::to_string(count - 1)), 1);
-    LRUHandle* head = ht._list[1 & (ht._length - 1)];
-    EXPECT_EQ(head, h->prev_hash);
-    EXPECT_EQ(head->next_hash, h);
-    int index = count - 1;
+    LRUHandle* h = ht.lookup(keys[0], 1);
+    LRUHandle** head_ptr = &(ht._list[1 & (ht._length - 1)]);
+    LRUHandle* head = *head_ptr;
+    ASSERT_EQ(head, h);
+    int index = 0;
     while (h != nullptr) {
         EXPECT_EQ(hs[index], h) << index;
         h = h->next_hash;
-        if (h != nullptr) {
-            EXPECT_EQ(hs[index], h->prev_hash);
-        }
-        --index;
+        ++index;
     }
 
     for (int i = 0; i < count; ++i) {
@@ -420,7 +463,6 @@ TEST(CacheHandleTest, HandleTableTest) {
         h->hash = 1; // make them in a same hash table linked-list
         h->refs = 0;
         h->next = h->prev = nullptr;
-        h->prev_hash = nullptr;
         h->next_hash = nullptr;
         h->in_cache = false;
         h->priority = CachePriority::NORMAL;
@@ -437,28 +479,21 @@ TEST(CacheHandleTest, HandleTableTest) {
         EXPECT_EQ(ht.lookup(keys[i], 1), hs[i]);
     }
 
-    LRUHandle* old = ht.remove(CacheKey("9"), 1); // first in hash table linked-list
-    EXPECT_EQ(old, hs[9]);
-    EXPECT_EQ(old->prev_hash, head);
-    EXPECT_EQ(old->next_hash, hs[8]); // hs[8] is the new first node
-    EXPECT_EQ(head->next_hash, hs[8]);
-    EXPECT_EQ(hs[8]->prev_hash, head);
+    LRUHandle* old = ht.remove(CacheKey("0"), 1); // first in hash table linked-list
+    ASSERT_EQ(old, hs[0]);
+    ASSERT_EQ(old->next_hash, hs[1]); // hs[1] is the new first node
+    ASSERT_EQ(*head_ptr, hs[1]);
 
-    old = ht.remove(CacheKey("0"), 1); // last in hash table linked-list
-    EXPECT_EQ(old, hs[0]);
-    EXPECT_EQ(old->prev_hash, hs[1]); // hs[1] is the new last node
-    EXPECT_EQ(old->prev_hash->next_hash, nullptr);
+    old = ht.remove(CacheKey("9"), 1); // last in hash table linked-list
+    ASSERT_EQ(old, hs[9]);
 
     old = ht.remove(CacheKey("5"), 1); // middle in hash table linked-list
-    EXPECT_EQ(old, hs[5]);
-    EXPECT_EQ(old->prev_hash, hs[6]);
-    EXPECT_EQ(old->next_hash, hs[4]);
-    EXPECT_EQ(hs[6]->next_hash, hs[4]);
-    EXPECT_EQ(hs[4]->prev_hash, hs[6]);
+    ASSERT_EQ(old, hs[5]);
+    ASSERT_EQ(old->next_hash, hs[6]);
+    ASSERT_EQ(hs[4]->next_hash, hs[6]);
 
     ht.remove(hs[4]); // middle in hash table linked-list
-    EXPECT_EQ(hs[6]->next_hash, hs[3]);
-    EXPECT_EQ(hs[3]->prev_hash, hs[6]);
+    ASSERT_EQ(hs[3]->next_hash, hs[6]);
 
     EXPECT_EQ(ht._elems, count - 4);
 
