@@ -24,13 +24,11 @@
 #include "olap/schema.h"
 #include "olap/tablet_schema.h"
 #include "runtime/mem_pool.h"
-#include "runtime/mem_tracker.h"
-#include "util/logging.h"
 #include "util/types.h"
 
 namespace doris {
 
-void set_tablet_schema_for_init(TabletSchema* tablet_schema) {
+void set_tablet_schema_for_init(TabletSchemaSPtr tablet_schema) {
     TabletSchemaPB tablet_schema_pb;
     ColumnPB* column_1 = tablet_schema_pb.add_column();
     column_1->set_unique_id(1);
@@ -79,75 +77,84 @@ void set_tablet_schema_for_init(TabletSchema* tablet_schema) {
     column_5->set_index_length(8);
 
     ColumnPB* column_6 = tablet_schema_pb.add_column();
-    column_6->set_unique_id(6);
+    column_6->set_unique_id(5);
     column_6->set_name("column_6");
-    column_6->set_type("DECIMAL");
+    column_6->set_type("DATEV2");
     column_6->set_is_key(true);
     column_6->set_is_nullable(true);
-    column_6->set_length(12);
-    column_6->set_index_length(12);
-    column_6->set_frac(3);
-    column_6->set_precision(6);
+    column_6->set_length(4);
+    column_6->set_index_length(4);
 
     ColumnPB* column_7 = tablet_schema_pb.add_column();
-    column_7->set_unique_id(7);
+    column_7->set_unique_id(6);
     column_7->set_name("column_7");
-    column_7->set_type("CHAR");
+    column_7->set_type("DECIMAL");
     column_7->set_is_key(true);
     column_7->set_is_nullable(true);
-    column_7->set_length(4);
-    column_7->set_index_length(4);
-    column_7->set_default_value("char");
+    column_7->set_length(12);
+    column_7->set_index_length(12);
+    column_7->set_frac(3);
+    column_7->set_precision(6);
 
     ColumnPB* column_8 = tablet_schema_pb.add_column();
-    column_8->set_unique_id(8);
+    column_8->set_unique_id(7);
     column_8->set_name("column_8");
-    column_8->set_type("BIGINT");
+    column_8->set_type("CHAR");
+    column_8->set_is_key(true);
     column_8->set_is_nullable(true);
-    column_8->set_length(8);
-    column_8->set_aggregation("SUM");
-    column_8->set_is_key(false);
+    column_8->set_length(4);
+    column_8->set_index_length(4);
+    column_8->set_default_value("char");
 
     ColumnPB* column_9 = tablet_schema_pb.add_column();
-    column_9->set_unique_id(9);
+    column_9->set_unique_id(8);
     column_9->set_name("column_9");
-    column_9->set_type("VARCHAR");
+    column_9->set_type("BIGINT");
     column_9->set_is_nullable(true);
-    column_9->set_length(16 + OLAP_VARCHAR_MAX_BYTES);
-    column_9->set_aggregation("REPLACE");
+    column_9->set_length(8);
+    column_9->set_aggregation("SUM");
     column_9->set_is_key(false);
 
     ColumnPB* column_10 = tablet_schema_pb.add_column();
-    column_10->set_unique_id(10);
+    column_10->set_unique_id(9);
     column_10->set_name("column_10");
-    column_10->set_type("LARGEINT");
+    column_10->set_type("VARCHAR");
     column_10->set_is_nullable(true);
-    column_10->set_length(16);
-    column_10->set_aggregation("MAX");
+    column_10->set_length(16 + OLAP_VARCHAR_MAX_BYTES);
+    column_10->set_aggregation("REPLACE");
     column_10->set_is_key(false);
 
     ColumnPB* column_11 = tablet_schema_pb.add_column();
-    column_11->set_unique_id(11);
+    column_11->set_unique_id(10);
     column_11->set_name("column_11");
-    column_11->set_type("DECIMAL");
+    column_11->set_type("LARGEINT");
     column_11->set_is_nullable(true);
-    column_11->set_length(12);
-    column_11->set_aggregation("MIN");
+    column_11->set_length(16);
+    column_11->set_aggregation("MAX");
     column_11->set_is_key(false);
 
     ColumnPB* column_12 = tablet_schema_pb.add_column();
-    column_12->set_unique_id(12);
+    column_12->set_unique_id(11);
     column_12->set_name("column_12");
-    column_12->set_type("HLL");
+    column_12->set_type("DECIMAL");
     column_12->set_is_nullable(true);
-    column_12->set_length(HLL_COLUMN_DEFAULT_LEN);
-    column_12->set_aggregation("HLL_UNION");
+    column_12->set_length(12);
+    column_12->set_aggregation("MIN");
     column_12->set_is_key(false);
 
+    ColumnPB* column_13 = tablet_schema_pb.add_column();
+    column_13->set_unique_id(12);
+    column_13->set_name("column_13");
+    column_13->set_type("HLL");
+    column_13->set_is_nullable(true);
+    column_13->set_length(HLL_COLUMN_DEFAULT_LEN);
+    column_13->set_aggregation("HLL_UNION");
+    column_13->set_is_key(false);
+
     tablet_schema->init_from_pb(tablet_schema_pb);
 }
 
-void set_tablet_schema_for_scan_key(TabletSchema* tablet_schema) {
+void set_tablet_schema_for_scan_key(TabletSchemaSPtr tablet_schema) {
     TabletSchemaPB tablet_schema_pb;
 
     ColumnPB* column_1 = tablet_schema_pb.add_column();
@@ -190,7 +197,7 @@ void set_tablet_schema_for_scan_key(TabletSchema* tablet_schema) {
     tablet_schema->init_from_pb(tablet_schema_pb);
 }
 
-void set_tablet_schema_for_cmp_and_aggregate(TabletSchema* tablet_schema) {
+void set_tablet_schema_for_cmp_and_aggregate(TabletSchemaSPtr tablet_schema) {
     TabletSchemaPB tablet_schema_pb;
 
     ColumnPB* column_1 = tablet_schema_pb.add_column();
@@ -253,35 +260,31 @@ void set_tablet_schema_for_cmp_and_aggregate(TabletSchema* tablet_schema) {
 
 class TestRowCursor : public testing::Test {
 public:
-    TestRowCursor() {
-        _mem_tracker.reset(new MemTracker(-1));
-        _mem_pool.reset(new MemPool(_mem_tracker.get()));
-    }
+    TestRowCursor() { _mem_pool.reset(new MemPool()); }
 
     virtual void SetUp() {}
 
     virtual void TearDown() {}
 
-    std::shared_ptr<MemTracker> _mem_tracker;
     std::unique_ptr<MemPool> _mem_pool;
 };
 
 TEST_F(TestRowCursor, InitRowCursor) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_init(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_init(tablet_schema);
     RowCursor row;
-    OLAPStatus res = row.init(tablet_schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
-    EXPECT_EQ(row.get_fixed_len(), 126);
+    Status res = row.init(tablet_schema);
+    EXPECT_EQ(res, Status::OK());
+    EXPECT_EQ(row.get_fixed_len(), 131);
     EXPECT_EQ(row.get_variable_len(), 20);
 }
 
 TEST_F(TestRowCursor, InitRowCursorWithColumnCount) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_init(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_init(tablet_schema);
     RowCursor row;
-    OLAPStatus res = row.init(tablet_schema, 5);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = row.init(tablet_schema, 5);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(row.get_fixed_len(), 23);
     EXPECT_EQ(row.get_variable_len(), 0);
     row.allocate_memory_for_string_type(tablet_schema);
@@ -289,41 +292,41 @@ TEST_F(TestRowCursor, InitRowCursorWithColumnCount) {
 }
 
 TEST_F(TestRowCursor, InitRowCursorWithColIds) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_init(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_init(tablet_schema);
 
     std::vector<uint32_t> col_ids;
-    for (size_t i = 0; i < tablet_schema.num_columns() / 2; ++i) {
+    for (size_t i = 0; i < tablet_schema->num_columns() / 2; ++i) {
         col_ids.push_back(i * 2);
     }
 
     RowCursor row;
-    OLAPStatus res = row.init(tablet_schema, col_ids);
-    EXPECT_EQ(res, OLAP_SUCCESS);
-    EXPECT_EQ(row.get_fixed_len(), 63);
-    EXPECT_EQ(row.get_variable_len(), 20);
+    Status res = row.init(tablet_schema, col_ids);
+    EXPECT_EQ(res, Status::OK());
+    EXPECT_EQ(row.get_fixed_len(), 55);
+    EXPECT_EQ(row.get_variable_len(), 0);
 }
 
 TEST_F(TestRowCursor, InitRowCursorWithScanKey) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_scan_key(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_scan_key(tablet_schema);
 
     std::vector<std::string> scan_keys;
     scan_keys.push_back("char_exceed_length");
     scan_keys.push_back("varchar_exceed_length");
 
     std::vector<uint32_t> columns {0, 1};
-    std::shared_ptr<Schema> schema = std::make_shared<Schema>(tablet_schema.columns(), columns);
+    std::shared_ptr<Schema> schema = std::make_shared<Schema>(tablet_schema->columns(), columns);
 
     RowCursor row;
-    OLAPStatus res = row.init_scan_key(tablet_schema, scan_keys, schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = row.init_scan_key(tablet_schema, scan_keys, schema);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(row.get_fixed_len(), 34);
     EXPECT_EQ(row.get_variable_len(), 39);
 
     OlapTuple tuple1(scan_keys);
     res = row.from_tuple(tuple1);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    EXPECT_EQ(res, Status::OK());
 
     OlapTuple tuple2 = row.to_tuple();
     EXPECT_TRUE(strncmp(tuple2.get_value(0).c_str(), "0&char_exceed_length", 20));
@@ -331,12 +334,12 @@ TEST_F(TestRowCursor, InitRowCursorWithScanKey) {
 }
 
 TEST_F(TestRowCursor, EqualAndCompare) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_cmp_and_aggregate(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_cmp_and_aggregate(tablet_schema);
 
     RowCursor left;
-    OLAPStatus res = left.init(tablet_schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = left.init(tablet_schema);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(left.get_fixed_len(), 78);
     EXPECT_EQ(left.get_variable_len(), 20);
 
@@ -369,12 +372,12 @@ TEST_F(TestRowCursor, EqualAndCompare) {
 }
 
 TEST_F(TestRowCursor, IndexCmp) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_cmp_and_aggregate(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_cmp_and_aggregate(tablet_schema);
 
     RowCursor left;
-    OLAPStatus res = left.init(tablet_schema, 2);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = left.init(tablet_schema, 2);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(left.get_fixed_len(), 22);
     EXPECT_EQ(left.get_variable_len(), 4);
 
@@ -410,12 +413,12 @@ TEST_F(TestRowCursor, IndexCmp) {
 }
 
 TEST_F(TestRowCursor, FullKeyCmp) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_cmp_and_aggregate(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_cmp_and_aggregate(tablet_schema);
 
     RowCursor left;
-    OLAPStatus res = left.init(tablet_schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = left.init(tablet_schema);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(left.get_fixed_len(), 78);
     EXPECT_EQ(left.get_variable_len(), 20);
 
@@ -450,13 +453,13 @@ TEST_F(TestRowCursor, FullKeyCmp) {
 }
 
 TEST_F(TestRowCursor, AggregateWithoutNull) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_cmp_and_aggregate(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_cmp_and_aggregate(tablet_schema);
 
     RowCursor row;
 
-    OLAPStatus res = row.init(tablet_schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = row.init(tablet_schema);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(row.get_fixed_len(), 78);
     EXPECT_EQ(row.get_variable_len(), 20);
     row.allocate_memory_for_string_type(tablet_schema);
@@ -477,8 +480,7 @@ TEST_F(TestRowCursor, AggregateWithoutNull) {
     left.set_field_content(4, reinterpret_cast<char*>(&l_decimal), _mem_pool.get());
     left.set_field_content(5, reinterpret_cast<char*>(&l_varchar), _mem_pool.get());
 
-    std::shared_ptr<MemTracker> tracker(new MemTracker(-1));
-    std::unique_ptr<MemPool> mem_pool(new MemPool(tracker.get()));
+    std::unique_ptr<MemPool> mem_pool(new MemPool());
     ObjectPool agg_object_pool;
     init_row_with_others(&row, left, mem_pool.get(), &agg_object_pool);
 
@@ -513,13 +515,13 @@ TEST_F(TestRowCursor, AggregateWithoutNull) {
 }
 
 TEST_F(TestRowCursor, AggregateWithNull) {
-    TabletSchema tablet_schema;
-    set_tablet_schema_for_cmp_and_aggregate(&tablet_schema);
+    TabletSchemaSPtr tablet_schema = std::make_shared<TabletSchema>();
+    set_tablet_schema_for_cmp_and_aggregate(tablet_schema);
 
     RowCursor row;
 
-    OLAPStatus res = row.init(tablet_schema);
-    EXPECT_EQ(res, OLAP_SUCCESS);
+    Status res = row.init(tablet_schema);
+    EXPECT_EQ(res, Status::OK());
     EXPECT_EQ(row.get_fixed_len(), 78);
     EXPECT_EQ(row.get_variable_len(), 20);
     row.allocate_memory_for_string_type(tablet_schema);
@@ -538,8 +540,7 @@ TEST_F(TestRowCursor, AggregateWithNull) {
     left.set_null(4);
     left.set_field_content(5, reinterpret_cast<char*>(&l_varchar), _mem_pool.get());
 
-    std::shared_ptr<MemTracker> tracker(new MemTracker(-1));
-    std::unique_ptr<MemPool> mem_pool(new MemPool(tracker.get()));
+    std::unique_ptr<MemPool> mem_pool(new MemPool());
     ObjectPool agg_object_pool;
     init_row_with_others(&row, left, mem_pool.get(), &agg_object_pool);
 
@@ -559,8 +560,7 @@ TEST_F(TestRowCursor, AggregateWithNull) {
 
     agg_update_row(&row, right, nullptr);
 
-    int128_t agg_value = 0;
-    memcpy(&agg_value, row.cell_ptr(2), 16);
+    int128_t agg_value = get_int128_from_unalign(row.cell_ptr(2));
     EXPECT_TRUE(agg_value == ((int128_t)(1) << 101));
 
     bool is_null_double = left.is_null(3);
