@@ -33,7 +33,6 @@
 #include "util/cpu_info.h"
 #include "util/debug_util.h"
 #include "util/disk_info.h"
-#include "util/logging.h"
 
 using std::vector;
 
@@ -60,7 +59,7 @@ static const int NUM_STRINGS = sizeof(STRINGS) / sizeof(StringValue);
 
 class SimpleTupleStreamTest : public testing::Test {
 public:
-    SimpleTupleStreamTest() : _tracker(new MemTracker(-1)) {}
+    SimpleTupleStreamTest() {}
     // A null dtor to pass codestyle check
     ~SimpleTupleStreamTest() {}
 
@@ -68,7 +67,7 @@ protected:
     virtual void SetUp() {
         _test_env.reset(new TestEnv());
         create_descriptors();
-        _mem_pool.reset(new MemPool(_tracker.get()));
+        _mem_pool.reset(new MemPool());
     }
 
     virtual void create_descriptors() {
@@ -99,8 +98,7 @@ protected:
     void InitBlockMgr(int64_t limit, int block_size) {
         Status status = _test_env->create_query_state(0, limit, block_size, &_runtime_state);
         EXPECT_TRUE(status.ok());
-        status = _runtime_state->block_mgr2()->register_client(0, _tracker, _runtime_state,
-                                                               &_client);
+        status = _runtime_state->block_mgr2()->register_client(0, _runtime_state, &_client);
         EXPECT_TRUE(status.ok());
     }
 
@@ -117,7 +115,7 @@ protected:
     }
 
     virtual RowBatch* CreateIntBatch(int offset, int num_rows, bool gen_null) {
-        RowBatch* batch = _pool.add(new RowBatch(*_int_desc, num_rows, _tracker.get()));
+        RowBatch* batch = _pool.add(new RowBatch(*_int_desc, num_rows));
         int tuple_size = _int_desc->tuple_descriptors()[0]->byte_size();
         uint8_t* tuple_mem = reinterpret_cast<uint8_t*>(
                 batch->tuple_data_pool()->allocate(tuple_size * num_rows));
@@ -146,7 +144,7 @@ protected:
 
     virtual RowBatch* CreateStringBatch(int offset, int num_rows, bool gen_null) {
         int tuple_size = sizeof(StringValue) + 1;
-        RowBatch* batch = _pool.add(new RowBatch(*_string_desc, num_rows, _tracker.get()));
+        RowBatch* batch = _pool.add(new RowBatch(*_string_desc, num_rows));
         uint8_t* tuple_mem = batch->tuple_data_pool()->allocate(tuple_size * num_rows);
         memset(tuple_mem, 0, tuple_size * num_rows);
         const int string_tuples = _string_desc->tuple_descriptors().size();
@@ -209,7 +207,7 @@ protected:
     void ReadValues(BufferedTupleStream2* stream, RowDescriptor* desc, std::vector<T>* results,
                     int num_batches = -1) {
         bool eos = false;
-        RowBatch batch(*desc, BATCH_SIZE, _tracker.get());
+        RowBatch batch(*desc, BATCH_SIZE);
         int batches_read = 0;
         do {
             batch.reset();
@@ -267,7 +265,7 @@ protected:
         BufferedTupleStream2 stream(_runtime_state, *desc, _runtime_state->block_mgr2(), _client,
                                     true, false);
         Status status = stream.init(-1, nullptr, true);
-        EXPECT_TRUE(status.ok()) << status.get_error_msg();
+        EXPECT_TRUE(status.ok()) << status;
         status = stream.unpin_stream();
         EXPECT_TRUE(status.ok());
 
@@ -354,7 +352,6 @@ protected:
     RuntimeState* _runtime_state;
     BufferedBlockMgr2::Client* _client;
 
-    std::shared_ptr<MemTracker> _tracker;
     ObjectPool _pool;
     RowDescriptor* _int_desc;
     RowDescriptor* _string_desc;
@@ -784,7 +781,7 @@ TEST_F(ArrayTupleStreamTest, TestArrayDeepCopy) {
     array_len_index = 0;
     bool eos = false;
     int rows_read = 0;
-    RowBatch batch(*_array_desc, BATCH_SIZE, _tracker.get());
+    RowBatch batch(*_array_desc, BATCH_SIZE);
     do {
         batch.reset();
         EXPECT_TRUE(stream.get_next(&batch, &eos).ok());
