@@ -33,10 +33,11 @@
 #include "common/logging.h"
 #include "gutil/strings/split.h"
 #include "gutil/strings/substitute.h"
+#include "io/fs/file_system.h"
+#include "io/fs/file_writer.h"
+#include "io/fs/local_file_system.h"
 #include "olap/comparison_predicate.h"
 #include "olap/data_dir.h"
-#include "olap/fs/block_manager.h"
-#include "olap/fs/fs_util.h"
 #include "olap/in_list_predicate.h"
 #include "olap/olap_common.h"
 #include "olap/row_block2.h"
@@ -51,7 +52,6 @@
 #include "olap/tablet_schema_helper.h"
 #include "olap/types.h"
 #include "runtime/mem_pool.h"
-#include "runtime/mem_tracker.h"
 #include "testutil/test_util.h"
 #include "util/debug_util.h"
 #include "util/file_utils.h"
@@ -104,7 +104,7 @@ namespace doris {
 class BaseBenchmark {
 public:
     BaseBenchmark(const std::string& name, int iterations) : _name(name), _iterations(iterations) {}
-    virtual ~BaseBenchmark() {}
+    virtual ~BaseBenchmark() = default;
 
     void add_name(const std::string& str) { _name += str; }
 
@@ -189,8 +189,7 @@ public:
             //check values
             size_t num = page_start_ids[slice_index + 1] - page_start_ids[slice_index];
 
-            auto tracker = std::make_shared<MemTracker>();
-            MemPool pool(tracker.get());
+            MemPool pool;
             const auto* type_info = get_scalar_type_info<OLAP_FIELD_TYPE_VARCHAR>();
             std::unique_ptr<ColumnVectorBatch> cvb;
             ColumnVectorBatch::create(num, false, type_info, nullptr, &cvb);
@@ -268,9 +267,7 @@ private:
 class SegmentBenchmark : public BaseBenchmark {
 public:
     SegmentBenchmark(const std::string& name, int iterations, const std::string& column_type)
-            : BaseBenchmark(name, iterations),
-              _tracker(std::make_shared<MemTracker>()),
-              _pool(_tracker.get()) {
+            : BaseBenchmark(name, iterations), _pool() {
         if (FileUtils::check_exist(kSegmentDir)) {
             FileUtils::remove_all(kSegmentDir);
         }
@@ -279,9 +276,7 @@ public:
         init_schema(column_type);
     }
     SegmentBenchmark(const std::string& name, int iterations)
-            : BaseBenchmark(name, iterations),
-              _tracker(std::make_shared<MemTracker>()),
-              _pool(_tracker.get()) {
+            : BaseBenchmark(name, iterations), _pool() {
         if (FileUtils::check_exist(kSegmentDir)) {
             FileUtils::remove_all(kSegmentDir);
         }
@@ -293,7 +288,7 @@ public:
         }
     }
 
-    const Schema& get_schema() { return *_schema.get(); }
+    const Schema& get_schema() { return *_schema; }
 
     virtual void init() override {}
     virtual void run() override {}
@@ -340,15 +335,16 @@ public:
                        std::shared_ptr<Segment>* res) {
         // must use unique filename for each segment, otherwise page cache kicks in and produces
         // the wrong answer (it use (filename,offset) as cache key)
-        std::string filename = strings::Substitute("$0/seg_$1.dat", kSegmentDir, ++seg_id);
-        std::unique_ptr<fs::WritableBlock> wblock;
-        fs::CreateBlockOptions block_opts({filename});
-        fs::fs_util::block_manager(TStorageMedium::HDD)->create_block(block_opts, &wblock);
+        std::string filename = fmt::format("seg_{}.dat", seg_id++);
+        std::string path = fmt::format("{}/{}", kSegmentDir, filename);
+        auto fs = io::global_local_filesystem();
 
+        io::FileWriterPtr file_writer;
+        fs->create_file(path, &file_writer);
         SegmentWriterOptions opts;
         DataDir data_dir(kSegmentDir);
         data_dir.init();
-        SegmentWriter writer(wblock.get(), 0, &_tablet_schema, &data_dir, opts);
+        SegmentWriter writer(file_writer.get(), 0, &_tablet_schema, &data_dir, INT32_MAX, opts);
         writer.init(1024);
 
         RowCursor row;
@@ -366,9 +362,9 @@ public:
 
         uint64_t file_size, index_size;
         writer.finalize(&file_size, &index_size);
-        wblock->close();
+        file_writer->close();
 
-        Segment::open(filename, seg_id, &_tablet_schema, res);
+        Segment::open(fs, path, "", seg_id, {}, &_tablet_schema, res);
     }
 
     std::vector<std::vector<std::string>> generate_dataset(int rows_number) {
@@ -402,7 +398,7 @@ private:
         return res;
     }
 
-    std::shared_ptr<MemTracker> _tracker;
+private:
     MemPool _pool;
     TabletSchema _tablet_schema;
     std::shared_ptr<Schema> _schema;
@@ -470,7 +466,7 @@ public:
         StorageReadOptions read_opts;
         read_opts.stats = &stats;
         std::unique_ptr<RowwiseIterator> iter;
-        _segment->new_iterator(get_schema(), read_opts, nullptr, &iter);
+        _segment->new_iterator(get_schema(), read_opts, &iter);
         RowBlockV2 block(get_schema(), 1024);
 
         int left = _dataset.size();
@@ -515,7 +511,7 @@ public:
         StorageReadOptions read_opts;
         read_opts.stats = &stats;
         std::unique_ptr<RowwiseIterator> iter;
-        _segment->new_iterator(get_schema(), read_opts, nullptr, &iter);
+        _segment->new_iterator(get_schema(), read_opts, &iter);
         RowBlockV2 block(get_schema(), 1024);
 
         int left = _dataset.size();
