@@ -17,18 +17,17 @@
 
 #include "vec/exprs/vexpr.h"
 
+#include <gtest/gtest.h>
 #include <thrift/protocol/TJSONProtocol.h>
 
 #include <cmath>
 #include <iostream>
 
 #include "exec/schema_scanner.h"
-#include "gen_cpp/Data_types.h"
 #include "gen_cpp/Exprs_types.h"
 #include "gen_cpp/Types_types.h"
-#include "gtest/gtest.h"
 #include "runtime/exec_env.h"
-#include "runtime/mem_tracker.h"
+#include "runtime/large_int_value.h"
 #include "runtime/memory/chunk_allocator.h"
 #include "runtime/primitive_type.h"
 #include "runtime/row_batch.h"
@@ -39,6 +38,7 @@
 #include "vec/exprs/vliteral.h"
 #include "vec/runtime/vdatetime_value.h"
 #include "vec/utils/util.hpp"
+
 TEST(TEST_VEXPR, ABSTEST) {
     doris::ChunkAllocator::init_instance(4096);
     doris::ObjectPool object_pool;
@@ -48,8 +48,7 @@ TEST(TEST_VEXPR, ABSTEST) {
 
     auto tuple_desc = const_cast<doris::TupleDescriptor*>(desc_tbl->get_tuple_descriptor(0));
     doris::RowDescriptor row_desc(tuple_desc, false);
-    auto tracker_ptr = doris::MemTracker::CreateTracker(-1, "BlockTest", nullptr, false);
-    doris::RowBatch row_batch(row_desc, 1024, tracker_ptr.get());
+    doris::RowBatch row_batch(row_desc, 1024);
     std::string expr_json =
             R"|({"1":{"lst":["rec",2,{"1":{"i32":20},"2":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":6}}}}]}}},"4":{"i32":1},"20":{"i32":-1},"26":{"rec":{"1":{"rec":{"2":{"str":"abs"}}},"2":{"i32":0},"3":{"lst":["rec",1,{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":5}}}}]}}]},"4":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":6}}}}]}}},"5":{"tf":0},"7":{"str":"abs(INT)"},"9":{"rec":{"1":{"str":"_ZN5doris13MathFunctions3absEPN9doris_udf15FunctionContextERKNS1_6IntValE"}}},"11":{"i64":0}}}},{"1":{"i32":16},"2":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":5}}}}]}}},"4":{"i32":0},"15":{"rec":{"1":{"i32":0},"2":{"i32":0}}},"20":{"i32":-1},"23":{"i32":-1}}]}})|";
     doris::TExpr exprx = apache::thrift::from_json_string<doris::TExpr>(expr_json);
@@ -70,15 +69,18 @@ TEST(TEST_VEXPR, ABSTEST) {
 
     doris::RuntimeState runtime_stat(doris::TUniqueId(), doris::TQueryOptions(),
                                      doris::TQueryGlobals(), nullptr);
-    runtime_stat.init_instance_mem_tracker();
+    runtime_stat.init_mem_trackers();
     runtime_stat.set_desc_tbl(desc_tbl);
-    std::shared_ptr<doris::MemTracker> tracker = doris::MemTracker::CreateTracker();
-    context->prepare(&runtime_stat, row_desc, tracker);
-    context->open(&runtime_stat);
+    auto state = doris::Status::OK();
+    state = context->prepare(&runtime_stat, row_desc);
+    ASSERT_TRUE(state.ok());
+    state = context->open(&runtime_stat);
+    ASSERT_TRUE(state.ok());
 
     auto block = row_batch.convert_to_vec_block();
     int ts = -1;
-    context->execute(&block, &ts);
+    state = context->execute(&block, &ts);
+
     context->close(&runtime_stat);
 }
 
@@ -91,8 +93,7 @@ TEST(TEST_VEXPR, ABSTEST2) {
     schema_scanner.init(&param, &object_pool);
     auto tuple_desc = const_cast<TupleDescriptor*>(schema_scanner.tuple_desc());
     RowDescriptor row_desc(tuple_desc, false);
-    auto tracker_ptr = MemTracker::CreateTracker(-1, "BlockTest", nullptr, false);
-    RowBatch row_batch(row_desc, 1024, tracker_ptr.get());
+    RowBatch row_batch(row_desc, 1024);
     std::string expr_json =
             R"|({"1":{"lst":["rec",2,{"1":{"i32":20},"2":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":6}}}}]}}},"4":{"i32":1},"20":{"i32":-1},"26":{"rec":{"1":{"rec":{"2":{"str":"abs"}}},"2":{"i32":0},"3":{"lst":["rec",1,{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":5}}}}]}}]},"4":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":6}}}}]}}},"5":{"tf":0},"7":{"str":"abs(INT)"},"9":{"rec":{"1":{"str":"_ZN5doris13MathFunctions3absEPN9doris_udf15FunctionContextERKNS1_6IntValE"}}},"11":{"i64":0}}}},{"1":{"i32":16},"2":{"rec":{"1":{"lst":["rec",1,{"1":{"i32":0},"2":{"rec":{"1":{"i32":5}}}}]}}},"4":{"i32":0},"15":{"rec":{"1":{"i32":0},"2":{"i32":0}}},"20":{"i32":-1},"23":{"i32":-1}}]}})|";
     TExpr exprx = apache::thrift::from_json_string<TExpr>(expr_json);
@@ -114,17 +115,19 @@ TEST(TEST_VEXPR, ABSTEST2) {
 
     doris::RuntimeState runtime_stat(doris::TUniqueId(), doris::TQueryOptions(),
                                      doris::TQueryGlobals(), nullptr);
-    runtime_stat.init_instance_mem_tracker();
+    runtime_stat.init_mem_trackers();
     DescriptorTbl desc_tbl;
     desc_tbl._slot_desc_map[0] = tuple_desc->slots()[0];
     runtime_stat.set_desc_tbl(&desc_tbl);
-    std::shared_ptr<doris::MemTracker> tracker = doris::MemTracker::CreateTracker();
-    context->prepare(&runtime_stat, row_desc, tracker);
-    context->open(&runtime_stat);
+    auto state = Status::OK();
+    state = context->prepare(&runtime_stat, row_desc);
+    ASSERT_TRUE(state.ok());
+    state = context->open(&runtime_stat);
+    ASSERT_TRUE(state.ok());
 
     auto block = row_batch.convert_to_vec_block();
     int ts = -1;
-    context->execute(&block, &ts);
+    state = context->execute(&block, &ts);
     context->close(&runtime_stat);
 }
 
@@ -188,6 +191,13 @@ struct literal_traits<TYPE_DATETIME> {
     using CXXType = std::string;
 };
 
+template <>
+struct literal_traits<TYPE_DATEV2> {
+    const static TPrimitiveType::type ttype = TPrimitiveType::DATEV2;
+    const static TExprNodeType::type tnode_type = TExprNodeType::STRING_LITERAL;
+    using CXXType = std::string;
+};
+
 template <>
 struct literal_traits<TYPE_DECIMALV2> {
     const static TPrimitiveType::type ttype = TPrimitiveType::DECIMALV2;
@@ -225,6 +235,14 @@ void set_literal(TExprNode& node, const U& value) {
     node.__set_date_literal(date_literal);
 }
 
+template <PrimitiveType T, class U = typename literal_traits<T>::CXXType,
+          std::enable_if_t<T == TYPE_DATEV2, bool> = true>
+void set_literal(TExprNode& node, const U& value) {
+    TDateLiteral date_literal;
+    date_literal.__set_value(value);
+    node.__set_date_literal(date_literal);
+}
+
 template <PrimitiveType T, class U = typename literal_traits<T>::CXXType,
           std::enable_if_t<std::numeric_limits<U>::is_iec559, bool> = true>
 void set_literal(TExprNode& node, const U& value) {
@@ -342,6 +360,20 @@ TEST(TEST_VEXPR, LITERALTEST) {
         auto v = (*ctn.column)[0].get<__int64_t>();
         EXPECT_EQ(v, dt);
     }
+    {
+        vectorized::DateV2Value<doris::vectorized::DateV2ValueType> data_time_value;
+        const char* date = "20210407";
+        data_time_value.from_date_str(date, strlen(date));
+        uint32_t dt;
+        memcpy(&dt, &data_time_value, sizeof(uint32_t));
+        VLiteral literal(create_literal<TYPE_DATEV2, std::string>(std::string(date)));
+        Block block;
+        int ret = -1;
+        literal.execute(nullptr, &block, &ret);
+        auto ctn = block.safe_get_by_position(ret);
+        auto v = (*ctn.column)[0].get<uint32_t>();
+        EXPECT_EQ(v, dt);
+    }
     {
         VLiteral literal(create_literal<TYPE_DECIMALV2, std::string>(std::string("1234.56")));
         Block block;
