@@ -21,11 +21,9 @@
 #include <string>
 
 #include "function_test_util.h"
-#include "runtime/tuple_row.h"
 #include "util/encryption_util.h"
-#include "util/url_coding.h"
-#include "vec/core/field.h"
 #include "vec/core/types.h"
+#include "vec/data_types/data_type_array.h"
 #include "vec/data_types/data_type_string.h"
 
 namespace doris::vectorized {
@@ -171,6 +169,7 @@ TEST(function_string_test, function_string_repeat_test) {
                         {{std::string("hel lo"), 2}, std::string("hel lohel lo")},
                         {{std::string("hello word"), -1}, std::string("")},
                         {{std::string(""), 1}, std::string("")},
+                        {{std::string("134"), 1073741825}, Null()}, // bigger than 1GB
                         {{std::string("HELLO,!^%"), 2}, std::string("HELLO,!^%HELLO,!^%")},
                         {{std::string("你"), 2}, std::string("你你")}};
     check_function<DataTypeString, true>(func_name, input_types, data_set);
@@ -346,6 +345,50 @@ TEST(function_string_test, function_concat_test) {
     };
 }
 
+TEST(function_string_test, function_elt_test) {
+    std::string func_name = "elt";
+
+    {
+        InputTypeSet input_types = {TypeIndex::Int32, TypeIndex::String, TypeIndex::String};
+
+        DataSet data_set = {{{1, std::string("hello"), std::string("world")}, std::string("hello")},
+                            {{1, std::string("你好"), std::string("百度")}, std::string("你好")},
+                            {{1, std::string("hello"), std::string("")}, std::string("hello")}};
+
+        check_function<DataTypeString, true>(func_name, input_types, data_set);
+    };
+
+    {
+        InputTypeSet input_types = {TypeIndex::Int32, TypeIndex::String, TypeIndex::String};
+
+        DataSet data_set = {{{2, std::string("hello"), std::string("world")}, std::string("world")},
+                            {{2, std::string("你好"), std::string("百度")}, std::string("百度")},
+                            {{2, std::string("hello"), std::string("")}, std::string("")}};
+
+        check_function<DataTypeString, true>(func_name, input_types, data_set);
+    };
+
+    {
+        InputTypeSet input_types = {TypeIndex::Int32, TypeIndex::String, TypeIndex::String};
+
+        DataSet data_set = {{{0, std::string("hello"), std::string("world")}, Null()},
+                            {{0, std::string("你好"), std::string("百度")}, Null()},
+                            {{0, std::string("hello"), std::string("")}, Null()}};
+
+        check_function<DataTypeString, true>(func_name, input_types, data_set);
+    };
+
+    {
+        InputTypeSet input_types = {TypeIndex::Int32, TypeIndex::String, TypeIndex::String};
+
+        DataSet data_set = {{{3, std::string("hello"), std::string("world")}, Null()},
+                            {{3, std::string("你好"), std::string("百度")}, Null()},
+                            {{3, std::string("hello"), std::string("")}, Null()}};
+
+        check_function<DataTypeString, true>(func_name, input_types, data_set);
+    };
+}
+
 TEST(function_string_test, function_concat_ws_test) {
     std::string func_name = "concat_ws";
     {
@@ -390,6 +433,23 @@ TEST(function_string_test, function_concat_ws_test) {
 
         check_function<DataTypeString, true>(func_name, input_types, data_set);
     };
+
+    {
+        InputTypeSet input_types = {TypeIndex::String, TypeIndex::Array, TypeIndex::String};
+
+        Array vec1 = {Field("", 0), Field("", 0), Field("", 0)};
+        Array vec2 = {Field("123", 3), Field("456", 3), Field("789", 3)};
+        Array vec3 = {Field("", 0), Field("?", 1), Field("", 0)};
+        Array vec4 = {Field("abc", 3), Field("", 0), Field("def", 3)};
+        Array vec5 = {Field("abc", 3), Field("def", 3), Field("ghi", 3)};
+        DataSet data_set = {{{std::string("-"), vec1}, std::string("--")},
+                            {{std::string(""), vec2}, std::string("123456789")},
+                            {{std::string("-"), vec3}, std::string("-?-")},
+                            {{Null(), vec4}, Null()},
+                            {{std::string("-"), vec5}, std::string("abc-def-ghi")}};
+
+        check_function<DataTypeString, true>(func_name, input_types, data_set);
+    };
 }
 
 TEST(function_string_test, function_null_or_empty_test) {
@@ -512,23 +572,6 @@ TEST(function_string_test, function_find_in_set_test) {
     check_function<DataTypeInt32, true>(func_name, input_types, data_set);
 }
 
-TEST(function_string_test, function_string_splitpart_test) {
-    std::string func_name = "split_part";
-    InputTypeSet input_types = {TypeIndex::String, TypeIndex::String, TypeIndex::Int32};
-
-    DataSet data_set = {
-            {{std::string("prefix_string1"), std::string("_"), 2}, std::string("string1")},
-            {{std::string("prefix__string2"), std::string("__"), 2}, std::string("string2")},
-            {{std::string("prefix__string2"), std::string("_"), 2}, std::string("")},
-            {{std::string("prefix_string2"), std::string("__"), 1}, Null()},
-            {{Null(), std::string("__"), 1}, Null()},
-            {{std::string("prefix_string"), Null(), 1}, Null()},
-            {{std::string("prefix_string"), std::string("__"), Null()}, Null()},
-            {{std::string("prefix_string"), std::string("__"), -1}, Null()}};
-
-    check_function<DataTypeString, true>(func_name, input_types, data_set);
-}
-
 TEST(function_string_test, function_md5sum_test) {
     std::string func_name = "md5sum";
 
@@ -642,9 +685,9 @@ TEST(function_string_test, function_aes_encrypt_test) {
             int cipher_len = strlen(src[i]) + 16;
             char p[cipher_len];
 
-            int outlen = EncryptionUtil::encrypt(AES_128_ECB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 NULL, true, (unsigned char*)p);
+            int outlen = EncryptionUtil::encrypt(
+                    EncryptionMode::AES_128_ECB, (unsigned char*)src[i], strlen(src[i]),
+                    (unsigned char*)key, strlen(key), nullptr, 0, true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -675,9 +718,10 @@ TEST(function_string_test, function_aes_encrypt_test) {
             init_vec.reset(new char[iv_len]);
             std::memset(init_vec.get(), 0, strlen(iv) + 1);
             memcpy(init_vec.get(), iv, strlen(iv));
-            int outlen = EncryptionUtil::encrypt(AES_256_ECB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 init_vec.get(), true, (unsigned char*)p);
+            int outlen =
+                    EncryptionUtil::encrypt(EncryptionMode::AES_256_ECB, (unsigned char*)src[i],
+                                            strlen(src[i]), (unsigned char*)key, strlen(key),
+                                            init_vec.get(), strlen(iv), true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -708,9 +752,9 @@ TEST(function_string_test, function_aes_decrypt_test) {
             int cipher_len = strlen(src[i]) + 16;
             char p[cipher_len];
 
-            int outlen = EncryptionUtil::encrypt(AES_128_ECB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 NULL, true, (unsigned char*)p);
+            int outlen = EncryptionUtil::encrypt(
+                    EncryptionMode::AES_128_ECB, (unsigned char*)src[i], strlen(src[i]),
+                    (unsigned char*)key, strlen(key), nullptr, 0, true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -740,9 +784,10 @@ TEST(function_string_test, function_aes_decrypt_test) {
             init_vec.reset(new char[iv_len]);
             std::memset(init_vec.get(), 0, strlen(iv) + 1);
             memcpy(init_vec.get(), iv, strlen(iv));
-            int outlen = EncryptionUtil::encrypt(AES_128_OFB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 init_vec.get(), true, (unsigned char*)p);
+            int outlen =
+                    EncryptionUtil::encrypt(EncryptionMode::AES_128_OFB, (unsigned char*)src[i],
+                                            strlen(src[i]), (unsigned char*)key, strlen(key),
+                                            init_vec.get(), strlen(iv), true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
         DataSet data_set = {
@@ -770,9 +815,9 @@ TEST(function_string_test, function_sm4_encrypt_test) {
             int cipher_len = strlen(src[i]) + 16;
             char p[cipher_len];
 
-            int outlen = EncryptionUtil::encrypt(SM4_128_ECB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 NULL, true, (unsigned char*)p);
+            int outlen = EncryptionUtil::encrypt(
+                    EncryptionMode::SM4_128_ECB, (unsigned char*)src[i], strlen(src[i]),
+                    (unsigned char*)key, strlen(key), nullptr, 0, true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -805,9 +850,10 @@ TEST(function_string_test, function_sm4_encrypt_test) {
             init_vec.reset(new char[iv_len]);
             std::memset(init_vec.get(), 0, strlen(iv) + 1);
             memcpy(init_vec.get(), iv, strlen(iv));
-            int outlen = EncryptionUtil::encrypt(SM4_128_CTR, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 init_vec.get(), true, (unsigned char*)p);
+            int outlen =
+                    EncryptionUtil::encrypt(EncryptionMode::SM4_128_CTR, (unsigned char*)src[i],
+                                            strlen(src[i]), (unsigned char*)key, strlen(key),
+                                            init_vec.get(), strlen(iv), true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -838,9 +884,9 @@ TEST(function_string_test, function_sm4_decrypt_test) {
             int cipher_len = strlen(src[i]) + 16;
             char p[cipher_len];
 
-            int outlen = EncryptionUtil::encrypt(SM4_128_ECB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 NULL, true, (unsigned char*)p);
+            int outlen = EncryptionUtil::encrypt(
+                    EncryptionMode::SM4_128_ECB, (unsigned char*)src[i], strlen(src[i]),
+                    (unsigned char*)key, strlen(key), nullptr, 0, true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -872,9 +918,10 @@ TEST(function_string_test, function_sm4_decrypt_test) {
             init_vec.reset(new char[iv_len]);
             std::memset(init_vec.get(), 0, strlen(iv) + 1);
             memcpy(init_vec.get(), iv, strlen(iv));
-            int outlen = EncryptionUtil::encrypt(SM4_128_OFB, (unsigned char*)src[i],
-                                                 strlen(src[i]), (unsigned char*)key, strlen(key),
-                                                 init_vec.get(), true, (unsigned char*)p);
+            int outlen =
+                    EncryptionUtil::encrypt(EncryptionMode::SM4_128_OFB, (unsigned char*)src[i],
+                                            strlen(src[i]), (unsigned char*)key, strlen(key),
+                                            init_vec.get(), strlen(iv), true, (unsigned char*)p);
             r[i] = std::string(p, outlen);
         }
 
@@ -890,6 +937,31 @@ TEST(function_string_test, function_sm4_decrypt_test) {
     }
 }
 
+TEST(function_string_test, function_extract_url_parameter_test) {
+    std::string func_name = "extract_url_parameter";
+    InputTypeSet input_types = {TypeIndex::String, TypeIndex::String};
+    DataSet data_set = {
+            {{VARCHAR(""), VARCHAR("k1")}, {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa"), VARCHAR("")}, {VARCHAR("")}},
+            {{VARCHAR("https://doris.apache.org/"), VARCHAR("k1")}, {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?"), VARCHAR("k1")}, {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa"), VARCHAR("k1")}, {VARCHAR("aa")}},
+            {{VARCHAR("http://doris.apache.org:8080?k1&k2=bb#99"), VARCHAR("k1")}, {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa#999"), VARCHAR("k1")}, {VARCHAR("aa")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa&k2=bb&test=dd#999/"), VARCHAR("k1")},
+             {VARCHAR("aa")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa&k2=bb&test=dd#999/"), VARCHAR("k2")},
+             {VARCHAR("bb")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa&k2=bb&test=dd#999/"), VARCHAR("999")},
+             {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa&k2=bb&test=dd#999/"), VARCHAR("k3")},
+             {VARCHAR("")}},
+            {{VARCHAR("http://doris.apache.org?k1=aa&k2=bb&test=dd#999/"), VARCHAR("test")},
+             {VARCHAR("dd")}}};
+
+    check_function<DataTypeString, true>(func_name, input_types, data_set);
+}
+
 TEST(function_string_test, function_parse_url_test) {
     std::string func_name = "parse_url";
 
@@ -1023,13 +1095,13 @@ TEST(function_string_test, function_str_to_date_test) {
     DataSet data_set = {
             {{Null(), std::string("%Y-%m-%d %H:%i:%s")}, {Null()}},
             {{std::string("2014-12-21 12:34:56"), std::string("%Y-%m-%d %H:%i:%s")},
-             str_to_data_time("2014-12-21 12:34:56", false)},
+             str_to_date_time("2014-12-21 12:34:56", false)},
             {{std::string("2014-12-21 12:34%3A56"), std::string("%Y-%m-%d %H:%i%%3A%s")},
-             str_to_data_time("2014-12-21 12:34:56", false)},
+             str_to_date_time("2014-12-21 12:34:56", false)},
             {{std::string("11/09/2011"), std::string("%m/%d/%Y")},
-             str_to_data_time("2011-11-09", false)},
+             str_to_date_time("2011-11-09", false)},
             {{std::string("2020-09-01"), std::string("%Y-%m-%d %H:%i:%s")},
-             str_to_data_time("2020-09-01 00:00:00", false)}};
+             str_to_date_time("2020-09-01 00:00:00", false)}};
     check_function<DataTypeDateTime, true>(func_name, input_types, data_set);
 }
 
