@@ -23,6 +23,7 @@ import org.apache.doris.catalog.PrimitiveType;
 import org.apache.doris.catalog.ScalarType;
 import org.apache.doris.catalog.Type;
 import org.apache.doris.common.AnalysisException;
+import org.apache.doris.common.Config;
 import org.apache.doris.common.ErrorCode;
 import org.apache.doris.common.ErrorReport;
 import org.apache.doris.thrift.TExprNode;
@@ -30,10 +31,12 @@ import org.apache.doris.thrift.TExprNodeType;
 import org.apache.doris.thrift.TExprOpcode;
 
 import com.google.common.base.Preconditions;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
 import java.util.HashMap;
+import java.util.Locale;
 import java.util.Map;
 
 /**
@@ -84,6 +87,52 @@ public class TimestampArithmeticExpr extends Expr {
         children.add(e2);
     }
 
+    /**
+     * used for Nereids ONLY.
+     * C'tor for function-call like arithmetic, e.g., 'date_add(a, interval b year)'.
+     *
+     * @param funcName timestamp arithmetic function name, used for all function except ADD and SUBTRACT.
+     * @param e1 non interval literal child of this function
+     * @param e2 interval literal child of this function
+     * @param timeUnitIdent interval time unit, could be 'year', 'month', 'day', 'hour', 'minute', 'second'.
+     * @param dataType the return data type of this expression.
+     */
+    public TimestampArithmeticExpr(String funcName, Expr e1, Expr e2, String timeUnitIdent, Type dataType) {
+        this.funcName = funcName;
+        this.timeUnitIdent = timeUnitIdent;
+        this.timeUnit = TIME_UNITS_MAP.get(timeUnitIdent.toUpperCase(Locale.ROOT));
+        this.intervalFirst = false;
+        children.add(e1);
+        children.add(e2);
+        this.type = dataType;
+    }
+
+    /**
+     * used for Nereids ONLY.
+     * C'tor for non-function-call like arithmetic, e.g., 'a + interval b year'.
+     * e1 always refers to the timestamp to be added/subtracted from, and e2
+     * to the time value (even in the interval-first case).
+     *
+     * @param op operator of this function either ADD or SUBTRACT.
+     * @param e1 non interval literal child of this function
+     * @param e2 interval literal child of this function
+     * @param timeUnitIdent interval time unit, could be 'year', 'month', 'day', 'hour', 'minute', 'second'.
+     * @param intervalFirst true if the left child is interval literal
+     * @param dataType the return data type of this expression.
+     */
+    public TimestampArithmeticExpr(ArithmeticExpr.Operator op, Expr e1, Expr e2,
+            String timeUnitIdent, boolean intervalFirst, Type dataType) {
+        Preconditions.checkState(op == Operator.ADD || op == Operator.SUBTRACT);
+        this.funcName = null;
+        this.op = op;
+        this.timeUnitIdent = timeUnitIdent;
+        this.timeUnit = TIME_UNITS_MAP.get(timeUnitIdent.toUpperCase(Locale.ROOT));
+        this.intervalFirst = intervalFirst;
+        children.add(e1);
+        children.add(e2);
+        this.type = dataType;
+    }
+
     protected TimestampArithmeticExpr(TimestampArithmeticExpr other) {
         super(other);
         funcName = other.funcName;
@@ -111,6 +160,16 @@ public class TimestampArithmeticExpr extends Expr {
         if (t1 == PrimitiveType.DATE) {
             return Type.DATE;
         }
+        if (t1 == PrimitiveType.DATETIMEV2) {
+            return Type.DATETIMEV2;
+        }
+        if (t1 == PrimitiveType.DATEV2) {
+            return Type.DATEV2;
+        }
+        if (Config.enable_date_conversion
+                && PrimitiveType.isImplicitCast(t1, PrimitiveType.DATETIMEV2)) {
+            return Type.DATETIMEV2;
+        }
         if (PrimitiveType.isImplicitCast(t1, PrimitiveType.DATETIME)) {
             return Type.DATETIME;
         }
@@ -129,7 +188,7 @@ public class TimestampArithmeticExpr extends Expr {
             }
             Type dateType = fixType();
             if (dateType.isDate() && timeUnit.isDateTime()) {
-                dateType = Type.DATETIME;
+                dateType = ScalarType.getDefaultDateType(Type.DATETIME);
             }
             // The first child must return a timestamp or null.
             if (!getChild(0).getType().isDateType() && !getChild(0).getType().isNull()) {
@@ -183,6 +242,9 @@ public class TimestampArithmeticExpr extends Expr {
             if (dateType.isDate() && timeUnit.isDateTime()) {
                 dateType = Type.DATETIME;
             }
+            if (dateType.isDateV2() && timeUnit.isDateTime()) {
+                dateType = Type.DATETIMEV2;
+            }
             // The first child must return a timestamp or null.
             if (!getChild(0).getType().isDateType() && !getChild(0).getType().isNull()) {
                 if (!dateType.isValid()) {
@@ -214,7 +276,7 @@ public class TimestampArithmeticExpr extends Expr {
         }
 
         Type[] childrenTypes = collectChildReturnTypes();
-        fn = getBuiltinFunction(analyzer, funcOpName.toLowerCase(), childrenTypes,
+        fn = getBuiltinFunction(funcOpName.toLowerCase(), childrenTypes,
                 Function.CompareMode.IS_NONSTRICT_SUPERTYPE_OF);
         Preconditions.checkArgument(fn != null);
         Type[] argTypes = fn.getArgs();
@@ -223,8 +285,8 @@ public class TimestampArithmeticExpr extends Expr {
             for (int i = 0; i < childrenTypes.length; ++i) {
                 // For varargs, we must compare with the last type in callArgs.argTypes.
                 int ix = Math.min(argTypes.length - 1, i);
-                if (!childrenTypes[i].matchesType(argTypes[ix]) &&
-                        !(childrenTypes[i].isDateType() && argTypes[ix].isDateType())) {
+                if (!childrenTypes[i].matchesType(argTypes[ix]) && !(
+                        childrenTypes[i].isDateOrDateTime() && argTypes[ix].isDateOrDateTime())) {
                     uncheckedCastChild(argTypes[ix], i);
                 }
             }
@@ -235,7 +297,7 @@ public class TimestampArithmeticExpr extends Expr {
     @Override
     protected void toThrift(TExprNode msg) {
         msg.node_type = TExprNodeType.COMPUTE_FUNCTION_CALL;
-        msg.setOpcode(opcode);                    
+        msg.setOpcode(opcode);
     }
 
     public ArithmeticExpr.Operator getOp() {
@@ -339,6 +401,44 @@ public class TimestampArithmeticExpr extends Expr {
         return strBuilder.toString();
     }
 
+    @Override
+    public String toDigestImpl() {
+        StringBuilder strBuilder = new StringBuilder();
+        if (funcName != null) {
+            if (funcName.equalsIgnoreCase("TIMESTAMPDIFF") || funcName.equalsIgnoreCase("TIMESTAMPADD")) {
+                strBuilder.append(funcName).append("(");
+                strBuilder.append(timeUnitIdent).append(", ");
+                strBuilder.append(getChild(1).toDigest()).append(", ");
+                strBuilder.append(getChild(0).toDigest()).append(")");
+                return strBuilder.toString();
+            }
+            // Function-call like version.
+            strBuilder.append(funcName).append("(");
+            strBuilder.append(getChild(0).toDigest()).append(", ");
+            strBuilder.append("INTERVAL ");
+            strBuilder.append(getChild(1).toDigest());
+            strBuilder.append(" ").append(timeUnitIdent);
+            strBuilder.append(")");
+            return strBuilder.toString();
+        }
+        if (intervalFirst) {
+            // Non-function-call like version with interval as first operand.
+            strBuilder.append("INTERVAL ");
+            strBuilder.append(getChild(1).toDigest() + " ");
+            strBuilder.append(timeUnitIdent);
+            strBuilder.append(" ").append(op.toString()).append(" ");
+            strBuilder.append(getChild(0).toDigest());
+        } else {
+            // Non-function-call like version with interval as second operand.
+            strBuilder.append(getChild(0).toDigest());
+            strBuilder.append(" " + op.toString() + " ");
+            strBuilder.append("INTERVAL ");
+            strBuilder.append(getChild(1).toDigest() + " ");
+            strBuilder.append(timeUnitIdent);
+        }
+        return strBuilder.toString();
+    }
+
     // Time units supported in timestamp arithmetic.
     public enum TimeUnit {
         YEAR("YEAR"),                               // YEARS
@@ -379,4 +479,15 @@ public class TimestampArithmeticExpr extends Expr {
             return description;
         }
     }
+
+    @Override
+    public void finalizeImplForNereids() throws AnalysisException {
+        if (StringUtils.isEmpty(funcName)) {
+            throw new AnalysisException("function name is null");
+        }
+        timeUnit = TIME_UNITS_MAP.get(timeUnitIdent.toUpperCase());
+        opcode = getOpCode();
+        fn = getBuiltinFunction(funcName.toLowerCase(), collectChildReturnTypes(),
+                Function.CompareMode.IS_NONSTRICT_SUPERTYPE_OF);
+    }
 }
