@@ -35,10 +35,12 @@ import java.io.IOException;
 import java.util.Objects;
 
 public class DataProperty implements Writable, GsonPostProcessable {
-    public static final TStorageMedium DEFAULT_STORAGE_MEDIUM =
-            "SSD".equalsIgnoreCase(Config.default_storage_medium) ? TStorageMedium.SSD : TStorageMedium.HDD;
+    public static final TStorageMedium DEFAULT_STORAGE_MEDIUM = "SSD".equalsIgnoreCase(Config.default_storage_medium)
+            ? TStorageMedium.SSD : TStorageMedium.HDD;
     public static final long MAX_COOLDOWN_TIME_MS = 253402271999000L; // 9999-12-31 23:59:59
 
+    public static final DataProperty DEFAULT_HDD_DATA_PROPERTY = new DataProperty(TStorageMedium.HDD);
+
     @SerializedName(value = "storageMedium")
     private TStorageMedium storageMedium;
     @SerializedName(value = "cooldownTimeMs")
@@ -56,6 +58,12 @@ public class DataProperty implements Writable, GsonPostProcessable {
         this.storagePolicy = "";
     }
 
+    public DataProperty(DataProperty other) {
+        this.storageMedium = other.storageMedium;
+        this.cooldownTimeMs = other.cooldownTimeMs;
+        this.storagePolicy = other.storagePolicy;
+    }
+
     /**
      * DataProperty construction.
      *
