@@ -21,7 +21,6 @@ import org.apache.doris.common.io.Text;
 import org.apache.doris.common.io.Writable;
 
 import com.google.gson.annotations.SerializedName;
-
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
@@ -36,6 +35,7 @@ import java.util.Comparator;
 public class Replica implements Writable {
     private static final Logger LOG = LogManager.getLogger(Replica.class);
     public static final VersionComparator<Replica> VERSION_DESC_COMPARATOR = new VersionComparator<Replica>();
+    public static final IdComparator<Replica> ID_COMPARATOR = new IdComparator<Replica>();
 
     public enum ReplicaState {
         NORMAL,
@@ -80,6 +80,8 @@ public class Replica implements Writable {
     private int schemaHash = -1;
     @SerializedName(value = "dataSize")
     private volatile long dataSize = 0;
+    @SerializedName(value = "remoteDataSize")
+    private volatile long remoteDataSize = 0;
     @SerializedName(value = "rowCount")
     private volatile long rowCount = 0;
     @SerializedName(value = "state")
@@ -133,16 +135,16 @@ public class Replica implements Writable {
     // for rollup
     // the new replica's version is -1 and last failed version is -1
     public Replica(long replicaId, long backendId, int schemaHash, ReplicaState state) {
-        this(replicaId, backendId, -1, schemaHash, 0L, 0L, state, -1, -1);
+        this(replicaId, backendId, -1, schemaHash, 0L, 0L, 0L, state, -1, -1);
     }
 
     // for create tablet and restore
     public Replica(long replicaId, long backendId, ReplicaState state, long version, int schemaHash) {
-        this(replicaId, backendId, version, schemaHash, 0L, 0L, state, -1L, version);
+        this(replicaId, backendId, version, schemaHash, 0L, 0L, 0L, state, -1L, version);
     }
 
     public Replica(long replicaId, long backendId, long version, int schemaHash,
-                       long dataSize, long rowCount, ReplicaState state, 
+                       long dataSize, long remoteDataSize, long rowCount, ReplicaState state,
                        long lastFailedVersion,
                        long lastSuccessVersion) {
         this.id = replicaId;
@@ -151,6 +153,7 @@ public class Replica implements Writable {
         this.schemaHash = schemaHash;
 
         this.dataSize = dataSize;
+        this.remoteDataSize = remoteDataSize;
         this.rowCount = rowCount;
         this.state = state;
         if (this.state == null) {
@@ -192,6 +195,10 @@ public class Replica implements Writable {
         return dataSize;
     }
 
+    public long getRemoteDataSize() {
+        return remoteDataSize;
+    }
+
     public long getRowCount() {
         return rowCount;
     }
@@ -246,34 +253,22 @@ public class Replica implements Writable {
         this.rowCount = rowNum;
     }
 
-    public synchronized void updateStat(long dataSize, long rowNum, long versionCount) {
+    public synchronized void updateStat(long dataSize, long remoteDataSize, long rowNum, long versionCount) {
         this.dataSize = dataSize;
+        this.remoteDataSize = remoteDataSize;
         this.rowCount = rowNum;
         this.versionCount = versionCount;
     }
 
-    public synchronized void updateVersionInfo(long newVersion, long newDataSize, long newRowCount) {
-        updateReplicaInfo(newVersion, this.lastFailedVersion, this.lastSuccessVersion, newDataSize, newRowCount);
-    }
-    
-    public synchronized void updateVersionWithFailedInfo(long newVersion, long lastFailedVersion, long lastSuccessVersion) {
-        updateReplicaInfo(newVersion, lastFailedVersion, lastSuccessVersion, dataSize, rowCount);
+    public synchronized void updateVersionInfo(long newVersion, long newDataSize, long newRemoteDataSize,
+                                               long newRowCount) {
+        updateReplicaInfo(newVersion, this.lastFailedVersion, this.lastSuccessVersion, newDataSize, newRemoteDataSize,
+                newRowCount);
     }
 
-    public void updateVersionInfoForRecovery(
-            long newVersion,
-            long lastFailedVersion,
-            long lastSuccessVersion) {
-
-        LOG.warn("update replica {} on backend {}'s version for recovery. version: {}:{}."
-                + " last failed version: {}:{}, last success version: {}:{}",
-                this.id, this.backendId, this.version, newVersion,
-                this.lastFailedVersion, lastFailedVersion,
-                this.lastSuccessVersion, lastSuccessVersion);
-
-        this.version = newVersion;
-        this.lastFailedVersion = lastFailedVersion;
-        this.lastSuccessVersion = lastSuccessVersion;
+    public synchronized void updateVersionWithFailedInfo(
+            long newVersion, long lastFailedVersion, long lastSuccessVersion) {
+        updateReplicaInfo(newVersion, lastFailedVersion, lastSuccessVersion, dataSize, remoteDataSize, rowCount);
     }
 
     /* last failed version:  LFV
@@ -300,20 +295,22 @@ public class Replica implements Writable {
      *      the V(hash) equals to LSV(hash), and V equals to LFV, but LFV hash is 0 or some unknown number.
      *      We just reset the LFV(hash) to recovery this replica.
      */
-    private void updateReplicaInfo(long newVersion, 
-            long lastFailedVersion, long lastSuccessVersion, 
-            long newDataSize, long newRowCount) {
+    private void updateReplicaInfo(long newVersion,
+            long lastFailedVersion, long lastSuccessVersion,
+            long newDataSize, long newRemoteDataSize, long newRowCount) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("before update: {}", this.toString());
         }
 
         if (newVersion < this.version) {
             // This case means that replica meta version has been updated by ReportHandler before
-            // For example, the publish version daemon has already sent some publish version tasks to one be to publish version 2, 3, 4, 5, 6,
-            // and the be finish all publish version tasks, the be's replica version is 6 now, but publish version daemon need to wait
+            // For example, the publish version daemon has already sent some publish version tasks
+            // to one be to publish version 2, 3, 4, 5, 6, and the be finish all publish version tasks,
+            // the be's replica version is 6 now, but publish version daemon need to wait
             // for other be to finish most of publish version tasks to update replica version in fe.
-            // At the moment, the replica version in fe is 4, when ReportHandler sync tablet, it find reported replica version in be is 6 and then
-            // set version to 6 for replica in fe. And then publish version daemon try to finish txn, and use visible version(5)
+            // At the moment, the replica version in fe is 4, when ReportHandler sync tablet,
+            // it find reported replica version in be is 6 and then set version to 6 for replica in fe.
+            // And then publish version daemon try to finish txn, and use visible version(5)
             // to update replica. Finally, it find the newer version(5) is lower than replica version(6) in fe.
             if (LOG.isDebugEnabled()) {
                 LOG.debug("replica {} on backend {}'s new version {} is lower than meta version {},"
@@ -324,6 +321,7 @@ public class Replica implements Writable {
 
         this.version = newVersion;
         this.dataSize = newDataSize;
+        this.remoteDataSize = newRemoteDataSize;
         this.rowCount = newRowCount;
 
         // just check it
@@ -339,7 +337,7 @@ public class Replica implements Writable {
         // TODO: this case is unknown, add log to observe
         if (this.version > lastFailedVersion && lastFailedVersion > 0) {
             LOG.debug("current version {} is larger than last failed version {}, "
-                        + "maybe a fatal error or be report version, print a stack here ", 
+                        + "maybe a fatal error or be report version, print a stack here ",
                     this.version, lastFailedVersion, new Exception());
         }
 
@@ -375,15 +373,17 @@ public class Replica implements Writable {
             LOG.debug("after update {}", this.toString());
         }
     }
-    
+
     public synchronized void updateLastFailedVersion(long lastFailedVersion) {
-        updateReplicaInfo(this.version, lastFailedVersion, this.lastSuccessVersion, dataSize, rowCount);
+        updateReplicaInfo(this.version, lastFailedVersion, this.lastSuccessVersion, dataSize, remoteDataSize, rowCount);
     }
 
     /*
      * Check whether the replica's version catch up with the expected version.
-     * If ignoreAlter is true, and state is ALTER, and replica's version is PARTITION_INIT_VERSION, just return true, ignore the version.
-     *      This is for the case that when altering table, the newly created replica's version is PARTITION_INIT_VERSION,
+     * If ignoreAlter is true, and state is ALTER, and replica's version is
+     *  PARTITION_INIT_VERSION, just return true, ignore the version.
+     *      This is for the case that when altering table,
+     *      the newly created replica's version is PARTITION_INIT_VERSION,
      *      but we need to treat it as a "normal" replica which version is supposed to be "catch-up".
      *      But if state is ALTER but version larger than PARTITION_INIT_VERSION, which means this replica
      *      is already updated by load process, so we need to consider its version.
@@ -392,7 +392,7 @@ public class Replica implements Writable {
         if (ignoreAlter && state == ReplicaState.ALTER && version == Partition.PARTITION_INIT_VERSION) {
             return true;
         }
-        
+
         if (expectedVersion == Partition.PARTITION_INIT_VERSION) {
             // no data is loaded into this replica, just return true
             return true;
@@ -432,7 +432,7 @@ public class Replica implements Writable {
 
     @Override
     public String toString() {
-        StringBuffer strBuffer = new StringBuffer("[replicaId=");
+        StringBuilder strBuffer = new StringBuilder("[replicaId=");
         strBuffer.append(id);
         strBuffer.append(", BackendId=");
         strBuffer.append(backendId);
@@ -528,6 +528,22 @@ public class Replica implements Writable {
         }
     }
 
+    private static class IdComparator<T extends Replica> implements Comparator<T> {
+        public IdComparator() {
+        }
+
+        @Override
+        public int compare(T replica1, T replica2) {
+            if (replica1.getId() < replica2.getId()) {
+                return -1;
+            } else if (replica1.getId() == replica2.getId()) {
+                return 0;
+            } else {
+                return 1;
+            }
+        }
+    }
+
     public void setWatermarkTxnId(long watermarkTxnId) {
         this.watermarkTxnId = watermarkTxnId;
     }
