@@ -179,8 +179,9 @@ public class HiveMetaStoreCache {
         Map<Long, List<UniqueId>> idToUniqueIdsMap = Maps.newHashMapWithExpectedSize(partitionNames.size());
         long idx = 0;
         for (String partitionName : partitionNames) {
+            String decodedPartitionName;
             try {
-                partitionName = URLDecoder.decode(partitionName, StandardCharsets.UTF_8.name());
+                decodedPartitionName = URLDecoder.decode(partitionName, StandardCharsets.UTF_8.name());
             } catch (UnsupportedEncodingException e) {
                 // It should not be here
                 throw new RuntimeException(e);
@@ -188,7 +189,7 @@ public class HiveMetaStoreCache {
             long partitionId = idx++;
             ListPartitionItem listPartitionItem = toListPartitionItem(partitionName, key.types);
             idToPartitionItem.put(partitionId, listPartitionItem);
-            partitionNameToIdMap.put(partitionName, partitionId);
+            partitionNameToIdMap.put(decodedPartitionName, partitionId);
         }
 
         Map<UniqueId, Range<PartitionKey>> uidToPartitionRange = null;
@@ -219,7 +220,14 @@ public class HiveMetaStoreCache {
         for (String part : parts) {
             String[] kv = part.split("=");
             Preconditions.checkState(kv.length == 2, partitionName);
-            values.add(new PartitionValue(kv[1], HIVE_DEFAULT_PARTITION.equals(kv[1])));
+            String decodedValue = null;
+            try {
+                decodedValue = URLDecoder.decode(kv[1], StandardCharsets.UTF_8.name());
+            } catch (UnsupportedEncodingException e) {
+                // It should not be here
+                throw new RuntimeException(e);
+            }
+            values.add(new PartitionValue(decodedValue, HIVE_DEFAULT_PARTITION.equals(decodedValue)));
         }
         try {
             PartitionKey key = PartitionKey.createListPartitionKeyWithTypes(values, types);
@@ -262,7 +270,6 @@ public class HiveMetaStoreCache {
             FileInputFormat.setInputPaths(jobConf, finalLocation);
             try {
                 InputFormat<?, ?> inputFormat = HiveUtil.getInputFormat(jobConf, key.inputFormat, false);
-                HiveSplit[] hiveSplits;
                 InputSplit[] splits;
                 String remoteUser = jobConf.get(HdfsResource.HADOOP_USER_NAME);
                 if (!Strings.isNullOrEmpty(remoteUser)) {
@@ -279,7 +286,7 @@ public class HiveMetaStoreCache {
                     LOG.warn("Splits for location {} is null", finalLocation);
                     return ImmutableList.copyOf(new HiveSplit[0]);
                 }
-                hiveSplits = new HiveSplit[splits.length];
+                List<HiveSplit> hiveSplits = Lists.newArrayList();
                 List<String> pValues;
                 // handle default hive partition case, replace the default partition value with null_string.
                 if (key.hasDefaultPartitionValue) {
@@ -295,9 +302,15 @@ public class HiveMetaStoreCache {
                     pValues = key.partitionValues;
                 }
                 for (int i = 0; i < splits.length; i++) {
+                    if (splits[i].getLength() == 0) {
+                        if (LOG.isDebugEnabled()) {
+                            LOG.debug("get empty file {}, skip it", splits[i].toString());
+                        }
+                        continue;
+                    }
                     FileSplit fileSplit = (FileSplit) splits[i];
-                    hiveSplits[i] = new HiveSplit(fileSplit.getPath(), fileSplit.getStart(), fileSplit.getLength(),
-                        fileSplit.getLength(), null, pValues);
+                    hiveSplits.add(new HiveSplit(fileSplit.getPath(), fileSplit.getStart(), fileSplit.getLength(),
+                            fileSplit.getLength(), null, pValues));
                 }
                 return ImmutableList.copyOf(hiveSplits);
             } catch (Exception e) {
