@@ -18,7 +18,7 @@
 package org.apache.doris.httpv2.rest;
 
 import org.apache.doris.analysis.UserIdentity;
-import org.apache.doris.catalog.Catalog;
+import org.apache.doris.catalog.Env;
 import org.apache.doris.cluster.ClusterNamespace;
 import org.apache.doris.httpv2.controller.BaseController;
 import org.apache.doris.httpv2.exception.UnauthorizedException;
@@ -28,7 +28,6 @@ import org.apache.doris.thrift.TNetworkAddress;
 
 import com.google.common.base.Preconditions;
 import com.google.common.base.Strings;
-
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 import org.springframework.web.servlet.view.RedirectView;
@@ -39,7 +38,6 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.net.URI;
-
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
@@ -58,8 +56,8 @@ public class RestBaseController extends BaseController {
         ActionAuthorizationInfo authInfo = getAuthorizationInfo(request);
         // check password
         UserIdentity currentUser = checkPassword(authInfo);
-        ConnectContext ctx = new ConnectContext(null);
-        ctx.setCatalog(Catalog.getCurrentCatalog());
+        ConnectContext ctx = new ConnectContext();
+        ctx.setEnv(Env.getCurrentEnv());
         ctx.setQualifiedUser(authInfo.fullUserName);
         ctx.setRemoteIP(authInfo.remoteIp);
         ctx.setCurrentUserIdentity(currentUser);
@@ -85,11 +83,10 @@ public class RestBaseController extends BaseController {
             //I don't know why the format username@default_cluster is used in parseAuthInfo.
             //It is estimated that it is compatible with the standard format of username:password.
             //So here we feel that we can assemble it completely by hand.
-            String clusterName = ConnectContext.get() == null ?
-                SystemInfoService.DEFAULT_CLUSTER : ConnectContext.get().getClusterName();
-            userInfo = ClusterNamespace.getNameFromFullName(authInfo.fullUserName) +
-                "@" + clusterName  +
-                ":" + authInfo.password;
+            String clusterName = ConnectContext.get() == null
+                    ? SystemInfoService.DEFAULT_CLUSTER : ConnectContext.get().getClusterName();
+            userInfo = ClusterNamespace.getNameFromFullName(authInfo.fullUserName)
+                    + "@" + clusterName  + ":" + authInfo.password;
         }
         try {
             urlObj = new URI(urlStr);
@@ -110,11 +107,11 @@ public class RestBaseController extends BaseController {
     }
 
     public RedirectView redirectToMaster(HttpServletRequest request, HttpServletResponse response) {
-        Catalog catalog = Catalog.getCurrentCatalog();
-        if (catalog.isMaster()) {
+        Env env = Env.getCurrentEnv();
+        if (env.isMaster()) {
             return null;
         }
-        return redirectTo(request, new TNetworkAddress(catalog.getMasterIp(), catalog.getMasterHttpPort()));
+        return redirectTo(request, new TNetworkAddress(env.getMasterIp(), env.getMasterHttpPort()));
     }
 
     public void getFile(HttpServletRequest request, HttpServletResponse response, Object obj, String fileName)
@@ -158,7 +155,8 @@ public class RestBaseController extends BaseController {
         }
     }
 
-    public void writeFileResponse(HttpServletRequest request, HttpServletResponse response, File imageFile) throws IOException {
+    public void writeFileResponse(HttpServletRequest request,
+            HttpServletResponse response, File imageFile) throws IOException {
         Preconditions.checkArgument(imageFile != null && imageFile.exists());
         response.setHeader("Content-type", "application/octet-stream");
         response.addHeader("Content-Disposition", "attachment;fileName=" + imageFile.getName());
