@@ -25,7 +25,7 @@ import org.apache.doris.analysis.LiteralExpr;
 import org.apache.doris.analysis.Predicate;
 import org.apache.doris.analysis.SlotRef;
 import org.apache.doris.analysis.StringLiteral;
-import org.apache.doris.catalog.Catalog;
+import org.apache.doris.catalog.Env;
 import org.apache.doris.catalog.Replica;
 import org.apache.doris.common.Config;
 import org.apache.doris.common.FeConstants;
@@ -42,7 +42,6 @@ import com.google.common.base.Strings;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
-
 import org.apache.logging.log4j.LogManager;
 import org.apache.logging.log4j.Logger;
 
@@ -73,7 +72,7 @@ public class LoadJob implements Writable {
     }
 
     private static final int DEFAULT_TIMEOUT_S = 0;
-    private static final long DEFAULT_EXEC_MEM_LIMIT = 4294967296L; // 4GB
+    private static final long DEFAULT_EXEC_MEM_LIMIT = 2147483648L; // 2GB
 
     private long id;
     private long dbId;
@@ -92,7 +91,7 @@ public class LoadJob implements Writable {
     // progress has two functions at ETL stage:
     // 1. when progress < 100, it indicates ETL progress
     // 2. set progress = 100 ONLY when ETL progress is completely done
-    // 
+    //
     // when at LOADING stage, use it normally (as real progress)
     private int progress;
 
@@ -329,7 +328,6 @@ public class LoadJob implements Writable {
     public void setEtlFinishTimeMs(long etlFinishTimeMs) {
         this.etlFinishTimeMs = etlFinishTimeMs;
         if (etlStartTimeMs > -1) {
-            long etlCostMs = etlFinishTimeMs - etlStartTimeMs;
             switch (etlJobType) {
                 case HADOOP:
                     break;
@@ -357,18 +355,6 @@ public class LoadJob implements Writable {
 
     public void setLoadFinishTimeMs(long loadFinishTimeMs) {
         this.loadFinishTimeMs = loadFinishTimeMs;
-        long loadCostMs = loadFinishTimeMs - loadStartTimeMs;
-        long totalCostMs = loadFinishTimeMs - createTimeMs;
-        switch (etlJobType) {
-            case HADOOP:
-                break;
-            case MINI:
-                break;
-            case BROKER:
-                break;
-            default:
-                break;
-        }
     }
 
     public long getQuorumFinishTimeMs() {
@@ -489,7 +475,6 @@ public class LoadJob implements Writable {
     public void setHadoopEtlJobId(String etlJobId) {
         if (etlJobType == EtlJobType.HADOOP) {
             ((HadoopEtlJobInfo) etlJobInfo).setEtlJobId(etlJobId);
-            ;
         }
     }
 
@@ -663,7 +648,8 @@ public class LoadJob implements Writable {
                 + ", loadFinishTimeMs=" + loadFinishTimeMs + ", failMsg=" + failMsg + ", etlJobType=" + etlJobType
                 + ", etlJobInfo=" + etlJobInfo + ", priority=" + priority + ", transactionId=" + transactionId
                 + ", quorumFinishTimeMs=" + quorumFinishTimeMs
-                + ", unfinished tablets=[" + this.unfinishedTablets.subList(0, Math.min(3, this.unfinishedTablets.size())) + "]"
+                + ", unfinished tablets=[" + this.unfinishedTablets.subList(
+                        0, Math.min(3, this.unfinishedTablets.size())) + "]"
                 + "]";
     }
 
@@ -850,7 +836,7 @@ public class LoadJob implements Writable {
     }
 
     public void readFields(DataInput in) throws IOException {
-        long version = Catalog.getCurrentCatalogJournalVersion();
+        long version = Env.getCurrentEnvJournalVersion();
 
         id = in.readLong();
         dbId = in.readLong();
@@ -859,9 +845,11 @@ public class LoadJob implements Writable {
         timeoutSecond = in.readInt();
         maxFilterRatio = in.readDouble();
 
+        // CHECKSTYLE OFF
         boolean deleteFlag = false;
         deleteFlag = in.readBoolean();
-        
+        // CHECKSTYLE ON
+
         state = JobState.valueOf(Text.readString(in));
         progress = in.readInt();
         createTimeMs = in.readLong();
@@ -927,10 +915,12 @@ public class LoadJob implements Writable {
         }
 
         if (version >= 3 && version < 7) {
+            // CHECKSTYLE OFF
             // bos 3 parameters
             String bosEndpoint = Text.readString(in);
             String bosAccessKey = Text.readString(in);
             String bosSecretAccessKey = Text.readString(in);
+            // CHECKSTYLE ON
         }
 
         this.priority = TPriority.valueOf(Text.readString(in));
@@ -964,7 +954,7 @@ public class LoadJob implements Writable {
                 } else {
                     Operator op = Operator.valueOf(opStr);
                     String value = Text.readString(in);
-                    BinaryPredicate predicate = new BinaryPredicate(op, new SlotRef(null, key), 
+                    BinaryPredicate predicate = new BinaryPredicate(op, new SlotRef(null, key),
                             new StringLiteral(value));
                     conditions.add(predicate);
                 }
