@@ -24,7 +24,7 @@ import java.lang.annotation.RetentionPolicy;
 /*
  * AuditEvent contains all information about audit log info.
  * It should be created by AuditEventBuilder. For example:
- * 
+ *
  *      AuditEvent event = new AuditEventBuilder()
  *          .setEventType(AFTER_QUERY)
  *          .setClientIp(xxx)
@@ -60,6 +60,10 @@ public class AuditEvent {
     public String db = "";
     @AuditField(value = "State")
     public String state = "";
+    @AuditField(value = "ErrorCode")
+    public int errorCode = 0;
+    @AuditField(value = "ErrorMessage")
+    public String errorMessage = "";
     @AuditField(value = "Time")
     public long queryTime = -1;
     @AuditField(value = "ScanBytes")
@@ -84,6 +88,12 @@ public class AuditEvent {
     public String sqlHash = "";
     @AuditField(value = "peakMemoryBytes")
     public long peakMemoryBytes = -1;
+    @AuditField(value = "SqlDigest")
+    public String sqlDigest = "";
+    @AuditField(value = "TraceId")
+    public String traceId = "";
+    @AuditField(value = "FuzzyVariables")
+    public String fuzzyVariables = "";
 
     public static class AuditEventBuilder {
 
@@ -126,6 +136,16 @@ public class AuditEvent {
             return this;
         }
 
+        public AuditEventBuilder setErrorCode(int errorCode) {
+            auditEvent.errorCode = errorCode;
+            return this;
+        }
+
+        public AuditEventBuilder setErrorMessage(String errorMessage) {
+            auditEvent.errorMessage = errorMessage;
+            return this;
+        }
+
         public AuditEventBuilder setQueryTime(long queryTime) {
             auditEvent.queryTime = queryTime;
             return this;
@@ -186,6 +206,21 @@ public class AuditEvent {
             return this;
         }
 
+        public AuditEventBuilder setSqlDigest(String sqlDigest) {
+            auditEvent.sqlDigest = sqlDigest;
+            return this;
+        }
+
+        public AuditEventBuilder setTraceId(String traceId) {
+            auditEvent.traceId = traceId;
+            return this;
+        }
+
+        public AuditEventBuilder setFuzzyVariables(String variables) {
+            auditEvent.fuzzyVariables = variables;
+            return this;
+        }
+
         public AuditEvent build() {
             return this.auditEvent;
         }
