@@ -17,7 +17,7 @@
 
 package org.apache.doris.transaction;
 
-import org.apache.doris.catalog.Catalog;
+import org.apache.doris.catalog.Env;
 import org.apache.doris.catalog.OlapTable;
 import org.apache.doris.common.Config;
 import org.apache.doris.common.FeMetaVersion;
@@ -171,6 +171,7 @@ public class TransactionState implements Writable {
 
     private long dbId;
     private List<Long> tableIdList;
+    private int replicaNum = 0;
     private long transactionId;
     private String label;
     // requestId is used to judge whether a begin request is a internal retry request.
@@ -188,9 +189,10 @@ public class TransactionState implements Writable {
     private String reason = "";
     // error replica ids
     private Set<Long> errorReplicas;
-    private CountDownLatch latch;
+    // this latch will be counted down when txn status change to VISIBLE
+    private CountDownLatch visibleLatch;
 
-    // this state need not to be serialized
+    // this state need not be serialized
     private Map<Long, PublishVersionTask> publishVersionTasks;
     private boolean hasSendTask;
     private long publishVersionTime = -1;
@@ -246,12 +248,12 @@ public class TransactionState implements Writable {
         this.errorReplicas = Sets.newHashSet();
         this.publishVersionTasks = Maps.newHashMap();
         this.hasSendTask = false;
-        this.latch = new CountDownLatch(1);
+        this.visibleLatch = new CountDownLatch(1);
         this.authCode = UUID.randomUUID().toString();
     }
 
     public TransactionState(long dbId, List<Long> tableIdList, long transactionId, String label, TUniqueId requestId,
-                            LoadJobSourceType sourceType, TxnCoordinator txnCoordinator, long callbackId, long timeoutMs) {
+            LoadJobSourceType sourceType, TxnCoordinator txnCoordinator, long callbackId, long timeoutMs) {
         this.dbId = dbId;
         this.tableIdList = (tableIdList == null ? Lists.newArrayList() : tableIdList);
         this.transactionId = transactionId;
@@ -269,7 +271,7 @@ public class TransactionState implements Writable {
         this.errorReplicas = Sets.newHashSet();
         this.publishVersionTasks = Maps.newHashMap();
         this.hasSendTask = false;
-        this.latch = new CountDownLatch(1);
+        this.visibleLatch = new CountDownLatch(1);
         this.callbackId = callbackId;
         this.timeoutMs = timeoutMs;
         this.authCode = UUID.randomUUID().toString();
@@ -379,7 +381,6 @@ public class TransactionState implements Writable {
 
         // after status changed
         if (transactionStatus == TransactionStatus.VISIBLE) {
-            this.latch.countDown();
             if (MetricRepo.isInit) {
                 MetricRepo.COUNTER_TXN_SUCCESS.increase(1L);
             }
@@ -392,7 +393,7 @@ public class TransactionState implements Writable {
 
     public void beforeStateTransform(TransactionStatus transactionStatus) throws TransactionException {
         // before status changed
-        callback = Catalog.getCurrentGlobalTransactionMgr().getCallbackFactory().getCallback(callbackId);
+        callback = Env.getCurrentGlobalTransactionMgr().getCallbackFactory().getCallback(callbackId);
         if (callback != null) {
             switch (transactionStatus) {
                 case ABORTED:
@@ -420,11 +421,11 @@ public class TransactionState implements Writable {
         afterStateTransform(transactionStatus, txnOperated, null);
     }
 
-    public void afterStateTransform(TransactionStatus transactionStatus, boolean txnOperated, String txnStatusChangeReason)
-            throws UserException {
+    public void afterStateTransform(TransactionStatus transactionStatus,
+            boolean txnOperated, String txnStatusChangeReason) throws UserException {
         // after status changed
         if (callback == null) {
-            callback = Catalog.getCurrentGlobalTransactionMgr().getCallbackFactory().getCallback(callbackId);
+            callback = Env.getCurrentGlobalTransactionMgr().getCallbackFactory().getCallback(callbackId);
         }
         if (callback != null) {
             switch (transactionStatus) {
@@ -444,8 +445,8 @@ public class TransactionState implements Writable {
     }
 
     public void replaySetTransactionStatus() {
-        TxnStateChangeCallback callback = Catalog.getCurrentGlobalTransactionMgr().getCallbackFactory().getCallback(
-                callbackId);
+        TxnStateChangeCallback callback = Env.getCurrentGlobalTransactionMgr().getCallbackFactory()
+                .getCallback(callbackId);
         if (callback != null) {
             if (transactionStatus == TransactionStatus.ABORTED) {
                 callback.replayOnAborted(this);
@@ -457,8 +458,12 @@ public class TransactionState implements Writable {
         }
     }
 
+    public void countdownVisibleLatch() {
+        this.visibleLatch.countDown();
+    }
+
     public void waitTransactionVisible(long timeoutMillis) throws InterruptedException {
-        this.latch.await(timeoutMillis, TimeUnit.MILLISECONDS);
+        this.visibleLatch.await(timeoutMillis, TimeUnit.MILLISECONDS);
     }
 
     public void setPrepareTime(long prepareTime) {
@@ -534,8 +539,10 @@ public class TransactionState implements Writable {
 
     // return true if txn is running but timeout
     public boolean isTimeout(long currentMillis) {
-        return (transactionStatus == TransactionStatus.PREPARE && currentMillis - prepareTime > timeoutMs) ||
-                (transactionStatus == TransactionStatus.PRECOMMITTED && currentMillis - preCommitTime > preCommittedTimeoutMs);
+        return (transactionStatus == TransactionStatus.PREPARE
+                && currentMillis - prepareTime > timeoutMs)
+                || (transactionStatus == TransactionStatus.PRECOMMITTED
+                && currentMillis - preCommitTime > preCommittedTimeoutMs);
     }
 
     public synchronized void addTableIndexes(OlapTable table) {
@@ -650,7 +657,7 @@ public class TransactionState implements Writable {
         transactionStatus = TransactionStatus.valueOf(in.readInt());
         sourceType = LoadJobSourceType.valueOf(in.readInt());
         prepareTime = in.readLong();
-        if (Catalog.getCurrentCatalogJournalVersion() >= FeMetaVersion.VERSION_107) {
+        if (Env.getCurrentEnvJournalVersion() >= FeMetaVersion.VERSION_107) {
             preCommitTime = in.readLong();
         }
         commitTime = in.readLong();
