@@ -29,25 +29,22 @@ import org.apache.doris.common.AnalysisException;
 import org.apache.doris.common.Config;
 import org.apache.doris.common.UserException;
 import org.apache.doris.common.jmockit.Deencapsulation;
+import org.apache.doris.datasource.InternalCatalog;
 import org.apache.doris.qe.ConnectContext;
 
 import com.google.common.collect.Lists;
-
+import mockit.Expectations;
+import mockit.Injectable;
+import mockit.Mocked;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
 import java.util.ArrayList;
 import java.util.List;
-import mockit.Expectations;
-import mockit.Injectable;
-import mockit.Mocked;
-
-import mockit.Expectations;
-import mockit.Injectable;
-import mockit.Mocked;
 
 public class CreateMaterializedViewStmtTest {
+    private static final String internalCtl = InternalCatalog.INTERNAL_CATALOG_NAME;
 
     @Mocked
     private Analyzer analyzer;
@@ -95,7 +92,7 @@ public class CreateMaterializedViewStmtTest {
         SelectListItem selectListItem = new SelectListItem(slotRef, null);
         selectList.addItem(selectListItem);
 
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         SlotRef slotRef2 = new SlotRef(tableName, "v1");
         List<Expr> fnChildren = Lists.newArrayList(slotRef2);
         Deencapsulation.setField(slotRef2, "desc", slotDescriptor);
@@ -176,7 +173,7 @@ public class CreateMaterializedViewStmtTest {
         try {
             createMaterializedViewStmt.analyze(analyzer);
             Assert.fail();
-        } catch (IllegalArgumentException e) {
+        } catch (Exception e) {
             System.out.print(e.getMessage());
         }
     }
@@ -334,7 +331,7 @@ public class CreateMaterializedViewStmtTest {
         SelectList selectList = new SelectList();
         SelectListItem selectListItem1 = new SelectListItem(slotRef1, null);
         selectList.addItem(selectListItem1);
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         SlotRef slotRef2 = new SlotRef(tableName, "v1");
         Deencapsulation.setField(slotRef2, "desc", slotDescriptor);
         List<Expr> fnChildren = Lists.newArrayList(slotRef2);
@@ -381,7 +378,7 @@ public class CreateMaterializedViewStmtTest {
     @Test
     public void testDuplicateColumn(@Injectable SelectStmt selectStmt, @Injectable AggregateFunction aggregateFunction) throws UserException {
         SelectList selectList = new SelectList();
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         SlotRef slotRef1 = new SlotRef(tableName, "k1");
         SelectListItem selectListItem1 = new SelectListItem(slotRef1, null);
         selectList.addItem(selectListItem1);
@@ -418,7 +415,7 @@ public class CreateMaterializedViewStmtTest {
         SelectList selectList = new SelectList();
         SelectListItem selectListItem1 = new SelectListItem(slotRef1, null);
         selectList.addItem(selectListItem1);
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         SlotRef slotRef2 = new SlotRef(tableName, "k2");
         Deencapsulation.setField(slotRef2, "desc", slotDescriptor);
         List<Expr> fn1Children = Lists.newArrayList(slotRef2);
@@ -468,7 +465,7 @@ public class CreateMaterializedViewStmtTest {
         selectList.addItem(selectListItem1);
         SelectListItem selectListItem2 = new SelectListItem(slotRef2, null);
         selectList.addItem(selectListItem2);
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         SlotRef functionChild0 = new SlotRef(tableName, "v1");
         Deencapsulation.setField(functionChild0, "desc", slotDescriptor);
         List<Expr> fn1Children = Lists.newArrayList(functionChild0);
@@ -533,7 +530,7 @@ public class CreateMaterializedViewStmtTest {
         selectList.addItem(selectListItem3);
         SelectListItem selectListItem4 = new SelectListItem(slotRef4, null);
         selectList.addItem(selectListItem4);
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         final String columnName5 = "sum_v2";
         SlotRef functionChild0 = new SlotRef(tableName, columnName5);
         Deencapsulation.setField(functionChild0, "desc", slotDescriptor);
@@ -1029,7 +1026,7 @@ public class CreateMaterializedViewStmtTest {
         selectList.addItem(selectListItem1);
         SelectListItem selectListItem2 = new SelectListItem(slotRef2, null);
         selectList.addItem(selectListItem2);
-        TableName tableName = new TableName("db", "table");
+        TableName tableName = new TableName(internalCtl, "db", "table");
         final String columnName3 = "sum_v2";
         SlotRef slotRef = new SlotRef(tableName, columnName3);
         Deencapsulation.setField(slotRef, "desc", slotDescriptor);
@@ -1157,7 +1154,7 @@ public class CreateMaterializedViewStmtTest {
                                       @Injectable SlotDescriptor slotDescriptor3,
                                       @Injectable SlotDescriptor slotDescriptor4) {
         CreateMaterializedViewStmt createMaterializedViewStmt = new CreateMaterializedViewStmt("test", selectStmt, null);
-        SlotRef slotRef = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params = Lists.newArrayList();
         params.add(slotRef);
         FunctionCallExpr functionCallExpr = new FunctionCallExpr("sum", params);
@@ -1170,10 +1167,11 @@ public class CreateMaterializedViewStmtTest {
                 result = Type.LARGEINT;
             }
         };
-        MVColumnItem mvColumnItem = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr);
+        MVColumnItem mvColumnItem = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr);
         Assert.assertEquals(Type.LARGEINT, mvColumnItem.getType());
 
-        SlotRef slotRef2 = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef2 = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params2 = Lists.newArrayList();
         params2.add(slotRef2);
         FunctionCallExpr functionCallExpr2 = new FunctionCallExpr("sum", params2);
@@ -1186,10 +1184,11 @@ public class CreateMaterializedViewStmtTest {
                 result = Type.BIGINT;
             }
         };
-        MVColumnItem mvColumnItem2 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr2);
+        MVColumnItem mvColumnItem2 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr2);
         Assert.assertEquals(Type.BIGINT, mvColumnItem2.getType());
 
-        SlotRef slotRef3 = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef3 = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params3 = Lists.newArrayList();
         params3.add(slotRef3);
         FunctionCallExpr functionCallExpr3 = new FunctionCallExpr("min", params3);
@@ -1202,10 +1201,11 @@ public class CreateMaterializedViewStmtTest {
                 result = Type.VARCHAR;
             }
         };
-        MVColumnItem mvColumnItem3 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr3);
+        MVColumnItem mvColumnItem3 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr3);
         Assert.assertEquals(Type.VARCHAR, mvColumnItem3.getType());
 
-        SlotRef slotRef4 = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef4 = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params4 = Lists.newArrayList();
         params4.add(slotRef4);
         FunctionCallExpr functionCallExpr4 = new FunctionCallExpr("sum", params4);
@@ -1218,7 +1218,8 @@ public class CreateMaterializedViewStmtTest {
                 result = Type.DOUBLE;
             }
         };
-        MVColumnItem mvColumnItem4 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr4);
+        MVColumnItem mvColumnItem4 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr4);
         Assert.assertEquals(Type.DOUBLE, mvColumnItem4.getType());
 
     }
@@ -1232,7 +1233,7 @@ public class CreateMaterializedViewStmtTest {
                                                 @Injectable SlotDescriptor slotDescriptor3,
                                                 @Injectable Column column3) {
         CreateMaterializedViewStmt createMaterializedViewStmt = new CreateMaterializedViewStmt("test", selectStmt, null);
-        SlotRef slotRef = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params = Lists.newArrayList();
         params.add(slotRef);
         FunctionCallExpr functionCallExpr = new FunctionCallExpr("min", params);
@@ -1245,10 +1246,11 @@ public class CreateMaterializedViewStmtTest {
                 result = ScalarType.createVarchar(50);
             }
         };
-        MVColumnItem mvColumnItem = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr);
-        Assert.assertEquals(50, ((ScalarType)mvColumnItem.getType()).getLength());
+        MVColumnItem mvColumnItem = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr);
+        Assert.assertEquals(50, mvColumnItem.getType().getLength());
 
-        SlotRef slotRef2 = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef2 = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params2 = Lists.newArrayList();
         params2.add(slotRef2);
         FunctionCallExpr functionCallExpr2 = new FunctionCallExpr("min", params2);
@@ -1258,14 +1260,15 @@ public class CreateMaterializedViewStmtTest {
                 slotDescriptor2.getColumn();
                 result = column2;
                 column2.getOriginType();
-                result = ScalarType.createDecimalV2Type(10,1);
+                result = ScalarType.createDecimalType(10, 1);
             }
         };
-        MVColumnItem mvColumnItem2 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr2);
-        Assert.assertEquals(new Integer(10), ((ScalarType)mvColumnItem2.getType()).getPrecision());
-        Assert.assertEquals(1, ((ScalarType)mvColumnItem2.getType()).getScalarScale());
+        MVColumnItem mvColumnItem2 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr2);
+        Assert.assertEquals(new Integer(10), mvColumnItem2.getType().getPrecision());
+        Assert.assertEquals(1, ((ScalarType) mvColumnItem2.getType()).getScalarScale());
 
-        SlotRef slotRef3 = new SlotRef(new TableName("db", "table"), "a");
+        SlotRef slotRef3 = new SlotRef(new TableName(internalCtl, "db", "table"), "a");
         List<Expr> params3 = Lists.newArrayList();
         params3.add(slotRef3);
         FunctionCallExpr functionCallExpr3 = new FunctionCallExpr("min", params3);
@@ -1278,8 +1281,8 @@ public class CreateMaterializedViewStmtTest {
                 result = ScalarType.createChar(5);
             }
         };
-        MVColumnItem mvColumnItem3 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", functionCallExpr3);
-        Assert.assertEquals(5, ((ScalarType)mvColumnItem3.getType()).getLength());
+        MVColumnItem mvColumnItem3 = Deencapsulation.invoke(createMaterializedViewStmt, "buildMVColumnItem", analyzer,
+                functionCallExpr3);
+        Assert.assertEquals(5, mvColumnItem3.getType().getLength());
     }
 }
-
