@@ -23,19 +23,16 @@ import org.apache.doris.common.Pair;
 import org.apache.doris.thrift.TStorageMedium;
 
 import com.google.common.collect.Sets;
-
+import mockit.Expectations;
+import mockit.Mocked;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
 import java.io.DataInputStream;
 import java.io.DataOutputStream;
-import java.io.File;
-import java.io.FileInputStream;
-import java.io.FileOutputStream;
-
-import mockit.Expectations;
-import mockit.Mocked;
+import java.nio.file.Files;
+import java.nio.file.Path;
 
 public class TabletTest {
 
@@ -47,22 +44,22 @@ public class TabletTest {
     private TabletInvertedIndex invertedIndex;
 
     @Mocked
-    private Catalog catalog;
+    private Env env;
 
-    @Before 
+    @Before
     public void makeTablet() {
         invertedIndex = new TabletInvertedIndex();
-        new Expectations(catalog) {
+        new Expectations(env) {
             {
-                Catalog.getCurrentCatalogJournalVersion();
+                Env.getCurrentEnvJournalVersion();
                 minTimes = 0;
                 result = FeConstants.meta_version;
 
-                Catalog.getCurrentInvertedIndex();
+                Env.getCurrentInvertedIndex();
                 minTimes = 0;
                 result = invertedIndex;
 
-                Catalog.isCheckpointThread();
+                Env.isCheckpointThread();
                 minTimes = 0;
                 result = false;
             }
@@ -71,9 +68,9 @@ public class TabletTest {
         tablet = new Tablet(1);
         TabletMeta tabletMeta = new TabletMeta(10, 20, 30, 40, 1, TStorageMedium.HDD);
         invertedIndex.addTablet(1, tabletMeta);
-        replica1 = new Replica(1L, 1L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
-        replica2 = new Replica(2L, 2L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
-        replica3 = new Replica(3L, 3L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
+        replica1 = new Replica(1L, 1L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
+        replica2 = new Replica(2L, 2L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
+        replica3 = new Replica(3L, 3L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
         tablet.addReplica(replica1);
         tablet.addReplica(replica2);
         tablet.addReplica(replica3);
@@ -89,8 +86,8 @@ public class TabletTest {
         Assert.assertEquals(replica1, tablet.getReplicaByBackendId(replica1.getBackendId()));
         Assert.assertEquals(replica2, tablet.getReplicaByBackendId(replica2.getBackendId()));
         Assert.assertEquals(replica3, tablet.getReplicaByBackendId(replica3.getBackendId()));
-        
-        
+
+
         long newTabletId = 20000;
         tablet.setTabletId(newTabletId);
         Assert.assertEquals("tabletId=" + newTabletId, tablet.toString());
@@ -115,45 +112,43 @@ public class TabletTest {
         tablet.clearReplica();
         Assert.assertEquals(0, tablet.getReplicas().size());
     }
-        
+
     @Test
     public void testSerialization() throws Exception {
-        File file = new File("./olapTabletTest");
-        file.createNewFile();
-        DataOutputStream dos = new DataOutputStream(new FileOutputStream(file));
+        final Path path = Files.createTempFile("olapTabletTest", "tmp");
+        DataOutputStream dos = new DataOutputStream(Files.newOutputStream(path));
         tablet.write(dos);
         dos.flush();
         dos.close();
-        
+
         // 2. Read a object from file
-        DataInputStream dis = new DataInputStream(new FileInputStream(file));
+        DataInputStream dis = new DataInputStream(Files.newInputStream(path));
         Tablet rTablet1 = Tablet.read(dis);
         Assert.assertEquals(1, rTablet1.getId());
         Assert.assertEquals(3, rTablet1.getReplicas().size());
         Assert.assertEquals(rTablet1.getReplicas().get(0).getVersion(), rTablet1.getReplicas().get(1).getVersion());
-        
-        Assert.assertTrue(rTablet1.equals(tablet));
-        Assert.assertTrue(rTablet1.equals(rTablet1));
-        Assert.assertFalse(rTablet1.equals(this));
-        
+
+        Assert.assertEquals(rTablet1, tablet);
+        Assert.assertEquals(rTablet1, rTablet1);
+
         Tablet tablet2 = new Tablet(1);
-        Replica replica1 = new Replica(1L, 1L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
-        Replica replica2 = new Replica(2L, 2L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
-        Replica replica3 = new Replica(3L, 3L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0);
+        Replica replica1 = new Replica(1L, 1L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
+        Replica replica2 = new Replica(2L, 2L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
+        Replica replica3 = new Replica(3L, 3L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0);
         tablet2.addReplica(replica1);
         tablet2.addReplica(replica2);
-        Assert.assertFalse(tablet2.equals(tablet));
+        Assert.assertNotEquals(tablet2, tablet);
         tablet2.addReplica(replica3);
-        Assert.assertTrue(tablet2.equals(tablet));
-        
+        Assert.assertEquals(tablet2, tablet);
+
         Tablet tablet3 = new Tablet(1);
         tablet3.addReplica(replica1);
         tablet3.addReplica(replica2);
-        tablet3.addReplica(new Replica(4L, 4L, 100L, 0, 200000L, 3000L, ReplicaState.NORMAL, 0, 0));
-        Assert.assertFalse(tablet3.equals(tablet));
-        
+        tablet3.addReplica(new Replica(4L, 4L, 100L, 0, 200000L, 0, 3000L, ReplicaState.NORMAL, 0, 0));
+        Assert.assertNotEquals(tablet3, tablet);
+
         dis.close();
-        file.delete();
+        Files.delete(path);
     }
 
     /**
@@ -161,7 +156,8 @@ public class TabletTest {
      * @param backendId2ReplicaIsBad beId -> if replica is a bad replica
      */
     @SafeVarargs
-    private final void testTabletColocateHealthStatus0(Tablet.TabletStatus exceptedTabletStatus, Pair<Long, Boolean>... backendId2ReplicaIsBad) {
+    private final void testTabletColocateHealthStatus0(Tablet.TabletStatus exceptedTabletStatus,
+            Pair<Long, Boolean>... backendId2ReplicaIsBad) {
         Tablet tablet = new Tablet(1);
         int replicaId = 1;
         for (Pair<Long, Boolean> pair : backendId2ReplicaIsBad) {
@@ -171,7 +167,8 @@ public class TabletTest {
                 versionAndSuccessVersion = 99L;
                 lastFailVersion = 100L;
             }
-            tablet.addReplica(new Replica(replicaId++, pair.first, versionAndSuccessVersion, 0, 200000L, 3000L, ReplicaState.NORMAL, lastFailVersion, versionAndSuccessVersion));
+            tablet.addReplica(new Replica(replicaId++, pair.first, versionAndSuccessVersion, 0,
+                    200000L, 0, 3000L, ReplicaState.NORMAL, lastFailVersion, versionAndSuccessVersion));
         }
         Assert.assertEquals(tablet.getColocateHealthStatus(100L, new ReplicaAllocation((short) 3),
                 Sets.newHashSet(1L, 2L, 3L)), exceptedTabletStatus);
@@ -182,25 +179,25 @@ public class TabletTest {
         // [1 2 4]
         testTabletColocateHealthStatus0(
                 Tablet.TabletStatus.COLOCATE_MISMATCH,
-                Pair.create(1L, false), Pair.create(2L, false), Pair.create(4L, false)
+                Pair.of(1L, false), Pair.of(2L, false), Pair.of(4L, false)
         );
 
         // [1 2 3(bad)]
         testTabletColocateHealthStatus0(
                 Tablet.TabletStatus.VERSION_INCOMPLETE,
-                Pair.create(1L, false), Pair.create(2L, false), Pair.create(3L, true)
+                Pair.of(1L, false), Pair.of(2L, false), Pair.of(3L, true)
         );
 
         // 1 2 3 4(good)
         testTabletColocateHealthStatus0(
                 Tablet.TabletStatus.COLOCATE_REDUNDANT,
-                Pair.create(1L, false), Pair.create(2L, false), Pair.create(3L, false), Pair.create(4L, false)
+                Pair.of(1L, false), Pair.of(2L, false), Pair.of(3L, false), Pair.of(4L, false)
         );
 
         // [1 2 3 4(bad)]
         testTabletColocateHealthStatus0(
                 Tablet.TabletStatus.COLOCATE_REDUNDANT,
-                Pair.create(1L, false), Pair.create(2L, false), Pair.create(3L, false), Pair.create(4L, true)
+                Pair.of(1L, false), Pair.of(2L, false), Pair.of(3L, false), Pair.of(4L, true)
         );
     }
 }
