@@ -685,7 +685,7 @@ public class SelectMvIndexTest extends BaseMaterializedIndexSelectTest implement
         // don't use rollup k1_v1
         addRollup("alter table agg_table add rollup k1_v1(k1, v1)");
         // use rollup only_keys
-        addRollup("alter table agg_table add rollup only_keys (k1, k2) properties ('replication_num' = '1')");
+        addRollup("alter table agg_table add rollup only_keys (k2, k1) properties ('replication_num' = '1')");
 
         String query = "select k1, k2 from agg_table;";
         // todo: `preagg` should be ture when rollup could be used.
@@ -757,11 +757,11 @@ public class SelectMvIndexTest extends BaseMaterializedIndexSelectTest implement
 
     @Test
     public void testUniqueTableInQuery() throws Exception {
-        String uniqueTable = "CREATE TABLE " + TEST_TABLE_NAME + " (k1 int, v1 int) UNIQUE KEY (k1) "
-                + "DISTRIBUTED BY HASH(k1) BUCKETS 3 PROPERTIES ('replication_num' = '1');";
+        String uniqueTable = "CREATE TABLE " + TEST_TABLE_NAME + " (k1 int, k2 int, v1 int) UNIQUE KEY (k1, k2) "
+                + "DISTRIBUTED BY HASH(k1) BUCKETS 3 PROPERTIES ('replication_num' = '1','enable_unique_key_merge_on_write' = 'false');";
         createTable(uniqueTable);
-        String createK1MV = "create materialized view only_k1 as select k1 from " + TEST_TABLE_NAME + " group by "
-                + "k1;";
+        String createK1MV = "create materialized view only_k1 as select k2 from " + TEST_TABLE_NAME + " group by "
+                + "k2;";
         createMv(createK1MV);
         String query = "select * from " + TEST_TABLE_NAME + ";";
         singleTableTest(query, TEST_TABLE_NAME, false);
