@@ -14,10 +14,10 @@
 -- KIND, either express or implied.  See the License for the
 -- specific language governing permissions and limitations
 -- under the License.
-SELECT /*+SET_VAR(parallel_fragment_exec_instance_num=2, enable_vectorized_engine=true, batch_size=4096, enable_cost_based_join_reorder=true, enable_projection=true) */  
+SELECT /*+SET_VAR(parallel_fragment_exec_instance_num=2, enable_vectorized_engine=true, batch_size=4096, enable_cost_based_join_reorder=true, enable_projection=true) */
     d_year,
-    s_nation,
-    p_category,
+    s_city,
+    p_brand,
     SUM(lo_revenue - lo_supplycost) AS PROFIT
 FROM dates, customer, supplier, part, lineorder
 WHERE
@@ -25,15 +25,11 @@ WHERE
     AND lo_suppkey = s_suppkey
     AND lo_partkey = p_partkey
     AND lo_orderdate = d_datekey
-    AND c_region = 'AMERICA'
-    AND s_region = 'AMERICA'
+    AND s_nation = 'UNITED STATES'
     AND (
         d_year = 1997
         OR d_year = 1998
     )
-    AND (
-        p_mfgr = 'MFGR#1'
-        OR p_mfgr = 'MFGR#2'
-    )
-GROUP BY d_year, s_nation, p_category
-ORDER BY d_year, s_nation, p_category;
+    AND p_category = 'MFGR#14'
+GROUP BY d_year, s_city, p_brand
+ORDER BY d_year, s_city, p_brand;
